@@ -16,25 +16,26 @@
 #    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 ##############################################################################
 
-from __future__ import division, print_function
+import re
 
-from .. import qtall as qt4
+from .. import qtall as qt
 from .. import document
 from . import readcsv
 from . import base
 
 def _(text, disambiguation=None, context="Import_CSV"):
-    return qt4.QCoreApplication.translate(context, text, disambiguation)
+    return qt.QCoreApplication.translate(context, text, disambiguation)
 
 class ImportParamsCSV(base.ImportParamsBase):
     """CSV import parameters.
 
     additional parameters:
-     readrows: readdata in rows
+     readrows: read data in rows
      delimiter: CSV delimiter
+     skipwhitespace: whether to ignore white space following CSV delimiter
      textdelimiter: delimiter for text
      headerignore: number of lines to ignore after headers
-     rowsignore: number of lines to ignore at top fo file
+     rowsignore: number of lines to ignore at top of file
      blanksaredata: treat blank entries as nans
      numericlocale: name of local for numbers
      dateformat: date format string
@@ -44,6 +45,7 @@ class ImportParamsCSV(base.ImportParamsBase):
     defaults = {
         'readrows': False,
         'delimiter': ',',
+        'skipwhitespace' : False,
         'textdelimiter': '"',
         'headerignore': 0,
         'rowsignore': 0,
@@ -51,7 +53,7 @@ class ImportParamsCSV(base.ImportParamsBase):
         'numericlocale': 'en_US',
         'dateformat': 'YYYY-MM-DD|T|hh:mm:ss',
         'headermode': 'multi',
-        }
+    }
     defaults.update(base.ImportParamsBase.defaults)
 
     def __init__(self, **argsv):
@@ -67,7 +69,12 @@ class OperationDataImportCSV(base.OperationDataImportBase):
     def doImport(self):
         """Do the data import."""
 
-        csvr = readcsv.ReadCSV(self.params)
+        try:
+            csvr = readcsv.ReadCSV(self.params)
+        except re.error:
+            # invalid date RE
+            raise base.ImportingError(_('Invalid date regular expression'))
+
         csvr.readData()
 
         LF = None
@@ -95,7 +102,7 @@ class LinkedFileCSV(base.LinkedFileBase):
 
 def ImportFileCSV(comm, filename,
                   readrows=False,
-                  delimiter=',', textdelimiter='"',
+                  delimiter=',', skipwhitespace=False, textdelimiter='"',
                   encoding='utf_8',
                   headerignore=0, rowsignore=0,
                   blanksaredata=False,
@@ -111,6 +118,7 @@ def ImportFileCSV(comm, filename,
 
     readrows: if true, data are read across rather than down
     delimiter: character for delimiting data (usually ',')
+    skipwhitespace: if true, white space following delimiter is ignored
     textdelimiter: character surrounding text (usually '"')
     encoding: encoding used in file
     headerignore: number of lines to ignore after header text
@@ -143,7 +151,8 @@ def ImportFileCSV(comm, filename,
 
     params = ImportParamsCSV(
         filename=realfilename, readrows=readrows,
-        delimiter=delimiter, textdelimiter=textdelimiter,
+        delimiter=delimiter, skipwhitespace=skipwhitespace,
+        textdelimiter=textdelimiter,
         encoding=encoding,
         headerignore=headerignore, rowsignore=rowsignore,
         blanksaredata=blanksaredata,
@@ -152,7 +161,7 @@ def ImportFileCSV(comm, filename,
         prefix=dsprefix, suffix=dssuffix,
         renames=renames,
         linked=linked,
-        )
+    )
     op = OperationDataImportCSV(params)
     comm.document.applyOperation(op)
 
