@@ -16,16 +16,13 @@
 #    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 ##############################################################################
 
-from __future__ import division, print_function
-import traceback
-
 from .. import document
 from .. import plugins
-from .. import qtall as qt4
+from .. import qtall as qt
 from . import base
 
 def _(text, disambiguation=None, context="Import_Plugin"):
-    return qt4.QCoreApplication.translate(context, text, disambiguation)
+    return qt.QCoreApplication.translate(context, text, disambiguation)
 
 class ImportParamsPlugin(base.ImportParamsBase):
     """Parameters for import plugins.
