@@ -16,13 +16,10 @@
 #    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 ##############################################################################
 
-from __future__ import division, print_function, absolute_import
-
 from .. import qtall as qt
 from .. import setting
 from .. import utils
 from ..dialogs import importdialog
-from ..compat import cstr
 
 from . import base
 from . import defn_fits
@@ -137,7 +134,7 @@ class ImportTabFITS(importdialog.ImportTab):
         self.datanodes = []
 
         valid = qt.QDoubleValidator(self)
-        valid.setNotation(qt.QDoubleValidator.ScientificNotation)
+        valid.setNotation(qt.QDoubleValidator.Notation.ScientificNotation)
         for w in (self.fitstwodminx, self.fitstwodminy,
                   self.fitstwodmaxx, self.fitstwodmaxy):
             w.setValidator(valid)
@@ -197,15 +194,16 @@ class ImportTabFITS(importdialog.ImportTab):
             'pixel': 1,
             'pixel_wcs': 2,
             'fraction': 3,
-            }[wcsmode]
+        }[wcsmode]
         self.fitswcsmode.setCurrentIndex(idx)
 
     def updateOptionsTwoD(self, node):
         """Read options for 2d datasets on dialog."""
 
         rangeout = []
-        for w in (self.fitstwodminx, self.fitstwodminy,
-                  self.fitstwodmaxx, self.fitstwodmaxy):
+        for w in (
+                self.fitstwodminx, self.fitstwodminy,
+                self.fitstwodmaxx, self.fitstwodmaxy):
             txt = w.text()
             val, ok = setting.uilocale.toDouble(txt)
             if not ok: val = None
@@ -261,7 +259,7 @@ class ImportTabFITS(importdialog.ImportTab):
 
         for widget, name in (
             (self.fitstwodgrp, 'twod'),
-            ):
+        ):
             if name == toshow:
                 widget.show()
             else:
@@ -318,7 +316,7 @@ class ImportTabFITS(importdialog.ImportTab):
             tags=tags,
             prefix=prefix, suffix=suffix,
             linked=linked,
-            )
+        )
 
         op = defn_fits.OperationDataImportFITS(params)
 
@@ -334,7 +332,7 @@ class ImportTabFITS(importdialog.ImportTab):
             utils.feedback.importcts['fits'] += 1
 
         except base.ImportingError as e:
-            self.fitsimportstatus.setText(_("Error: %s") % cstr(e))
+            self.fitsimportstatus.setText(_("Error: %s") % str(e))
 
         qt.QTimer.singleShot(4000, self.fitsimportstatus.clear)
 
