@@ -16,11 +16,10 @@
 #    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 ##############################################################################
 
-from __future__ import division, print_function
+import csv
 import re
 
-from .. import qtall as qt4
-from ..compat import cstr
+from .. import qtall as qt
 from .. import utils
 from ..dialogs import importdialog
 from . import defn_twod
@@ -28,7 +27,7 @@ from . import simpleread
 from . import dialog_csv
 
 def _(text, disambiguation=None, context="Import_2D"):
-    return qt4.QCoreApplication.translate(context, text, disambiguation)
+    return qt.QCoreApplication.translate(context, text, disambiguation)
 
 class ImportTab2D(importdialog.ImportTab):
     """Tab for importing from a 2D data file."""
@@ -39,11 +38,13 @@ class ImportTab2D(importdialog.ImportTab):
         """Load user interface and set up validators."""
         importdialog.ImportTab.loadUi(self)
 
-        self.rangeedits = [ self.twod_xminedit, self.twod_xmaxedit,
-                            self.twod_yminedit, self.twod_ymaxedit ]
+        self.rangeedits = [
+            self.twod_xminedit, self.twod_xmaxedit,
+            self.twod_yminedit, self.twod_ymaxedit
+        ]
 
         # set up some validators for 2d edits
-        dval = qt4.QDoubleValidator(self)
+        dval = qt.QDoubleValidator(self)
         for w in self.rangeedits:
             w.setValidator(dval)
 
@@ -64,7 +65,7 @@ class ImportTab2D(importdialog.ImportTab):
 
     def slotGridAtEdgeChanged(self, state):
         """Enable/disable widgets depending on grid at edge."""
-        nogridatedge = state == qt4.Qt.Unchecked
+        nogridatedge = state == qt.Qt.CheckState.Unchecked
         for w in self.rangeedits:
             w.setEnabled(nogridatedge)
             if not nogridatedge:
@@ -74,9 +75,10 @@ class ImportTab2D(importdialog.ImportTab):
         """Reset controls."""
         for combo in self.rangeedits + [self.twod_datasetsedit]:
             combo.setEditText("")
-        for check in (self.twod_invertrowscheck, self.twod_invertcolscheck,
-                      self.twod_transposecheck, self.twod_gridatedge,
-                      self.twod_gridatedge):
+        for check in (
+                self.twod_invertrowscheck, self.twod_invertcolscheck,
+                self.twod_transposecheck, self.twod_gridatedge,
+                self.twod_gridatedge ):
             check.setChecked(False)
         self.twod_mode.setCurrentIndex(0)
         self.twod_csvdelim.setEditText(dialog_csv.csv_delimiters[0])
@@ -172,7 +174,7 @@ class ImportTab2D(importdialog.ImportTab):
             tags=tags,
             linked=linked,
             encoding=encoding
-            )
+        )
 
         try:
             op = defn_twod.OperationDataImport2D(params)
@@ -190,8 +192,8 @@ class ImportTab2D(importdialog.ImportTab):
             # feature feedback
             utils.feedback.importcts['twod'] += 1
 
-        except simpleread.Read2DError as e:
-            output = _('Error importing datasets:\n %s') % cstr(e)
+        except (simpleread.Read2DError, csv.Error) as e:
+            output = _('Error importing datasets:\n %s') % str(e)
 
         # show status in preview box
         self.twod_previewedit.setPlainText(output)
