@@ -16,8 +16,6 @@
 #    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 ##############################################################################
 
-from __future__ import division, print_function, absolute_import
-
 from .. import qtall as qt
 from . import fits_hdf5_helpers
 
@@ -71,24 +69,23 @@ class GenericTreeModel(qt.QAbstractItemModel):
         return node.setData(self, index, value, role)
 
     def flags(self, index):
-        defflags = qt.QAbstractItemModel.flags(self, index)
-        if not index.isValid():
-            return defflags
-        else:
+        flags = qt.QAbstractItemModel.flags(self, index)
+        if index.isValid():
             node = index.internalPointer()
-            return node.flags(index.column(), defflags)
+            flags = node.flags(index.column(), flags)
+        return flags
 
     def columnCount(self, parent):
         return len(self.columnheads)
 
     def headerData(self, section, orientation, role):
-        if ( orientation == qt.Qt.Horizontal and
-             role == qt.Qt.DisplayRole and
+        if ( orientation == qt.Qt.Orientation.Horizontal and
+             role == qt.Qt.ItemDataRole.DisplayRole and
              section < len(self.columnheads) ):
             return self.columnheads[section]
         return None
 
-class Node(object):
+class Node:
     """Generic Node used by tree model."""
     def __init__(self, parent):
         self.parent = parent
@@ -103,6 +100,26 @@ class Node(object):
     def setData(self, model, index, value, role):
         return False
 
+    def _updateRow(self, model, index):
+        """Helper to tell model to update view of index given."""
+        par = model.parent(index)
+        row = index.row()
+        idx1 = model.index(row, 0, par)
+        idx2 = model.index(row, model.columnCount(index)-1, par)
+        model.dataChanged.emit(idx1, idx2)
+
+    def _recursiveUpdate(self, model, rootindex):
+        """Recursively tell model to update view starting from index."""
+        def recurse(idx):
+            nc = model.rowCount(idx)
+            if nc > 0:
+                idx1 = model.index(0, 0, idx)
+                idx2 = model.index(nc-1, model.columnCount(idx)-1, idx)
+                model.dataChanged.emit(idx1, idx2)
+                for i in range(nc):
+                    recurse(model.index(i, 0, idx))
+        recurse(rootindex)
+
 class ErrorNode(Node):
     """Node for showing error messages."""
 
@@ -111,7 +128,7 @@ class ErrorNode(Node):
         self.name = name
 
     def data(self, column, role):
-        if column == 0 and role == qt.Qt.DisplayRole:
+        if column == 0 and role == qt.Qt.ItemDataRole.DisplayRole:
             return self.name
         return None
 
@@ -161,12 +178,12 @@ class ImportNameDeligate(qt.QItemDelegate):
 
         w.addItems([x[0] for x in out])
         for v, item in enumerate(out):
-            w.setItemData(v, item[1], qt.Qt.ToolTipRole)
+            w.setItemData(v, item[1], qt.Qt.ItemDataRole.ToolTipRole)
         return w
 
     def setEditorData(self, editor, index):
         """Update data in editor."""
-        text = index.data(qt.Qt.EditRole)
+        text = index.data(qt.Qt.ItemDataRole.EditRole)
 
         i = editor.findText(text)
         if i != -1:
@@ -176,8 +193,8 @@ class ImportNameDeligate(qt.QItemDelegate):
 
     def setModelData(self, editor, model, index):
         """Update data in model."""
-        model.setData(index, editor.currentText(),
-                      qt.Qt.EditRole)
+        model.setData(
+            index, editor.currentText(), qt.Qt.ItemDataRole.EditRole)
 
     def updateEditorGeometry(self, editor, option, index):
         """Update editor geometry."""
@@ -201,13 +218,6 @@ class FileNode(Node):
             p = p.parent
         return False
 
-    def _updateRow(self, model, index):
-        """This is messy - inform view that this row has changed."""
-        par = model.parent(index)
-        row = index.row()
-        idx1 = model.index(row, 0, par)
-        idx2 = model.index(row, model.columnCount(index)-1, par)
-        model.dataChanged.emit(idx1, idx2)
 
 class FileGroupNode(FileNode):
     def __init__(self, parent, name, dispname):
@@ -217,14 +227,16 @@ class FileGroupNode(FileNode):
         self.grpimport = False
 
     def data(self, column, role):
-        if column == _ColName and role == qt.Qt.DisplayRole:
+        if column == _ColName and role == qt.Qt.ItemDataRole.DisplayRole:
             return self.name
-        elif role == qt.Qt.CheckStateRole and column == _ColToImport:
-            return ( qt.Qt.Checked
-                     if self.grpimport or self.grpImport()
-                     else qt.Qt.Unchecked )
+        elif role == qt.Qt.ItemDataRole.CheckStateRole and column == _ColToImport:
+            return (
+                qt.Qt.CheckState.Checked
+                if self.grpimport or self.grpImport()
+                else qt.Qt.CheckState.Unchecked
+            )
 
-        elif role == qt.Qt.ToolTipRole:
+        elif role == qt.Qt.ItemDataRole.ToolTipRole:
             if column == _ColToImport:
                 return _("Check to import all datasets under this group")
             elif column == _ColName:
@@ -236,9 +248,9 @@ class FileGroupNode(FileNode):
         """Enable selection of group for importing. This prevents
         importing child items individually."""
         column = index.column()
-        if column == _ColToImport and role == qt.Qt.CheckStateRole:
+        if column == _ColToImport and role == qt.Qt.ItemDataRole.CheckStateRole:
             # import check has changed
-            self.grpimport = value == qt.Qt.Checked
+            self.grpimport = value != 0
 
             # disable importing of child nodes
             def recursivedisable(node):
@@ -252,18 +264,18 @@ class FileGroupNode(FileNode):
             if self.grpimport:
                 recursivedisable(self)
 
-            self._updateRow(model, index)
+            self._recursiveUpdate(model, index)
             return True
 
         return False
 
     def flags(self, column, defflags):
         if self.grpImport():
-            defflags &= ~qt.Qt.ItemIsEnabled
+            defflags &= ~qt.Qt.ItemFlag.ItemIsEnabled
             return defflags
 
         if column == _ColToImport:
-            defflags |= qt.Qt.ItemIsUserCheckable
+            defflags |= qt.Qt.ItemFlag.ItemIsUserCheckable
         return defflags
 
 class EmptyDataNode(FileNode):
@@ -276,12 +288,12 @@ class EmptyDataNode(FileNode):
     def data(self, column, role):
         """Return data for column"""
 
-        if role == qt.Qt.DisplayRole:
+        if role == qt.Qt.ItemDataRole.DisplayRole:
             if column == _ColName:
                 return self.name
             elif column == _ColShape:
                 return _('Empty')
-        elif role == qt.Qt.ToolTipRole:
+        elif role == qt.Qt.ItemDataRole.ToolTipRole:
             if column == _ColName:
                 return self.fullname
 
@@ -353,16 +365,16 @@ class FileDataNode(FileNode):
 
     def data(self, column, role):
         """Return data for column"""
-        if role in (qt.Qt.DisplayRole, qt.Qt.EditRole):
+        if role in (qt.Qt.ItemDataRole.DisplayRole, qt.Qt.ItemDataRole.EditRole):
             if column == _ColName:
                 return self.name
             elif column == _ColDataType:
                 return self.datatype
             elif column == _ColShape:
-                return u'\u00d7'.join([str(x) for x in self.shape])
+                return '\u00d7'.join([str(x) for x in self.shape])
 
             elif column == _ColImportName:
-                if role == qt.Qt.EditRole and not self.importname:
+                if role == qt.Qt.ItemDataRole.EditRole and not self.importname:
                     return self.name
                 else:
                     if self.importname:
@@ -381,7 +393,7 @@ class FileDataNode(FileNode):
                         self.attrs["vsz_slice"])
                 return None
 
-        elif role == qt.Qt.ToolTipRole:
+        elif role == qt.Qt.ItemDataRole.ToolTipRole:
             if column == _ColName:
                 return self.fullname
             elif column == _ColDataType:
@@ -406,19 +418,19 @@ class FileDataNode(FileNode):
                     '   :10,:,2:20\n'
                     '   1:10:5,::5')
 
-        elif role == qt.Qt.CheckStateRole and column == _ColToImport:
+        elif role == qt.Qt.ItemDataRole.CheckStateRole and column == _ColToImport:
             if ( (self.toimport or self.grpImport()) and
                  self.dimsOkForImport() ):
-                return qt.Qt.Checked
-            return qt.Qt.Unchecked
+                return qt.Qt.CheckState.Checked
+            return qt.Qt.CheckState.Unchecked
         return None
 
     def setData(self, model, index, value, role):
         # enable selection of dataset for importing
         column = index.column()
-        if column == _ColToImport and role == qt.Qt.CheckStateRole:
+        if column == _ColToImport and role == qt.Qt.ItemDataRole.CheckStateRole:
             # import check has changed
-            self.toimport = value == qt.Qt.Checked
+            self.toimport = value != 0
             if not self.toimport:
                 self.importname = ''
 
@@ -440,17 +452,16 @@ class FileDataNode(FileNode):
         return False
 
     def flags(self, column, defflags):
-
         if ( column == _ColToImport and self.datatypevalid and
              not self.grpImport() and self.dimsOkForImport() ):
             # allow import column to be clicked
-            defflags |= qt.Qt.ItemIsUserCheckable
+            defflags |= qt.Qt.ItemFlag.ItemIsUserCheckable
         elif ( column == _ColImportName and (self.toimport or self.grpImport())
                and self.dimsOkForImport() ):
-            defflags |= qt.Qt.ItemIsEditable
+            defflags |= qt.Qt.ItemFlag.ItemIsEditable
         elif column == _ColSlice and self.datatypevalid:
             # allow name to be edited
-            defflags |= qt.Qt.ItemIsEditable
+            defflags |= qt.Qt.ItemFlag.ItemIsEditable
 
         return defflags
 
@@ -463,11 +474,11 @@ class FileCompoundNode(FileGroupNode):
 
     def data(self, column, role):
         """Return data for column"""
-        if role == qt.Qt.DisplayRole:
+        if role == qt.Qt.ItemDataRole.DisplayRole:
             if column == _ColDataType:
                 return _("Table")
             elif column == _ColShape:
-                return u'\u00d7'.join([str(x) for x in self.shape])
+                return '\u00d7'.join([str(x) for x in self.shape])
         return FileGroupNode.data(self, column, role)
 
 ##############################################################################
@@ -481,8 +492,10 @@ def setupTreeView(view, rootnode, datanodes):
 
     mod = GenericTreeModel(
         view, rootnode,
-        [_('Name'), _('Type'), _('Size'), _('Import'),
-         _('Import as'), _('Slice')])
+        [
+            _('Name'), _('Type'), _('Size'), _('Import'),
+            _('Import as'), _('Slice')
+        ])
 
     view.setModel(mod)
     view.expandAll()
