@@ -16,11 +16,9 @@
 #    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 ##############################################################################
 
-from __future__ import division
 import ast
 import copy
 
-from ..compat import cstrerror
 from .. import qtall as qt
 from .. import document
 from .veuszdialog import VeuszDialog
@@ -86,7 +84,7 @@ class CustomItemModel(qt.QAbstractTableModel):
 
     def data(self, index, role):
         """Lookup data in document.evaluate.customs list."""
-        if role in (qt.Qt.DisplayRole, qt.Qt.EditRole):
+        if role in (qt.Qt.ItemDataRole.DisplayRole, qt.Qt.ItemDataRole.EditRole):
             try:
                 defn = self._getCustoms()[index.row()]
             except IndexError:
@@ -97,7 +95,7 @@ class CustomItemModel(qt.QAbstractTableModel):
                 return repr(defn[col])
             else:
                 return defn[col]
-        elif role == qt.Qt.ToolTipRole:
+        elif role == qt.Qt.ItemDataRole.ToolTipRole:
             # tooltip on row for new entries on last row
             if index.row() == len(self._getCustoms()):
                 return self.tooltips[self.ctype][index.column()]
@@ -107,13 +105,13 @@ class CustomItemModel(qt.QAbstractTableModel):
     def flags(self, index):
         """Items are editable"""
         return (
-            qt.Qt.ItemIsSelectable | qt.Qt.ItemIsEditable |
-            qt.Qt.ItemIsEnabled )
+            qt.Qt.ItemFlag.ItemIsSelectable | qt.Qt.ItemFlag.ItemIsEditable |
+            qt.Qt.ItemFlag.ItemIsEnabled )
 
     def headerData(self, section, orientation, role):
         """Return the headers at the top of the view."""
-        if role == qt.Qt.DisplayRole:
-            if orientation == qt.Qt.Horizontal:
+        if role == qt.Qt.ItemDataRole.DisplayRole:
+            if orientation == qt.Qt.Orientation.Horizontal:
                 # columns defined in headers
                 return self.headers[self.ctype][section]
             else:
@@ -147,7 +145,7 @@ class CustomItemModel(qt.QAbstractTableModel):
 
     def setData(self, index, value, role):
         """Edit an item."""
-        if index.isValid() and role == qt.Qt.EditRole:
+        if index.isValid() and role == qt.Qt.ItemDataRole.EditRole:
             col = index.column()
             row = index.row()
 
@@ -257,7 +255,7 @@ class CustomDialog(VeuszDialog):
             1: (self.importView, self.importModel),
             2: (self.colorView, self.colorModel),
             3: (self.colormapView, self.colormapModel)
-            }[self.viewsTab.currentIndex()]
+        }[self.viewsTab.currentIndex()]
 
     def slotRemove(self):
         """Remove an entry."""
@@ -299,7 +297,7 @@ class CustomDialog(VeuszDialog):
                 qt.QMessageBox.critical(
                     self, _("Error - Veusz"),
                     _("Unable to save '%s'\n\n%s") % (
-                        filename, cstrerror(e)))
+                        filename, e.strerror))
 
     def slotLoad(self):
         """Load entries."""
@@ -313,7 +311,7 @@ class CustomDialog(VeuszDialog):
                 qt.QMessageBox.critical(
                     self, _("Error - Veusz"),
                     _("Unable to load '%s'\n\n%s") % (
-                            filename, cstrerror(e)))
+                            filename, e.strerror))
             else:
                 # add to recent file list
                 self.recentButton.addFile(filename)
