@@ -20,27 +20,24 @@
 
 """Module for implementing dialog box for viewing/editing data."""
 
-from __future__ import division
+import numpy as N
 
-from ..compat import cstr
-from .. import qtall as qt4
+from .. import qtall as qt
 from .. import document
+from .. import datasets
 from .. import setting
 from ..qtwidgets.datasetbrowser import DatasetBrowser
-from .veuszdialog import VeuszDialog
-
-# register function to dataset class to edit dataset
-recreate_register = {}
+from .veuszdialog import VeuszDialog, recreate_register
 
 def _(text, disambiguation=None, context="DataEditDialog"):
     """Translate text."""
-    return qt4.QCoreApplication.translate(context, text, disambiguation)
+    return qt.QCoreApplication.translate(context, text, disambiguation)
 
-class DatasetTableModel1D(qt4.QAbstractTableModel):
+class DatasetTableModel1D(qt.QAbstractTableModel):
     """Provides access to editing and viewing of datasets."""
 
     def __init__(self, parent, document, datasetname):
-        qt4.QAbstractTableModel.__init__(self, parent)
+        qt.QAbstractTableModel.__init__(self, parent)
 
         self.document = document
         self.dsname = datasetname
@@ -81,7 +78,7 @@ class DatasetTableModel1D(qt4.QAbstractTableModel):
             # select correct part of dataset
             data = getattr(ds, ds.columns[index.column()])
         if ds is not None and data is not None and role in (
-            qt4.Qt.DisplayRole, qt4.Qt.EditRole):
+            qt.Qt.ItemDataRole.DisplayRole, qt.Qt.ItemDataRole.EditRole):
             # blank row at end of data
             if index.row() == len(data):
                 return None
@@ -101,8 +98,8 @@ class DatasetTableModel1D(qt4.QAbstractTableModel):
         except KeyError:
             return None
 
-        if role == qt4.Qt.DisplayRole:
-            if orientation == qt4.Qt.Horizontal:
+        if role == qt.Qt.ItemDataRole.DisplayRole:
+            if orientation == qt.Qt.Orientation.Horizontal:
                 # column names
                 return ds.column_descriptions[section]
             else:
@@ -116,12 +113,12 @@ class DatasetTableModel1D(qt4.QAbstractTableModel):
     def flags(self, index):
         """Update flags to say that items are editable."""
         if index.isValid():
-            f = qt4.QAbstractTableModel.flags(self, index)
+            f = qt.QAbstractTableModel.flags(self, index)
             ds = self.document.data.get(self.dsname)
             if ds is not None and ds.editable:
-                f |= qt4.Qt.ItemIsEditable
+                f |= qt.Qt.ItemFlag.ItemIsEditable
             return f
-        return qt4.Qt.ItemIsEnabled
+        return qt.Qt.ItemFlag.ItemIsEnabled
 
     def removeRows(self, row, count):
         """Remove rows."""
@@ -136,7 +133,7 @@ class DatasetTableModel1D(qt4.QAbstractTableModel):
     def setData(self, index, value, role):
         """Called to set the data."""
 
-        if not index.isValid() or role != qt4.Qt.EditRole:
+        if not index.isValid() or role != qt.Qt.ItemDataRole.EditRole:
             return False
 
         row = index.row()
@@ -148,8 +145,8 @@ class DatasetTableModel1D(qt4.QAbstractTableModel):
         ops = document.OperationMultiple([], descr=_('set value'))
         if data is None:
             ops.addOperation(
-                document.OperationDatasetAddColumn(self.dsname,
-                                                   ds.columns[column]))
+                document.OperationDatasetAddColumn(
+                    self.dsname, ds.columns[column]))
 
         # add a row if necessary
         if row == len(ds.data):
@@ -163,20 +160,19 @@ class DatasetTableModel1D(qt4.QAbstractTableModel):
             return False
 
         ops.addOperation(
-            document.OperationDatasetSetVal(self.dsname,
-                                            ds.columns[column],
-                                            row, val))
+            document.OperationDatasetSetVal(
+                self.dsname, ds.columns[column], row, val))
         try:
             self.document.applyOperation(ops)
         except RuntimeError:
             return False
         return True
 
-class DatasetTableModelMulti(qt4.QAbstractTableModel):
+class DatasetTableModelMulti(qt.QAbstractTableModel):
     """Edit multiple datasets simultaneously with a spreadsheet-like style."""
 
     def __init__(self, parent, document, datasetnames):
-        qt4.QAbstractTableModel.__init__(self, parent)
+        qt.QAbstractTableModel.__init__(self, parent)
 
         self.document = document
         self.dsnames = datasetnames
@@ -243,7 +239,7 @@ class DatasetTableModelMulti(qt4.QAbstractTableModel):
         ds = self.document.data[dsname]
         data = getattr(ds, colname)
 
-        if role == qt4.Qt.DisplayRole:
+        if role == qt.Qt.ItemDataRole.DisplayRole:
             if index.row() < self.rowcounts[dsidx]-1:
                 # convert data to Data
                 d = data[index.row()]
@@ -255,8 +251,8 @@ class DatasetTableModelMulti(qt4.QAbstractTableModel):
     def headerData(self, section, orientation, role):
         """Return row numbers or column names."""
 
-        if role == qt4.Qt.DisplayRole:
-            if orientation == qt4.Qt.Horizontal:
+        if role == qt.Qt.ItemDataRole.DisplayRole:
+            if orientation == qt.Qt.Orientation.Horizontal:
                 # column names
                 dsname, colname, dsidx, colidx = self.colattrs[section]
                 ds = self.document.data[dsname]
@@ -274,18 +270,18 @@ class DatasetTableModelMulti(qt4.QAbstractTableModel):
     def flags(self, index):
         """Update flags to say that items are editable."""
         if index.isValid():
-            f = qt4.QAbstractTableModel.flags(self, index)
+            f = qt.QAbstractTableModel.flags(self, index)
             dsname, colname, dsidx, colidx = self.colattrs[index.column()]
             ds = self.document.data.get(dsname)
             if ds is not None and ds.editable:
-                f |= qt4.Qt.ItemIsEditable
+                f |= qt.Qt.ItemFlag.ItemIsEditable
             return f
-        return qt4.Qt.ItemIsEnabled
+        return qt.Qt.ItemFlag.ItemIsEnabled
 
     def setData(self, index, value, role):
         """Validate and set data in dataset."""
 
-        if not index.isValid() or role != qt4.Qt.EditRole:
+        if not index.isValid() or role != qt.Qt.ItemDataRole.EditRole:
             return False
 
         row = index.row()
@@ -334,11 +330,11 @@ class DatasetTableModelMulti(qt4.QAbstractTableModel):
         self.document.applyOperation(
             document.OperationMultiple(ops, _('delete row(s)')))
 
-class DatasetTableModel2D(qt4.QAbstractTableModel):
+class DatasetTableModel2D(qt.QAbstractTableModel):
     """A 2D dataset model."""
 
     def __init__(self, parent, document, datasetname):
-        qt4.QAbstractTableModel.__init__(self, parent)
+        qt.QAbstractTableModel.__init__(self, parent)
 
         self.document = document
         self.dsname = datasetname
@@ -349,65 +345,85 @@ class DatasetTableModel2D(qt4.QAbstractTableModel):
         """Get coordinates at edge of grid."""
         self.xedge = self.yedge = self.xcent = self.ycent = []
         ds = self.document.data.get(self.dsname)
-        if ds:
+        if ds and ds.dimensions==2:
             self.xcent, self.ycent = ds.getPixelCentres()
             self.xedge, self.yedge = ds.getPixelEdges()
 
     def rowCount(self, parent):
         if parent.isValid():
             return 0
-        ds = self.document.data[self.dsname].data
-        if ds is not None:
-            return ds.shape[0]
+        try:
+            data = self.document.data[self.dsname].data
+        except KeyError:
+            return 0
+        if data is not None and data.ndim==2:
+            return data.shape[0]
         else:
             return 0
 
     def columnCount(self, parent):
         if parent.isValid():
             return 0
-        ds = self.document.data[self.dsname].data
-        if ds is not None:
-            return ds.shape[1]
+        try:
+            data = self.document.data[self.dsname].data
+        except KeyError:
+            return 0
+        if data is not None and data.ndim==2:
+            return data.shape[1]
         else:
             return 0
 
     def data(self, index, role):
-        if role == qt4.Qt.DisplayRole:
+        if role == qt.Qt.ItemDataRole.DisplayRole:
             # get data (note y is reversed, sigh)
-            ds = self.document.data[self.dsname].data
-            if ds is not None:
-                num = ds[ds.shape[0]-index.row()-1, index.column()]
-                return float(num)
+            try:
+                data = self.document.data[self.dsname].data
+            except KeyError:
+                return None
+            if data is not None and data.ndim==2:
+                try:
+                    num = data[data.shape[0]-index.row()-1, index.column()]
+                    return float(num)
+                except IndexError:
+                    pass
 
         return None
 
     def headerData(self, section, orientation, role):
         """Return headers at top."""
 
-        ds = self.document.data[self.dsname]
-        xaxis = orientation == qt4.Qt.Horizontal
+        ds = self.document.data.get(self.dsname)
+        if ds.dimensions != 2:
+            return None
 
-        if ds is not None and role == qt4.Qt.DisplayRole:
-            v = self.xcent[section] if xaxis else self.ycent[section]
-            return '%i (%s)' % (section+1, setting.ui_floattostring(v))
+        xaxis = orientation == qt.Qt.Orientation.Horizontal
 
-        elif ds is not None and role == qt4.Qt.ToolTipRole:
-            v1 = self.xedge[section] if xaxis else self.yedge[section]
-            v2 = self.xedge[section+1] if xaxis else self.yedge[section+1]
-            return u'%s\u2013%s' % (setting.ui_floattostring(v1),
-                                    setting.ui_floattostring(v2))
+        # note: y coordinates are upside down (high y is at top)
+        if ds is not None and role == qt.Qt.ItemDataRole.DisplayRole:
+            v = self.xcent[section] if xaxis else self.ycent[
+                len(self.ycent)-section-1]
+            return '%i (%s)' % (
+                len(self.ycent)-section, setting.ui_floattostring(v, maxdp=4))
+
+        elif ds is not None and role == qt.Qt.ItemDataRole.ToolTipRole:
+            v1 = self.xedge[section] if xaxis else self.yedge[
+                len(self.yedge)-section-2]
+            v2 = self.xedge[section+1] if xaxis else self.yedge[
+                len(self.yedge)-section-1]
+            return '%s\u2013%s' % (
+                setting.ui_floattostring(v1), setting.ui_floattostring(v2))
 
         return None
 
     def flags(self, index):
         """Update flags to say that items are editable."""
         if not index.isValid():
-            return qt4.Qt.ItemIsEnabled
+            return qt.Qt.ItemFlag.ItemIsEnabled
         else:
-            f = qt4.QAbstractTableModel.flags(self, index)
+            f = qt.QAbstractTableModel.flags(self, index)
             ds = self.document.data.get(self.dsname)
             if ds is not None and ds.editable:
-                f |= qt4.Qt.ItemIsEditable
+                f |= qt.Qt.ItemFlag.ItemIsEditable
             return f
 
     def slotDocumentModified(self):
@@ -418,7 +434,7 @@ class DatasetTableModel2D(qt4.QAbstractTableModel):
     def setData(self, index, value, role):
         """Called to set the data."""
 
-        if not index.isValid() or role != qt4.Qt.EditRole:
+        if not index.isValid() or role != qt.Qt.ItemDataRole.EditRole:
             return False
 
         ds = self.document.data[self.dsname]
@@ -436,16 +452,79 @@ class DatasetTableModel2D(qt4.QAbstractTableModel):
         self.document.applyOperation(op)
         return True
 
-class ViewDelegate(qt4.QStyledItemDelegate):
+class DatasetTableModelND(qt.QAbstractTableModel):
+    """An ND dataset model."""
+
+    def __init__(self, parent, document, datasetname):
+        qt.QAbstractTableModel.__init__(self, parent)
+
+        self.document = document
+        self.dsname = datasetname
+        document.signalModified.connect(self.slotDocumentModified)
+
+    def rowCount(self, parent):
+        if parent.isValid():
+            return 0
+        try:
+            data = self.document.data[self.dsname].data
+        except KeyError:
+            return 0
+        return 0 if data is None else data.size
+
+    def columnCount(self, parent):
+        if parent.isValid():
+            return 0
+        try:
+            data = self.document.data[self.dsname].data
+        except KeyError:
+            return 0
+        return 1 if data is not None else 0
+
+    def data(self, index, role):
+        """Items in array."""
+        if role == qt.Qt.ItemDataRole.DisplayRole:
+            try:
+                data = self.document.data[self.dsname].data
+            except KeyError:
+                return None
+            if data is not None:
+                try:
+                    num = N.ravel(data)[index.row()]
+                    return float(num)
+                except IndexError:
+                    pass
+        return None
+
+    def headerData(self, section, orientation, role):
+        """Return headers at top."""
+
+        ds = self.document.data.get(self.dsname)
+        if ds is None:
+            return None
+
+        if ds is not None and role == qt.Qt.ItemDataRole.DisplayRole:
+            if orientation == qt.Qt.Orientation.Horizontal:
+                return _('Value')
+            else:
+                idx = N.unravel_index(section, ds.data.shape)
+                txt = ','.join( [str(v+1) for v in idx] )
+                return txt
+        return None
+
+    def slotDocumentModified(self):
+        """Called when document modified."""
+        self.layoutChanged.emit()
+
+class ViewDelegate(qt.QStyledItemDelegate):
     """Delegate for fixing double editing.
     Normal editing uses double spin box, which is inappropriate
     """
 
     def createEditor(self, parent, option, index):
         if type(index.data()) is float:
-            return qt4.QLineEdit(parent)
+            return qt.QLineEdit(parent)
         else:
-            return qt4.QStyledItemDelegate.createEditor(
+            return qt.QStyledItemDelegate.createEditor(
                 self, parent, option, index)
 
     def setEditorData(self, editor, index):
@@ -454,11 +533,11 @@ class ViewDelegate(qt4.QStyledItemDelegate):
             txt = setting.ui_floattostring(index.data())
             editor.setText(txt)
         else:
-            qt4.QStyledItemDelegate.setEditorData(self, editor, index)
+            qt.QStyledItemDelegate.setEditorData(self, editor, index)
 
 class DataEditDialog(VeuszDialog):
     """Dialog for editing and rearranging data sets."""
-    
+
     def __init__(self, parent, document):
         VeuszDialog.__init__(self, parent, 'dataedit.ui')
         self.document = document
@@ -477,19 +556,19 @@ class DataEditDialog(VeuszDialog):
             (_('Copy'), self.slotCopy),
             (_('Delete row'), self.slotDeleteRow),
             (_('Insert row'), self.slotInsertRow),
-            ):
-            act = qt4.QAction(text, self)
+        ):
+            act = qt.QAction(text, self)
             act.triggered.connect(slot)
             self.datatableview.addAction(act)
-        self.datatableview.setContextMenuPolicy( qt4.Qt.ActionsContextMenu )
+        self.datatableview.setContextMenuPolicy( qt.Qt.ContextMenuPolicy.ActionsContextMenu )
 
         # layout edit dialog improvement
         self.splitter.setStretchFactor(0, 3)
         self.splitter.setStretchFactor(1, 4)
 
         # don't want text to look editable or special
-        self.linkedlabel.setFrameShape(qt4.QFrame.NoFrame)
-        self.linkedlabel.viewport().setBackgroundRole(qt4.QPalette.Window)
+        self.linkedlabel.setFrameShape(qt.QFrame.Shape.NoFrame)
+        self.linkedlabel.viewport().setBackgroundRole(qt.QPalette.ColorRole.Window)
 
         # document changes
         document.signalModified.connect(self.slotDocumentModified)
@@ -504,20 +583,23 @@ class DataEditDialog(VeuszDialog):
             self.slotDatasetsSelected)
 
         # connect buttons
-        for btn, slot in ( (self.deletebutton, self.slotDatasetDelete),
-                           (self.unlinkbutton, self.slotDatasetUnlink),
-                           (self.duplicatebutton, self.slotDatasetDuplicate),
-                           (self.importbutton, self.slotDatasetImport),
-                           (self.createbutton, self.slotDatasetCreate),
-                           (self.editbutton, self.slotDatasetEdit),
-                           ):
+        for btn, slot in (
+                (self.deletebutton, self.slotDatasetDelete),
+                (self.unlinkbutton, self.slotDatasetUnlink),
+                (self.duplicatebutton, self.slotDatasetDuplicate),
+                (self.importbutton, self.slotDatasetImport),
+                (self.createbutton, self.slotDatasetCreate),
+                (self.editbutton, self.slotDatasetEdit),
+        ):
             btn.clicked.connect(slot)
 
         # menu for new button
-        self.newmenu = qt4.QMenu()
-        for text, slot in ( (_('Numerical dataset'), self.slotNewNumericalDataset),
-                            (_('Text dataset'), self.slotNewTextDataset),
-                            (_('Date/time dataset'), self.slotNewDateDataset) ):
+        self.newmenu = qt.QMenu()
+        for text, slot in (
+                (_('Numerical dataset'), self.slotNewNumericalDataset),
+                (_('Text dataset'), self.slotNewTextDataset),
+                (_('Date/time dataset'), self.slotNewDateDataset)
+        ):
             a = self.newmenu.addAction(text)
             a.triggered.connect(slot)
         self.newbutton.setMenu(self.newmenu)
@@ -536,6 +618,8 @@ class DataEditDialog(VeuszDialog):
                 model = DatasetTableModel1D(self, self.document, names[0])
             elif ds.dimensions == 2:
                 model = DatasetTableModel2D(self, self.document, names[0])
+            elif ds.dimensions == -1:
+                model = DatasetTableModelND(self, self.document, names[0])
         elif len(names) > 1:
             model = DatasetTableModelMulti(self, self.document, names)
 
@@ -543,7 +627,7 @@ class DataEditDialog(VeuszDialog):
         for a in self.datatableview.actions():
             a.setEnabled(model is not None)
 
-        self.datatableview.setModel(model)    
+        self.datatableview.setModel(model)
         self.setUnlinkState()
 
     def setUnlinkState(self):
@@ -626,8 +710,8 @@ class DataEditDialog(VeuszDialog):
         for name in self.dsbrowser.navtree.getSelectedDatasets():
             dataset = self.document.data[name]
             try:
-                recreate_register[type(dataset)](self.mainwindow, self.document,
-                                                 dataset, name)
+                recreate_register[type(dataset)](
+                    self.mainwindow, self.document, dataset, name)
             except KeyError:
                 pass
 
@@ -653,14 +737,14 @@ class DataEditDialog(VeuszDialog):
                     rowitems = []
                 lastrow = row
             rowitems.append(
-                cstr(model.createIndex(row, column).data()) )
+                str(model.createIndex(row, column).data()) )
         if rowitems:
             lines.append( '\t'.join(rowitems) )
         lines.append('')  # blank line at end
         lines = '\n'.join(lines)
 
         # put text on clipboard
-        qt4.QApplication.clipboard().setText(lines)
+        qt.QApplication.clipboard().setText(lines)
 
     def slotDeleteRow(self):
         """Delete the current row."""
@@ -674,15 +758,15 @@ class DataEditDialog(VeuszDialog):
 
     def slotNewNumericalDataset(self):
         """Add new value dataset."""
-        self.newDataset( document.Dataset(data=[0.]) )
+        self.newDataset( datasets.Dataset(data=[0.]) )
 
     def slotNewTextDataset(self):
         """Add new text dataset."""
-        self.newDataset( document.DatasetText(data=['']) )
+        self.newDataset( datasets.DatasetText(data=['']) )
 
     def slotNewDateDataset(self):
         """Add new date dataset."""
-        self.newDataset( document.DatasetDateTime(data=[]) )
+        self.newDataset( datasets.DatasetDateTime(data=[]) )
 
     def newDataset(self, ds):
         """Add new dataset to document."""
