@@ -32,7 +32,7 @@ def _(text, disambiguation=None, context='ExportDialog'):
 # formats which can have multiple pages
 multipageformats = set(('ps', 'pdf'))
 
-bitmapformats = set(('png', 'bmp', 'jpg', 'tiff', 'xpm'))
+bitmapformats = set(('png', 'bmp', 'jpg', 'tiff', 'xpm', 'webp'))
 
 # map formats to names of radio buttons
 formatradio = (
@@ -46,6 +46,7 @@ formatradio = (
     ('jpg', 'radioFormatJPG'),
     ('tiff', 'radioFormatTIFF'),
     ('xpm', 'radioFormatXPM'),
+    ('webp', 'radioFormatWebP'),
 )
 
 class ExportDialog(VeuszDialog):
@@ -120,7 +121,7 @@ class ExportDialog(VeuszDialog):
         self.exportQuality.setValue(setdb['export_quality'])
 
         # validate and set DPIs
-        dpis = ('72', '75', '90', '96', '100', '150', '200', '300')
+        dpis = ('72', '75', '90', '96', '100', '150', '200', '300', '600')
         for cntrl in self.exportDPI, self.exportDPISVG, self.exportDPIPDF:
             cntrl.addItems(dpis)
             cntrl.setValidator(qt.QIntValidator(10, 10000, self))
@@ -173,7 +174,7 @@ class ExportDialog(VeuszDialog):
             c.setVisible(fmt in ('pdf', 'ps', 'eps'))
 
         for c in (self.exportQuality, self.labelQuality):
-            c.setVisible(fmt == 'jpg')
+            c.setVisible(fmt == 'jpg' or fmt == 'webp')
 
         for c in (self.exportSVGTextAsText, self.labelSVGTextAsText,
                   self.exportDPISVG, self.labelDPISVG):
