@@ -18,13 +18,12 @@
 
 """Dialog boxes for tools and dataset plugins."""
 
-from __future__ import division
 import sys
 
-from ..compat import czip, cstr
 from .. import qtall as qt
 from .. import document
 from .. import plugins
+from .. import utils
 from . import exceptiondialog
 from .veuszdialog import VeuszDialog
 
@@ -65,12 +64,12 @@ class PluginDialog(VeuszDialog):
     def __init__(self, mainwindow, doc, plugininst, pluginkls):
         VeuszDialog.__init__(self, mainwindow, 'plugin.ui')
 
-        reset = self.buttonBox.button(qt.QDialogButtonBox.Reset)
+        reset = self.buttonBox.button(qt.QDialogButtonBox.StandardButton.Reset)
         reset.setAutoDefault(False)
         reset.setDefault(False)
         reset.clicked.connect( self.slotReset)
         self.buttonBox.button(
-            qt.QDialogButtonBox.Apply).clicked.connect(self.slotApply)
+            qt.QDialogButtonBox.StandardButton.Apply).clicked.connect(self.slotApply)
 
         self.pluginkls = pluginkls
         self.plugininst = plugininst
@@ -123,7 +122,7 @@ class PluginDialog(VeuszDialog):
         """Open up dataset in dialog for editing."""
 
         oldfields = ds.pluginmanager.fields
-        for field, cntrl in czip(self.fields, self.fieldcntrls):
+        for field, cntrl in zip(self.fields, self.fieldcntrls):
             field.setControlVal(cntrl, oldfields[field.name])
 
     def slotApply(self):
@@ -132,10 +131,12 @@ class PluginDialog(VeuszDialog):
         # default field
         fields = {'currentwidget': '/'}
         if self.mainwindow.treeedit.selwidgets:
-            fields = {'currentwidget': self.mainwindow.treeedit.selwidgets[0].path}
+            fields = {
+                'currentwidget': self.mainwindow.treeedit.selwidgets[0].path
+            }
 
         # read values from controls
-        for field, cntrls in czip(self.fields, self.fieldcntrls):
+        for field, cntrls in zip(self.fields, self.fieldcntrls):
             fields[field.name] = field.getControlResults(cntrls)
 
         # run plugin
@@ -159,43 +160,39 @@ def runPlugin(window, doc, plugin, fields):
     else:
         raise RuntimeError("Invalid plugin class")
 
-    # use correct operation class for different plugin types
-    if mode == 'tools':
-        op = document.OperationToolsPlugin(plugin, fields)
-    elif mode == 'dataset':
-        # a bit of a hack as we don't give currentwidget to this plugin
-        del fields['currentwidget']
-        op = document.OperationDatasetPlugin(plugin, fields)
-
     resultstext = ''
-    qt.QApplication.setOverrideCursor( qt.QCursor(qt.Qt.WaitCursor) )
     try:
-        results = doc.applyOperation(op)
+        with utils.OverrideCursor():
+            # use correct operation class for different plugin types
+            if mode == 'tools':
+                op = document.OperationToolsPlugin(plugin, fields)
+            elif mode == 'dataset':
+                # a bit of a hack as we don't give currentwidget to this plugin
+                del fields['currentwidget']
+                op = document.OperationDatasetPlugin(
+                    plugin, fields, raiseerrors=True)
 
-        # evaluate datasets using plugin to check it works
-        if mode == 'dataset':
-            op.validate()
-            resultstext = _('Created datasets: ') + ', '.join(results)
-        else:
-            resultstext = _('Done')
+            results = doc.applyOperation(op)
+
+            # evaluate datasets using plugin to check it works
+            if mode == 'dataset':
+                op.validate()
+                resultstext = _('Created datasets: ') + ', '.join(results)
+            else:
+                resultstext = _('Done')
 
     except (plugins.ToolsPluginException, plugins.DatasetPluginException) as ex:
         # unwind operations
         op.undo(doc)
-        qt.QApplication.restoreOverrideCursor()
 
         qt.QMessageBox.warning(
-            window, _("Error in %s") % plugin.name, cstr(ex))
+            window, _("Error in %s") % plugin.name, str(ex))
 
     except Exception:
         op.undo(doc)
-        qt.QApplication.restoreOverrideCursor()
 
         # show exception dialog
-        exceptiondialog.ExceptionDialog(sys.exc_info(), window).exec_()
-
-    else:
-        qt.QApplication.restoreOverrideCursor()
+        exceptiondialog.ExceptionDialog(sys.exc_info(), window).exec()
 
     return resultstext
 
