@@ -18,11 +18,9 @@
 
 """Store document colors."""
 
-from __future__ import division
 import re
 
 from .. import qtall as qt
-from ..compat import crange
 
 # match name of color
 themecolor_re = re.compile(r'^theme([1-9][0-9]*)$')
@@ -124,7 +122,7 @@ colorthemes = {
         "#83AB58", "#001C1E", "#D1F7CE", "#004B28", "#C8D0F6", "#A3A489", "#806C66", "#222800",
         "#BF5650", "#E83000", "#66796D", "#DA007C", "#FF1A59", "#8ADBB4", "#1E0200", "#5B4E51",
         "#C895C5", "#320033", "#FF6832", "#66E1D3", "#CFCDAC", "#D0AC94", "#7ED379", "#012C58",
-        ],
+    ],
 
 }
 # most up-to-date theme
@@ -157,7 +155,7 @@ class Colors(qt.QObject):
             'darkblue',
             'darkcyan',
             'darkmagenta'
-            ]
+        ]
 
         # model for UI for choosing colors
         self.model = None
@@ -292,14 +290,14 @@ class ColorModel(qt.QAbstractListModel):
         qcolor = self.colors.get(color)
         if color.lower() in ('auto', 'transparent'):
             # make a checkerboard pattern for special colors
-            image = qt.QImage(xw, yw, qt.QImage.Format_RGB32)
+            image = qt.QImage(xw, yw, qt.QImage.Format.Format_RGB32)
             if color.lower() == 'auto':
                 cnames = ['orange', 'skyblue', 'green']
             else:
                 cnames = ['lightgrey', 'darkgrey']
             cols = [qt.QColor(c).rgba() for c in cnames]
-            for x in crange(xw):
-                for y in crange(yw):
+            for x in range(xw):
+                for y in range(yw):
                     idx = (x//4 + y//4) % len(cols)
                     image.setPixel(x, y, cols[idx])
             pixmap = qt.QPixmap.fromImage(image)
@@ -316,9 +314,9 @@ class ColorModel(qt.QAbstractListModel):
             return None
 
         color = self.colorlist[index.row()]
-        if role == qt.Qt.DisplayRole or role == qt.Qt.EditRole:
+        if role == qt.Qt.ItemDataRole.DisplayRole or role == qt.Qt.ItemDataRole.EditRole:
             return color
-        elif role == qt.Qt.DecorationRole:
+        elif role == qt.Qt.ItemDataRole.DecorationRole:
             # icons are cached using rgba as index
             rgba = self.colors.get(color).rgba()
             if rgba not in self.iconcache:
@@ -329,12 +327,12 @@ class ColorModel(qt.QAbstractListModel):
 
     def flags(self, index):
         if not index.isValid():
-            return qt.Qt.ItemIsEnabled
+            return qt.Qt.ItemFlag.ItemIsEnabled
         return (
-            qt.QAbstractListModel.flags(self, index) | qt.Qt.ItemIsEditable)
+            qt.QAbstractListModel.flags(self, index) | qt.Qt.ItemFlag.ItemIsEditable)
 
     def setData(self, index, value, role):
-        if role == qt.Qt.EditRole or role == qt.Qt.DisplayRole:
+        if role == qt.Qt.ItemDataRole.EditRole or role == qt.Qt.ItemDataRole.DisplayRole:
             row = index.row()
             if row>=0 and row<len(self.colorlist):
                 self.colorlist[row] = value
