@@ -21,11 +21,11 @@
 
 """A class to represent Veusz documents, with dataset classes."""
 
-from __future__ import division, print_function, absolute_import
 import codecs
 import os.path
 import traceback
 import datetime
+from io import StringIO
 from collections import defaultdict
 
 try:
@@ -33,7 +33,6 @@ try:
 except ImportError:
     h5py = None
 
-from ..compat import citems, cvalues, cstr, CStringIO, cexecfile
 from .. import qtall as qt
 
 from . import widgetfactory
@@ -59,7 +58,7 @@ def getSuitableParent(widgettype, initialwidget):
         parent = parent.parent
     return parent
 
-class DocSuspend(object):
+class DocSuspend:
     """Handle document updates/suspensions."""
     def __init__(self, doc):
         self.doc = doc
@@ -69,6 +68,9 @@ class DocSuspend(object):
     def __exit__(self, type, value, traceback):
         self.doc.enableUpdates()
 
+class PluginLoadError(RuntimeError):
+    pass
+
 class Document(qt.QObject):
     """Document class for holding the graph data.
     """
@@ -78,7 +80,7 @@ class Document(qt.QObject):
     # this is emitted when the document is modified
     signalModified = qt.pyqtSignal(int)
     # emited to log a message
-    sigLog = qt.pyqtSignal(cstr)
+    sigLog = qt.pyqtSignal(str)
     # emitted when document wiped
     sigWiped = qt.pyqtSignal()
     # to ask whether an import is allowed
@@ -86,16 +88,20 @@ class Document(qt.QObject):
     # security value set
     sigSecuritySet = qt.pyqtSignal(bool)
 
+    # compatibility level
+    maxcompatlevel = 1
+
     def __init__(self):
         """Initialise the document."""
         qt.QObject.__init__( self )
 
+        # load plugins if not already loaded
         if not Document.pluginsloaded:
             Document.loadPlugins()
-            Document.pluginsloaded = True
 
         # change tracking of document as a whole
         self.changeset = 0            # increased when the document changes
+        self.compatlevel = 0          # for non-backward compatible changes
 
         # map tags to dataset names
         self.datasettags = defaultdict(list)
@@ -116,8 +122,10 @@ class Document(qt.QObject):
     def wipe(self):
         """Wipe out any stored data."""
         self.data = {}
+
         self.basewidget = widgetfactory.thefactory.makeWidget(
             'document', None, self)
+
         self.setModified(False)
         self.filename = ""
         self.evaluate.wipe()
@@ -147,11 +155,25 @@ class Document(qt.QObject):
         """Return context manager for suspending updates."""
         return DocSuspend(self)
 
-    def makeDefaultDoc(self, mode='graph'):
+    def setCompatLevel(self, level):
+        """Update the compatiblity level.
+
+        If level<0, then use latest version
+        """
+        if level < 0:
+            level = self.maxcompatlevel
+        elif level > self.maxcompatlevel:
+            raise ValueError(
+                "Compatibility level greater than supported by this Veusz version")
+        self.compatlevel = level
+        self.basewidget.makeStylesheet(compatlevel=self.compatlevel)
+
+    def makeDefaultDoc(self, mode='graph', compatlevel=-1):
         """Add default widgets to create document.
 
         mode == 'graph', 'polar', 'ternary' or 'graph3d'
         """
+        self.setCompatLevel(compatlevel)
         page = widgetfactory.thefactory.makeWidget(
             'page', self.basewidget, self)
 
@@ -261,9 +283,10 @@ class Document(qt.QObject):
         if filenames is a set, only get the objects with filenames given
         """
         links = set()
-        for ds in cvalues(self.data):
-            if ds.linked and (filenames is None or
-                              ds.linked.filename in filenames):
+        for ds in self.data.values():
+            if ds.linked and (
+                    filenames is None or
+                    ds.linked.filename in filenames):
                 links.add(ds.linked)
         return list(links)
 
@@ -295,7 +318,7 @@ class Document(qt.QObject):
 
     def datasetName(self, dataset):
         """Find name for given dataset, raising ValueError if missing."""
-        for name, ds in citems(self.data):
+        for name, ds in self.data.items():
             if ds is dataset:
                 return name
         raise ValueError("Cannot find dataset")
@@ -332,16 +355,21 @@ class Document(qt.QObject):
     @classmethod
     def loadPlugins(kls, pluginlist=None):
         """Load plugins and catch exceptions."""
+
+        # set early, so we don't repeatedly load faulty plugins
+        kls.pluginsloaded = True
+
         if pluginlist is None:
             pluginlist = setting.settingdb.get('plugins', [])
 
         for plugin in pluginlist:
             try:
-                cexecfile(plugin, {})
+                with open(plugin) as f:
+                    exec(f.read(), {})
             except Exception:
                 err = _('Error loading plugin %s\n\n%s') % (
                     plugin, traceback.format_exc())
-                raise RuntimeError(err)
+                raise PluginLoadError(err)
 
     def paintTo(self, painthelper, page):
         """Paint page specified to the paint helper."""
@@ -365,7 +393,7 @@ class Document(qt.QObject):
     def datasetTags(self):
         """Get list of all tags in datasets."""
         tags = set()
-        for dataset in cvalues(self.data):
+        for dataset in self.data.values():
             tags.update(dataset.tags)
         return sorted(tags)
 
@@ -373,8 +401,9 @@ class Document(qt.QObject):
         """Write a header to a saved file of type."""
 
         fileobj.write('# Veusz %s (version %s)\n' % (type, utils.version()))
-        fileobj.write('# Saved at %s\n\n' %
-                      datetime.datetime.utcnow().isoformat())
+        fileobj.write(
+            '# Saved at %s\n\n' %
+            datetime.datetime.utcnow().isoformat())
 
     def saveDatasetTags(self, fileobj):
         """Write dataset tags to output file"""
@@ -404,6 +433,9 @@ class Document(qt.QObject):
 
         self._writeFileHeader(fileobj, 'saved document')
 
+        # write compatibility level
+        fileobj.write('SetCompatLevel(%s)\n' % self.compatlevel)
+
         # add file directory to import path if we know it
         reldirname = None
         if getattr(fileobj, 'name', False):
@@ -444,7 +476,7 @@ class Document(qt.QObject):
         datagrp = vszgrp.create_group('Data')
         docgrp = vszgrp.create_group('Document')
 
-        textstream = CStringIO()
+        textstream = StringIO()
 
         self._writeFileHeader(textstream, 'saved document')
 
@@ -461,8 +493,8 @@ class Document(qt.QObject):
         # we do this first in case the datasets are overridden below
         savedlinks = {}
         for name, dataset in sorted(self.data.items()):
-            dataset.saveLinksToSavedDoc(textstream, savedlinks,
-                                        relpath=reldirname)
+            dataset.saveLinksToSavedDoc(
+                textstream, savedlinks, relpath=reldirname)
 
         # save the remaining datasets
         for name, dataset in sorted(self.data.items()):
@@ -641,16 +673,19 @@ class Document(qt.QObject):
 
             # do the widget's children
             for w in root.children:
-                self.walkNodes(tocall, root=w, nodetypes=nodetypes,
-                               _path = _path + '/' + w.name)
+                self.walkNodes(
+                    tocall, root=w, nodetypes=nodetypes,
+                    _path=_path+'/'+w.name)
             # then do the widget's settings
-            self.walkNodes(tocall, root=root.settings,
-                           nodetypes=nodetypes, _path=_path)
+            self.walkNodes(
+                tocall, root=root.settings,
+                nodetypes=nodetypes, _path=_path)
         elif root.nodetype == 'settings':
             # do the settings of the settings
             for name, s in sorted(root.setdict.items()):
-                self.walkNodes(tocall, root=s, nodetypes=nodetypes,
-                               _path = _path + '/' + s.name)
+                self.walkNodes(
+                    tocall, root=s, nodetypes=nodetypes,
+                    _path=_path+'/'+s.name)
         # elif root.nodetype == 'setting': pass
 
     def formatValsWithDatatypeToText(self, vals, displaydatatype):
@@ -660,8 +695,9 @@ class Document(qt.QObject):
         if displaydatatype == 'text':
             return vals
         elif displaydatatype == 'numeric':
-            return [ utils.formatNumber(val, '%Vg', locale=self.locale)
-                     for val in vals ]
+            return [
+                utils.formatNumber(val, '%Vg', locale=self.locale)
+                for val in vals ]
         elif displaydatatype == 'date':
             return [ utils.dateFloatToString(val) for val in vals ]
         else:
