@@ -19,10 +19,8 @@
 """A home-brewed SVG paint engine for doing svg with clipping
 and exporting text as paths for WYSIWYG."""
 
-from __future__ import division, print_function
 import re
 
-from ..compat import crange, cbytes
 from .. import qtall as qt
 
 # physical sizes
@@ -32,7 +30,7 @@ inch_pt = 72.0
 def printpath(path):
     """Debugging print path."""
     print("Contents of", path)
-    for i in crange(path.elementCount()):
+    for i in range(path.elementCount()):
         el = path.elementAt(i)
         print(" ", el.type, el.x, el.y)
 
@@ -55,12 +53,12 @@ def fltStr(v, prec=2):
 def escapeXML(text):
     """Escape special characters in XML."""
     # we have swap & with an unused character, so we can replace it later
-    text = text.replace('&', u'\ue001')
+    text = text.replace('&', '\ue001')
     text = text.replace('<', '&lt;')
     text = text.replace('>', '&gt;')
     text = text.replace('"', '&quot;')
     text = text.replace("'", '&apos;')
-    text = text.replace(u'\ue001', '&amp;')
+    text = text.replace('\ue001', '&amp;')
     return text
 
 def createPath(path, scale):
@@ -76,19 +74,21 @@ def createPath(path, scale):
     while i < count:
         e = path.elementAt(i)
         nx, ny = e.x*scale, e.y*scale
-        if e.type == qt.QPainterPath.MoveToElement:
+        if e.type == qt.QPainterPath.ElementType.MoveToElement:
             p.append( 'm%s,%s' % (fltStr(nx-ox), fltStr(ny-oy)) )
             ox, oy = nx, ny
-        elif e.type == qt.QPainterPath.LineToElement:
+        elif e.type == qt.QPainterPath.ElementType.LineToElement:
             p.append( 'l%s,%s' % (fltStr(nx-ox), fltStr(ny-oy)) )
             ox, oy = nx, ny
-        elif e.type == qt.QPainterPath.CurveToElement:
+        elif e.type == qt.QPainterPath.ElementType.CurveToElement:
             e1 = path.elementAt(i+1)
             e2 = path.elementAt(i+2)
-            p.append( 'c%s,%s,%s,%s,%s,%s' % (
+            p.append(
+                'c%s,%s,%s,%s,%s,%s' % (
                     fltStr(nx-ox), fltStr(ny-oy),
                     fltStr(e1.x*scale-ox), fltStr(e1.y*scale-oy),
-                    fltStr(e2.x*scale-ox), fltStr(e2.y*scale-oy)) )
+                    fltStr(e2.x*scale-ox), fltStr(e2.y*scale-oy))
+            )
             ox, oy = e2.x*scale, e2.y*scale
             i += 2
         else:
@@ -97,7 +97,7 @@ def createPath(path, scale):
         i += 1
     return ''.join(p)
 
-class SVGElement(object):
+class SVGElement:
     """SVG element in output.
     This represents the XML tree in memory
     """
@@ -141,12 +141,12 @@ class SVGPaintEngine(qt.QPaintEngine):
     def __init__(self, writetextastext=False):
         qt.QPaintEngine.__init__(
             self,
-            qt.QPaintEngine.Antialiasing |
-            qt.QPaintEngine.PainterPaths |
-            qt.QPaintEngine.PrimitiveTransform |
-            qt.QPaintEngine.PaintOutsidePaintEvent |
-            qt.QPaintEngine.PixmapTransform |
-            qt.QPaintEngine.AlphaBlend
+            qt.QPaintEngine.PaintEngineFeature.Antialiasing |
+            qt.QPaintEngine.PaintEngineFeature.PainterPaths |
+            qt.QPaintEngine.PaintEngineFeature.PrimitiveTransform |
+            qt.QPaintEngine.PaintEngineFeature.PaintOutsidePaintEvent |
+            qt.QPaintEngine.PaintEngineFeature.PixmapTransform |
+            qt.QPaintEngine.PaintEngineFeature.AlphaBlend
         )
 
         self.imageformat = 'png'
@@ -167,11 +167,13 @@ class SVGPaintEngine(qt.QPaintEngine):
         # svg root element for qt defaults
         self.rootelement = SVGElement(
             None, 'svg',
-            ('width="%spx" height="%spx" version="1.1"\n'
-             '    xmlns="http://www.w3.org/2000/svg"\n'
-             '    xmlns:xlink="http://www.w3.org/1999/xlink"') % (
-                 fltStr(self.device.width*self.device.sdpi*self.scale),
-                 fltStr(self.device.height*self.device.sdpi*self.scale))
+            (
+                'width="%spx" height="%spx" version="1.1"\n'
+                '    xmlns="http://www.w3.org/2000/svg"\n'
+                '    xmlns:xlink="http://www.w3.org/1999/xlink"') % (
+                    fltStr(self.device.width*self.device.sdpi*self.scale),
+                    fltStr(self.device.height*self.device.sdpi*self.scale),
+                )
         )
         SVGElement(self.rootelement, 'desc', '', 'Veusz output document')
 
@@ -226,9 +228,11 @@ class SVGPaintEngine(qt.QPaintEngine):
         self.pruneEmptyGroups()
 
         fileobj = self.device.fileobj
-        fileobj.write('<?xml version="1.0" standalone="no"?>\n'
-                      '<!DOCTYPE svg PUBLIC "-//W3C//DTD SVG 1.1//EN"\n'
-                      '  "http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd">\n')
+        fileobj.write(
+            '<?xml version="1.0" standalone="no"?>\n'
+            '<!DOCTYPE svg PUBLIC "-//W3C//DTD SVG 1.1//EN"\n'
+            '  "http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd">\n'
+        )
 
         # write all the elements
         self.rootelement.write(fileobj)
@@ -240,14 +244,12 @@ class SVGPaintEngine(qt.QPaintEngine):
 
         clippath = self.transform.map(clippath)
 
-        if clipoperation == qt.Qt.NoClip:
+        if clipoperation == qt.Qt.ClipOperation.NoClip:
             self.clippath = None
-        elif clipoperation == qt.Qt.ReplaceClip:
+        elif clipoperation == qt.Qt.ClipOperation.ReplaceClip:
             self.clippath = clippath
-        elif clipoperation == qt.Qt.IntersectClip:
+        elif clipoperation == qt.Qt.ClipOperation.IntersectClip:
             self.clippath = self.clippath.intersected(clippath)
-        elif clipoperation == qt.Qt.UniteClip:
-            self.clippath = self.clippath.united(clippath)
         else:
             assert False
 
@@ -257,19 +259,19 @@ class SVGPaintEngine(qt.QPaintEngine):
 
         # state is a list of transform, stroke/fill and clip states
         statevec = list(self.oldstate)
-        if ss & qt.QPaintEngine.DirtyTransform:
+        if ss & qt.QPaintEngine.DirtyFlag.DirtyTransform:
             self.transform = state.transform()
             statevec[0] = self.transformState()
-        if ss & qt.QPaintEngine.DirtyPen:
+        if ss & qt.QPaintEngine.DirtyFlag.DirtyPen:
             self.pen = state.pen()
             statevec[1] = self.strokeFillState()
-        if ss & qt.QPaintEngine.DirtyBrush:
+        if ss & qt.QPaintEngine.DirtyFlag.DirtyBrush:
             self.brush = state.brush()
             statevec[1] = self.strokeFillState()
-        if ss & qt.QPaintEngine.DirtyClipPath:
+        if ss & qt.QPaintEngine.DirtyFlag.DirtyClipPath:
             self._updateClipPath(state.clipPath(), state.clipOperation())
             statevec[2] = self.clipState()
-        if ss & qt.QPaintEngine.DirtyClipRegion:
+        if ss & qt.QPaintEngine.DirtyFlag.DirtyClipRegion:
             path = qt.QPainterPath()
             path.addRegion(state.clipRegion())
             self._updateClipPath(path, state.clipOperation())
@@ -277,18 +279,18 @@ class SVGPaintEngine(qt.QPaintEngine):
 
         # work out which state differs first
         pop = 0
-        for i in crange(2, -1, -1):
+        for i in range(2, -1, -1):
             if statevec[i] != self.oldstate[i]:
                 pop = i+1
                 break
 
         # go back up the tree the required number of times
-        for i in crange(pop):
+        for i in range(pop):
             if self.oldstate[i]:
                 self.celement = self.celement.parent
 
         # create new elements for changed states
-        for i in crange(pop-1, -1, -1):
+        for i in range(pop-1, -1, -1):
             if statevec[i]:
                 self.celement = SVGElement(
                     self.celement, 'g', ' '.join(statevec[i]))
@@ -306,8 +308,8 @@ class SVGPaintEngine(qt.QPaintEngine):
         if path in self.existingclips:
             url = 'url(#c%i)' % self.existingclips[path]
         else:
-            clippath = SVGElement(self.defs, 'clipPath',
-                                  'id="c%i"' % self.clipnum)
+            clippath = SVGElement(
+                self.defs, 'clipPath', 'id="c%i"' % self.clipnum)
             SVGElement(clippath, 'path', 'd="%s"' % path)
             url = 'url(#c%i)' % self.clipnum
             self.existingclips[path] = self.clipnum
@@ -328,20 +330,20 @@ class SVGPaintEngine(qt.QPaintEngine):
         if p.color().alphaF() != 1.:
             vals['stroke-opacity'] = '%.3g' % p.color().alphaF()
         # - join style
-        if p.joinStyle() != qt.Qt.BevelJoin:
+        if p.joinStyle() != qt.Qt.PenJoinStyle.BevelJoin:
             vals['stroke-linejoin'] = {
-                qt.Qt.MiterJoin: 'miter',
-                qt.Qt.SvgMiterJoin: 'miter',
-                qt.Qt.RoundJoin: 'round',
-                qt.Qt.BevelJoin: 'bevel'
-                }[p.joinStyle()]
+                qt.Qt.PenJoinStyle.MiterJoin: 'miter',
+                qt.Qt.PenJoinStyle.SvgMiterJoin: 'miter',
+                qt.Qt.PenJoinStyle.RoundJoin: 'round',
+                qt.Qt.PenJoinStyle.BevelJoin: 'bevel'
+            }[p.joinStyle()]
         # - cap style
-        if p.capStyle() != qt.Qt.SquareCap:
+        if p.capStyle() != qt.Qt.PenCapStyle.SquareCap:
             vals['stroke-linecap'] = {
-                qt.Qt.FlatCap: 'butt',
-                qt.Qt.SquareCap: 'square',
-                qt.Qt.RoundCap: 'round'
-                }[p.capStyle()]
+                qt.Qt.PenCapStyle.FlatCap: 'butt',
+                qt.Qt.PenCapStyle.SquareCap: 'square',
+                qt.Qt.PenCapStyle.RoundCap: 'round'
+            }[p.capStyle()]
         # - width
         w = p.widthF()
         # width 0 is device width for qt
@@ -350,16 +352,16 @@ class SVGPaintEngine(qt.QPaintEngine):
         vals['stroke-width'] = fltStr(w*self.scale)
 
         # - line style
-        if p.style() == qt.Qt.NoPen:
+        if p.style() == qt.Qt.PenStyle.NoPen:
             vals['stroke'] = 'none'
-        elif p.style() not in (qt.Qt.SolidLine, qt.Qt.NoPen):
+        elif p.style() not in (qt.Qt.PenStyle.SolidLine, qt.Qt.PenStyle.NoPen):
             # convert from pen width fractions to pts
             nums = [fltStr(self.scale*w*x) for x in p.dashPattern()]
             vals['stroke-dasharray'] = ','.join(nums)
 
         # BRUSH STYLES
         b = self.brush
-        if b.style() == qt.Qt.NoBrush:
+        if b.style() == qt.Qt.BrushStyle.NoBrush:
             vals['fill'] = 'none'
         else:
             vals['fill'] = b.color().name()
@@ -374,13 +376,17 @@ class SVGPaintEngine(qt.QPaintEngine):
             m = self.transform
             dx, dy = m.dx(), m.dy()
             if (m.m11(), m.m12(), m.m21(), m.m22()) == (1., 0., 0., 1):
-                out = ('transform="translate(%s,%s)"' % (
-                        fltStr(dx*self.scale), fltStr(dy*self.scale)) ,)
+                out = (
+                    'transform="translate(%s,%s)"' % (
+                        fltStr(dx*self.scale), fltStr(dy*self.scale)),
+                )
             else:
-                out = ('transform="matrix(%s %s %s %s %s %s)"' % (
+                out = (
+                    'transform="matrix(%s %s %s %s %s %s)"' % (
                         fltStr(m.m11(), 4), fltStr(m.m12(), 4),
                         fltStr(m.m21(), 4), fltStr(m.m22(), 4),
-                        fltStr(dx*self.scale), fltStr(dy*self.scale) ),)
+                        fltStr(dx*self.scale), fltStr(dy*self.scale) ),
+                )
         else:
             out = ()
         return out
@@ -390,7 +396,7 @@ class SVGPaintEngine(qt.QPaintEngine):
         p = createPath(path, self.scale)
 
         attrb = 'd="%s"' % p
-        if path.fillRule() == qt.Qt.WindingFill:
+        if path.fillRule() == qt.Qt.FillRule.WindingFill:
             attrb += ' fill-rule="nonzero"'
 
         if attrb in self.pathcache:
@@ -405,11 +411,13 @@ class SVGPaintEngine(qt.QPaintEngine):
                 element.attrb += ' id="p%i"' % num
 
             # if the parent is a translation, swallow this into the use element
-            m = re.match('transform="translate\(([-0-9.]+),([-0-9.]+)\)"',
-                         self.celement.attrb)
+            m = re.match(
+                r'transform="translate\(([-0-9.]+),([-0-9.]+)\)"',
+                self.celement.attrb)
             if m:
-                SVGElement(self.celement.parent, 'use',
-                           'xlink:href="#p%i" x="%s" y="%s"' % (
+                SVGElement(
+                    self.celement.parent, 'use',
+                    'xlink:href="#p%i" x="%s" y="%s"' % (
                         num, m.group(1), m.group(2)))
             else:
                 SVGElement(self.celement, 'use', 'xlink:href="#p%i"' % num)
@@ -429,14 +437,20 @@ class SVGPaintEngine(qt.QPaintEngine):
             else:
                 size = f.pointSizeF()*self.scale*self.device.sdpi/inch_pt
 
+            # get qfont for item
             font = textitem.font()
+
+            # get font family, removing any optional bracketed foundry name
+            font_family = re.sub(r'\s+\[.*\]', '', font.family())
+
+            # attributes for text item
             grpattrb = [
                 'stroke="none"',
                 'fill="%s"' % self.pen.color().name(),
                 'fill-opacity="%.3g"' % self.pen.color().alphaF(),
-                'font-family="%s"' % escapeXML(font.family()),
+                'font-family="%s"' % escapeXML(font_family),
                 'font-size="%s"' % size,
-                ]
+            ]
             if font.italic():
                 grpattrb.append('font-style="italic"')
             if font.bold():
@@ -452,7 +466,7 @@ class SVGPaintEngine(qt.QPaintEngine):
                 'x="%s"' % fltStr(pt.x()*self.scale),
                 'y="%s"' % fltStr(pt.y()*self.scale),
                 'textLength="%s"' % fltStr(textitem.width()*self.scale),
-                ]
+            ]
 
             # spaces get lost without this
             if text.find('  ') >= 0 or text[:1] == ' ' or text[-1:] == ' ':
@@ -462,7 +476,8 @@ class SVGPaintEngine(qt.QPaintEngine):
             SVGElement(
                 grp, 'text',
                 ' '.join(textattrb),
-                text=text )
+                text=text
+            )
 
         else:
             # convert to a path
@@ -492,32 +507,41 @@ class SVGPaintEngine(qt.QPaintEngine):
         for p in points:
             pts.append( '%s,%s' % (fltStr(p.x()*self.scale), fltStr(p.y()*self.scale)) )
 
-        if mode == qt.QPaintEngine.PolylineMode:
-            SVGElement(self.celement, 'polyline',
-                       'fill="none" points="%s"' % ' '.join(pts))
+        if mode == qt.QPaintEngine.PolygonDrawMode.PolylineMode:
+            SVGElement(
+                self.celement, 'polyline',
+                'fill="none" points="%s"' % ' '.join(pts))
 
         else:
             attrb = 'points="%s"' % ' '.join(pts)
-            if mode == qt.Qt.WindingFill:
+            if mode == qt.Qt.FillRule.WindingFill:
                 attrb += ' fill-rule="nonzero"'
             SVGElement(self.celement, 'polygon', attrb)
 
     def drawEllipse(self, rect):
         """Draw an ellipse to the svg file."""
-        SVGElement(self.celement, 'ellipse',
-                   'cx="%s" cy="%s" rx="%s" ry="%s"' %
-                   (fltStr(rect.center().x()*self.scale),
-                    fltStr(rect.center().y()*self.scale),
-                    fltStr(rect.width()*0.5*self.scale),
-                    fltStr(rect.height()*0.5*self.scale)))
+        SVGElement(
+            self.celement, 'ellipse',
+            'cx="%s" cy="%s" rx="%s" ry="%s"' %
+            (
+                fltStr(rect.center().x()*self.scale),
+                fltStr(rect.center().y()*self.scale),
+                fltStr(rect.width()*0.5*self.scale),
+                fltStr(rect.height()*0.5*self.scale)
+            )
+        )
 
     def drawPoints(self, points):
         """Draw points."""
         for pt in points:
             x, y = fltStr(pt.x()*self.scale), fltStr(pt.y()*self.scale)
-            SVGElement(self.celement, 'line',
-                       ('x1="%s" y1="%s" x2="%s" y2="%s" '
-                        'stroke-linecap="round"') % (x, y, x, y))
+            SVGElement(
+                self.celement, 'line',
+                (
+                    'x1="%s" y1="%s" x2="%s" y2="%s" '
+                    'stroke-linecap="round"'
+                ) % (x, y, x, y)
+            )
 
     def drawImage(self, r, img, sr, flags):
         """Draw image.
@@ -533,21 +557,22 @@ class SVGPaintEngine(qt.QPaintEngine):
         # convert pixmap to textual data
         data = qt.QByteArray()
         buf = qt.QBuffer(data)
-        buf.open(qt.QBuffer.ReadWrite)
+        buf.open(qt.QBuffer.OpenModeFlag.ReadWrite)
         pixmap.save(buf, self.imageformat.upper(), 0)
         buf.close()
 
-        attrb = [ 'x="%s" y="%s" ' % (fltStr(r.x()*self.scale), fltStr(r.y()*self.scale)),
-                  'width="%s" ' % fltStr(r.width()*self.scale),
-                  'height="%s" ' % fltStr(r.height()*self.scale),
-                  'xlink:href="data:image/%s;base64,' % self.imageformat,
-                  cbytes(data.toBase64()).decode('ascii'),
-                  '" preserveAspectRatio="none"' ]
+        attrb = [
+            'x="%s" y="%s" ' % (fltStr(r.x()*self.scale), fltStr(r.y()*self.scale)),
+            'width="%s" ' % fltStr(r.width()*self.scale),
+            'height="%s" ' % fltStr(r.height()*self.scale),
+            'xlink:href="data:image/%s;base64,' % self.imageformat,
+            bytes(data.toBase64()).decode('ascii'),
+            '" preserveAspectRatio="none"'
+        ]
         SVGElement(self.celement, 'image', ''.join(attrb))
 
     def type(self):
-        """A random number for the engine."""
-        return qt.QPaintEngine.User + 11
+        return qt.QPaintEngine.Type.SVG
 
 class SVGPaintDevice(qt.QPaintDevice):
     """Paint device for SVG paint engine.
@@ -572,27 +597,27 @@ class SVGPaintDevice(qt.QPaintDevice):
     def metric(self, m):
         """Return the metrics of the painter."""
 
-        if m == qt.QPaintDevice.PdmWidth:
+        if m == qt.QPaintDevice.PaintDeviceMetric.PdmWidth:
             return int(self.width*self.sdpi)
-        elif m == qt.QPaintDevice.PdmHeight:
+        elif m == qt.QPaintDevice.PaintDeviceMetric.PdmHeight:
             return int(self.height*self.sdpi)
-        elif m == qt.QPaintDevice.PdmWidthMM:
+        elif m == qt.QPaintDevice.PaintDeviceMetric.PdmWidthMM:
             return int(self.engine.width*inch_mm)
-        elif m == qt.QPaintDevice.PdmHeightMM:
+        elif m == qt.QPaintDevice.PaintDeviceMetric.PdmHeightMM:
             return int(self.engine.height*inch_mm)
-        elif m == qt.QPaintDevice.PdmNumColors:
+        elif m == qt.QPaintDevice.PaintDeviceMetric.PdmNumColors:
             return 2147483647
-        elif m == qt.QPaintDevice.PdmDepth:
+        elif m == qt.QPaintDevice.PaintDeviceMetric.PdmDepth:
             return 24
-        elif m == qt.QPaintDevice.PdmDpiX:
+        elif m == qt.QPaintDevice.PaintDeviceMetric.PdmDpiX:
             return int(self.sdpi)
-        elif m == qt.QPaintDevice.PdmDpiY:
+        elif m == qt.QPaintDevice.PaintDeviceMetric.PdmDpiY:
             return int(self.sdpi)
-        elif m == qt.QPaintDevice.PdmPhysicalDpiX:
+        elif m == qt.QPaintDevice.PaintDeviceMetric.PdmPhysicalDpiX:
             return int(self.sdpi)
-        elif m == qt.QPaintDevice.PdmPhysicalDpiY:
+        elif m == qt.QPaintDevice.PaintDeviceMetric.PdmPhysicalDpiY:
             return int(self.sdpi)
-        elif m == qt.QPaintDevice.PdmDevicePixelRatio:
+        elif m == qt.QPaintDevice.PaintDeviceMetric.PdmDevicePixelRatio:
             return 1
 
         # Qt >= 5.6
