@@ -16,23 +16,22 @@
 #    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 ##############################################################################
 
-from __future__ import division
 import sys
 import struct
 import socket
+import pickle
 
-from .compat import citems, pickle
+from . import qtall as qt
 from .windows.simplewindow import SimpleWindow
 from . import document
 from . import setting
-from . import qtall as qt4
 
 """Program to be run by embedding interface to run Veusz commands."""
 
 # embed.py module checks this is the same as its version number
 API_VERSION = 2
 
-class EmbeddedClient(object):
+class EmbeddedClient:
     """An object for each instance of embedded window with document."""
 
     def __init__(self, title, doc=None, hidden=False):
@@ -56,6 +55,7 @@ class EmbeddedClient(object):
         self.ci.addCommand('MoveToPage', self.cmdMoveToPage)
         self.ci.addCommand('IsClosed', self.cmdIsClosed)
         self.ci.addCommand('SetAntiAliasing', self.cmdSetAntiAliasing)
+        self.ci.addCommand('Wipe', self.cmdWipe)
         self.ci.addCommand('_apiVersion', self.cmd_apiVersion)
 
         setting.transient_settings['unsafe_mode'] = True
@@ -159,7 +159,11 @@ class EmbeddedClient(object):
         """
         self.plot.setPageNumber(pagenum-1)
 
-class EmbedApplication(qt4.QApplication):
+    def cmdWipe(self):
+        """Wipe the current document."""
+        self.document.wipe()
+
+class EmbedApplication(qt.QApplication):
     """Application to run remote end of embed connection.
 
     Commands are sent over stdin, with responses sent to stdout
@@ -169,12 +173,12 @@ class EmbedApplication(qt4.QApplication):
     cmdlenlen = struct.calcsize('<I')
 
     def __init__(self, thesocket, args):
-        qt4.QApplication.__init__(self, args)
+        qt.QApplication.__init__(self, args)
         self.socket = thesocket
 
         # listen to commands on the socket
-        self.notifier = qt4.QSocketNotifier(
-            self.socket.fileno(), qt4.QSocketNotifier.Read)
+        self.notifier = qt.QSocketNotifier(
+            self.socket.fileno(), qt.QSocketNotifier.Type.Read)
         self.notifier.activated.connect(self.slotDataToRead)
         self.notifier.setEnabled(True)
 
@@ -182,21 +186,22 @@ class EmbedApplication(qt4.QApplication):
         self.clients = {}
         self.clientcounter = 0
 
+    @staticmethod
     def readLenFromSocket(thesocket, length):
         """Read length bytes from socket."""
         s = b''
         while len(s) < length:
             s += thesocket.recv(length-len(s))
         return s
-    readLenFromSocket = staticmethod(readLenFromSocket)
 
+    @staticmethod
     def writeToSocket(thesocket, data):
         """Write to socket until all data written."""
         count = 0
         while count < len(data):
             count += thesocket.send(data[count:])
-    writeToSocket = staticmethod(writeToSocket)
 
+    @staticmethod
     def readCommand(thesocket):
         # get length of packet
         length = struct.unpack('<I', EmbedApplication.readLenFromSocket(
@@ -204,7 +209,6 @@ class EmbedApplication(qt4.QApplication):
         # unpickle command and arguments
         temp = EmbedApplication.readLenFromSocket(thesocket, length)
         return pickle.loads(temp)
-    readCommand = staticmethod(readCommand)
 
     def makeNewClient(self, title, doc=None, hidden=False):
         """Make a new client window."""
@@ -212,7 +216,7 @@ class EmbedApplication(qt4.QApplication):
         self.clients[self.clientcounter] = client
         # return new number and list of commands and docstrings
         retfuncs = []
-        for name, cmd in citems(client.ci.cmds):
+        for name, cmd in client.ci.cmds.items():
             retfuncs.append( (name, cmd.__doc__) )
 
         retval = self.clientcounter, retfuncs
@@ -249,7 +253,7 @@ class EmbedApplication(qt4.QApplication):
     def readFromSocket(self):
         self.notifier.setEnabled(False)
         self.socket.setblocking(1)
-        
+
         # unpickle command and arguments
         window, cmd, args, argsv = self.readCommand(self.socket)
 
@@ -261,9 +265,11 @@ class EmbedApplication(qt4.QApplication):
         elif cmd == '_NewWindowCopy':
             # sets the document of this window to be the same as the
             # one specified
-            retval = self.makeNewClient( args[0],
-                                         doc=self.clients[args[1]].document,
-                                         hidden=argsv['hidden'] )
+            retval = self.makeNewClient(
+                args[0],
+                doc=self.clients[args[1]].document,
+                hidden=argsv['hidden']
+            )
         else:
             interpreter = self.clients[window].ci
 
@@ -293,14 +299,16 @@ def runremote():
 
     if params[0] == 'unix':
         # talk to existing unix domain socket
-        listensocket = socket.fromfd( int(params[1]),
-                                      socket.AF_UNIX,
-                                      socket.SOCK_STREAM )
+        listensocket = socket.fromfd(
+            int(params[1]),
+            socket.AF_UNIX,
+            socket.SOCK_STREAM
+        )
 
     elif params[0] == 'internet':
         # talk to internet port
-        listensocket = socket.socket( socket.AF_INET,
-                                      socket.SOCK_STREAM )
+        listensocket = socket.socket(
+            socket.AF_INET, socket.SOCK_STREAM)
         listensocket.connect( (params[1], int(params[2])) )
 
     # get secret from stdin and send back to socket
@@ -311,4 +319,4 @@ def runremote():
     # finally start listening application
     app = EmbedApplication(listensocket, [])
     app.setQuitOnLastWindowClosed(False)
-    app.exec_()
+    app.exec()
