@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #    Copyright (C) 2011 Jeremy S. Sanders
 #    Email: Jeremy Sanders <jeremy@jeremysanders.net>
 #
@@ -17,7 +16,6 @@
 #    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 ###############################################################################
 
-from __future__ import division
 from .. import qtall as qt
 from .. import utils
 
@@ -36,7 +34,7 @@ class LineEditWithClear(qt.QLineEdit):
         # the clear button itself, with no padding
         self.clearbutton = cb = qt.QToolButton(self)
         cb.setIcon( utils.getIcon('kde-edit-delete') )
-        cb.setCursor(qt.Qt.ArrowCursor)
+        cb.setCursor(qt.Qt.CursorShape.ArrowCursor)
         cb.setStyleSheet('QToolButton { border: none; padding: 0px; }')
         cb.setToolTip("Clear text")
         cb.hide()
@@ -47,9 +45,10 @@ class LineEditWithClear(qt.QLineEdit):
         self.textChanged.connect(self.updateCloseButton)
 
         # positioning of the button
-        fw = self.style().pixelMetric(qt.QStyle.PM_DefaultFrameWidth)
-        self.setStyleSheet("QLineEdit { padding-right: %ipx; } " %
-                           (cb.sizeHint().width() + fw + 1))
+        fw = self.style().pixelMetric(qt.QStyle.PixelMetric.PM_DefaultFrameWidth)
+        self.setStyleSheet(
+            "QLineEdit { padding-right: %ipx; } " %
+            (cb.sizeHint().width() + fw + 1))
         msz = self.minimumSizeHint()
         mx =  cb.sizeHint().height()+ fw*2 + 2
         self.setMinimumSize( max(msz.width(), mx), max(msz.height(), mx) )
@@ -57,10 +56,11 @@ class LineEditWithClear(qt.QLineEdit):
     def resizeEvent(self, evt):
         """Move button if widget resized."""
         sz = self.clearbutton.sizeHint()
-        fw = self.style().pixelMetric(qt.QStyle.PM_DefaultFrameWidth)
+        fw = self.style().pixelMetric(qt.QStyle.PixelMetric.PM_DefaultFrameWidth)
         r = self.rect()
-        self.clearbutton.move( r.right() - fw - sz.width(),
-                               (r.bottom() + 1 - sz.height())//2 )
+        self.clearbutton.move(
+            r.right() - fw - sz.width(),
+            (r.bottom() + 1 - sz.height())//2 )
 
     def updateCloseButton(self, text):
         """Button should only appear if there is text."""
