@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #    Copyright (C) 2005 Jeremy S. Sanders
 #    Email: Jeremy Sanders <jeremy@jeremysanders.net>
 #
@@ -24,13 +23,10 @@
     changed. The creator should use this to change the setting.
 """
 
-from __future__ import division
 import re
 import numpy as N
 
-from ..compat import crange, czip, citems, cstr
 from .. import qtall as qt
-
 from .settingdb import settingdb
 from .. import utils
 
@@ -44,17 +40,35 @@ def styleClear(widget):
 
 def styleError(widget):
     """Show error state on widget."""
-    widget.setStyleSheet("background-color: " +
-                         settingdb.color('error').name() )
+    widget.setStyleSheet(
+        "background-color: " + settingdb.color('error').name() )
 
 class DotDotButton(qt.QPushButton):
     """A button for opening up more complex editor."""
     def __init__(self, tooltip=None, checkable=True):
-        qt.QPushButton.__init__(self, "..", flat=True, checkable=checkable,
-                                 maximumWidth=16, maximumHeight=16)
+        qt.QPushButton.__init__(
+            self, "..", flat=True, checkable=checkable,
+            maximumWidth=16, maximumHeight=16)
         if tooltip:
             self.setToolTip(tooltip)
-        self.setSizePolicy(qt.QSizePolicy.Maximum, qt.QSizePolicy.Maximum)
+        self.setSizePolicy(qt.QSizePolicy.Policy.Maximum, qt.QSizePolicy.Policy.Maximum)
+        self.setStyleSheet('QPushButton { padding: 0; }')
+
+class AddButton(qt.QPushButton):
+    """A button to add item."""
+    def __init__(self):
+        qt.QPushButton.__init__(self, "+", flat=True)
+        self.setFixedWidth(24)
+        self.setToolTip('Add another item')
+        self.setStyleSheet('QPushButton { padding: 0; }')
+
+class SubButton(qt.QPushButton):
+    """A button to subtract item."""
+    def __init__(self):
+        qt.QPushButton.__init__(self, "-", flat=True)
+        self.setFixedWidth(24)
+        self.setToolTip('Remove item')
+        self.setStyleSheet('QPushButton { padding: 0; }')
 
 class Edit(qt.QLineEdit):
     """Main control for editing settings which are text."""
@@ -97,14 +111,14 @@ class _EditBox(qt.QTextEdit):
     Emits closing(text) when the box closes
     """
 
-    closing = qt.pyqtSignal(cstr)
+    closing = qt.pyqtSignal(str)
 
     def __init__(self, origtext, readonly, parent):
         """Make a popup, framed widget containing a text editor."""
 
         qt.QTextEdit.__init__(self, parent)
-        self.setWindowFlags(qt.Qt.Popup)
-        self.setAttribute(qt.Qt.WA_DeleteOnClose)
+        self.setWindowFlags(qt.Qt.WindowType.Popup)
+        self.setAttribute(qt.Qt.WidgetAttribute.WA_DeleteOnClose)
 
         self.spacing = self.fontMetrics().height()
 
@@ -112,7 +126,7 @@ class _EditBox(qt.QTextEdit):
         self.setPlainText(origtext)
 
         cursor = self.textCursor()
-        cursor.movePosition(qt.QTextCursor.End)
+        cursor.movePosition(qt.QTextCursor.MoveOperation.End)
         self.setTextCursor(cursor)
 
         if readonly:
@@ -125,7 +139,7 @@ class _EditBox(qt.QTextEdit):
     def eventFilter(self, obj, event):
         """Grab clicks outside this window to close it."""
         if ( isinstance(event, qt.QMouseEvent) and
-             event.buttons() != qt.Qt.NoButton ):
+             event.buttons() != qt.Qt.MouseButton.NoButton ):
             frame = qt.QRect(0, 0, self.width(), self.height())
             if not frame.contains(event.pos()):
                 self.close()
@@ -137,11 +151,11 @@ class _EditBox(qt.QTextEdit):
         qt.QTextEdit.keyPressEvent(self, event)
 
         key = event.key()
-        if key == qt.Qt.Key_Escape:
+        if key == qt.Qt.Key.Key_Escape:
             # restore original content
             self.setPlainText(self.origtext)
             self.close()
-        elif key == qt.Qt.Key_Return:
+        elif key == qt.Qt.Key.Key_Return:
             # keep changes
             self.close()
 
@@ -194,8 +208,8 @@ class String(qt.QWidget):
 
         # if button is down and there's no existing popup, bring up a new one
         if on:
-            e = _EditBox( self.edit.text(),
-                          self.setting.readonly, self.button)
+            e = _EditBox(
+                self.edit.text(), self.setting.readonly, self.button)
 
             # we get notified with text when the popup closes
             e.closing.connect(self.boxClosing)
@@ -280,12 +294,12 @@ class FloatSlider(qt.QWidget):
         layout.setContentsMargins(0, 0, 0, 0)
         self.setLayout(layout)
 
-        s = self.slider = qt.QSlider(qt.Qt.Horizontal)
+        s = self.slider = qt.QSlider(qt.Qt.Orientation.Horizontal)
         s.setMinimum(int(setting.minval/setting.scale))
         s.setMaximum(int(setting.maxval/setting.scale))
         s.setPageStep(int(setting.step/setting.scale))
         s.setTickInterval(int(setting.tick/setting.scale))
-        s.setTickPosition(qt.QSlider.TicksAbove)
+        s.setTickPosition(qt.QSlider.TickPosition.TicksAbove)
         layout.addWidget(self.slider)
 
         self.edit = qt.QLineEdit()
@@ -326,7 +340,7 @@ class Bool(qt.QCheckBox):
         qt.QCheckBox.__init__(self, parent)
 
         self.setSizePolicy( qt.QSizePolicy(
-            qt.QSizePolicy.MinimumExpanding, qt.QSizePolicy.Fixed) )
+            qt.QSizePolicy.Policy.MinimumExpanding, qt.QSizePolicy.Policy.Fixed) )
 
         self.ignorechange = False
         self.setting = setting
@@ -392,7 +406,7 @@ class Choice(qt.QComboBox):
 
         # stops combobox readjusting in size to fit contents
         self.setSizeAdjustPolicy(
-            qt.QComboBox.AdjustToMinimumContentsLengthWithIcon)
+            qt.QComboBox.SizeAdjustPolicy.AdjustToMinimumContentsLengthWithIcon)
 
         # whether to show ui text to replace some items
         toadd = uilist if uilist is not None else vallist
@@ -402,13 +416,13 @@ class Choice(qt.QComboBox):
             self.addItems( list(toadd) )
         else:
             # add pixmaps and text to list
-            for icon, text in czip(icons, toadd):
+            for icon, text in zip(icons, toadd):
                 self.addItem(icon, text)
 
         # use tooltip descriptions if requested
         if descriptions is not None:
             for i, descr in enumerate(descriptions):
-                self.setItemData(i, descr, qt.Qt.ToolTipRole)
+                self.setItemData(i, descr, qt.Qt.ItemDataRole.ToolTipRole)
 
         # choose the correct setting
         try:
@@ -421,7 +435,7 @@ class Choice(qt.QComboBox):
             self.setEditText( setting.toUIText() )
 
         # if a different item is selected
-        self.activated[str].connect(self.slotActivated)
+        self.textActivated[str].connect(self.slotActivated)
 
         self.setting.setOnModified(self.onModified)
 
@@ -430,7 +444,7 @@ class Choice(qt.QComboBox):
 
         # make completion case sensitive (to help fix case typos)
         if self.completer():
-            self.completer().setCaseSensitivity(qt.Qt.CaseSensitive)
+            self.completer().setCaseSensitivity(qt.Qt.CaseSensitivity.CaseSensitive)
 
     def focusOutEvent(self, *args):
         """Allows us to check the contents of the widget."""
@@ -501,9 +515,11 @@ class FillStyleExtended(ChoiceSwitch):
         if self._icons is None:
             self._generateIcons()
 
-        ChoiceSwitch.__init__(self, setting, False,
-                              utils.extfillstyles, parent,
-                              icons=self._icons)
+        ChoiceSwitch.__init__(
+            self, setting, False,
+            utils.extfillstyles, parent,
+            icons=self._icons
+        )
 
     @classmethod
     def _generateIcons(cls):
@@ -529,7 +545,7 @@ class FillStyleExtended(ChoiceSwitch):
             pix = qt.QPixmap(size, size)
             pix.fill()
             painter = document.DirectPainter(pix)
-            painter.setRenderHint(qt.QPainter.Antialiasing)
+            painter.setRenderHint(qt.QPainter.RenderHint.Antialiasing)
             painter.updateMetaData(phelper)
             brush.style = f
             utils.brushExtFillPath(painter, brush, path)
@@ -547,7 +563,7 @@ class MultiLine(qt.QTextEdit):
         qt.QTextEdit.__init__(self, parent)
         self.setting = setting
 
-        self.setWordWrapMode(qt.QTextOption.NoWrap)
+        self.setWordWrapMode(qt.QTextOption.WrapMode.NoWrap)
         self.setTabChangesFocus(True)
 
         # set the text of the widget to the
@@ -574,7 +590,7 @@ class MultiLine(qt.QTextEdit):
         m = self.contentsMargins()
         docheight = self.document().size().height() + m.top() + m.bottom()
         docheight = min(self.heightmax, max(self.heightmin, docheight))
-        self.setFixedHeight(docheight)
+        self.setFixedHeight(int(docheight))
 
     def focusOutEvent(self, *args):
         """Allows us to check the contents of the widget."""
@@ -599,7 +615,7 @@ class Notes(MultiLine):
 
     def __init__(self, setting, parent):
         MultiLine.__init__(self, setting, parent)
-        self.setWordWrapMode(qt.QTextOption.WordWrap)
+        self.setWordWrapMode(qt.QTextOption.WrapMode.WordWrap)
 
 class Distance(Choice):
     """For editing distance settings."""
@@ -651,7 +667,7 @@ class Distance(Choice):
             newitems.insert(0, text)
 
         # get rid of existing items in list (clear doesn't work here)
-        for i in crange(self.count()):
+        for i in range(self.count()):
             self.removeItem(0)
 
         # put new items in and select the correct option
@@ -674,7 +690,7 @@ class DistancePt(Choice):
         '4pt', '5pt', '6pt', '8pt', '10pt', '12pt', '14pt', '16pt',
         '18pt', '20pt', '22pt', '24pt', '26pt', '28pt', '30pt',
         '34pt', '40pt', '44pt', '50pt', '60pt', '70pt'
-        )
+    )
 
     def __init__(self, setting, parent, allowauto=False):
         '''Initialise with blank list, then populate with sensible units.'''
@@ -719,14 +735,20 @@ class Dataset(qt.QWidget):
 
         # get datasets of the correct dimension
         datasets = []
-        for name, ds in citems(self.document.data):
-            if ( (ds.dimensions == self.dimensions or
-                  self.dimensions == 'all') and (
-                      ds.datatype == self.datatype or
-                      self.datatype == 'all' or
-                      ds.datatype in self.datatype)
-            ):
+        for name, ds in self.document.data.items():
+            okdims = (
+                ds.dimensions == self.dimensions or
+                self.dimensions == 'all'
+            )
+            oktype = (
+                ds.datatype == self.datatype or
+                self.datatype == 'all' or
+                ds.datatype in self.datatype
+            )
+
+            if okdims and oktype:
                 datasets.append(name)
+
         datasets.sort()
 
         if datasets != self.lastdatasets:
@@ -742,11 +764,12 @@ class Dataset(qt.QWidget):
         """Bring up list of datasets."""
         if on:
             from ..qtwidgets.datasetbrowser import DatasetBrowserPopup
-            d = DatasetBrowserPopup(self.document,
-                                    self.choice.currentText(),
-                                    self.button,
-                                    filterdims=set((self.dimensions,)),
-                                    filterdtype=set((self.datatype,)) )
+            d = DatasetBrowserPopup(
+                self.document,
+                self.choice.currentText(),
+                self.button,
+                filterdims=set((self.dimensions,)),
+                filterdtype=set((self.datatype,)) )
             d.closing.connect(self.boxClosing)
             d.newdataset.connect(self.newDataset)
             d.show()
@@ -774,8 +797,9 @@ class DatasetOrString(Dataset):
 
         # if button is down and there's no existing popup, bring up a new one
         if on:
-            e = _EditBox( self.choice.currentText(),
-                          self.choice.setting.readonly, self.textbutton)
+            e = _EditBox(
+                self.choice.currentText(),
+                self.choice.setting.readonly, self.textbutton)
 
             # we get notified with text when the popup closes
             e.closing.connect(self.textBoxClosing)
@@ -804,9 +828,11 @@ class FillStyle(Choice):
         if self._icons is None:
             self._generateIcons()
 
-        Choice.__init__(self, setting, False,
-                        self._fills, parent,
-                        icons=self._icons)
+        Choice.__init__(
+            self, setting, False,
+            self._fills, parent,
+            icons=self._icons
+        )
 
     @classmethod
     def _generateIcons(cls):
@@ -819,7 +845,7 @@ class FillStyle(Choice):
             pix = qt.QPixmap(size, size)
             pix.fill()
             painter = qt.QPainter(pix)
-            painter.setRenderHint(qt.QPainter.Antialiasing)
+            painter.setRenderHint(qt.QPainter.RenderHint.Antialiasing)
             brush = qt.QBrush(c, cls._fillcnvt[f])
             painter.fillRect(0, 0, size, size, brush)
             painter.end()
@@ -836,21 +862,23 @@ class Marker(Choice):
         if self._icons is None:
             self._generateIcons()
 
-        Choice.__init__(self, setting, False,
-                        utils.MarkerCodes, parent,
-                        icons=self._icons)
+        Choice.__init__(
+            self, setting, False,
+            utils.MarkerCodes, parent,
+            icons=self._icons
+        )
 
     @classmethod
     def _generateIcons(cls):
         size = 16
         icons = []
         brush = qt.QBrush( qt.QColor('darkgrey') )
-        pen = qt.QPen( qt.QBrush(qt.Qt.black), 1. )
+        pen = qt.QPen( qt.QBrush(qt.Qt.GlobalColor.black), 1. )
         for marker in utils.MarkerCodes:
             pix = qt.QPixmap(size, size)
             pix.fill()
             painter = qt.QPainter(pix)
-            painter.setRenderHint(qt.QPainter.Antialiasing)
+            painter.setRenderHint(qt.QPainter.RenderHint.Antialiasing)
             painter.setBrush(brush)
             painter.setPen(pen)
             utils.plotMarker(painter, size*0.5, size*0.5, marker, size*0.33)
@@ -868,27 +896,30 @@ class Arrow(Choice):
         if self._icons is None:
             self._generateIcons()
 
-        Choice.__init__(self, setting, False,
-                        utils.ArrowCodes, parent,
-                        icons=self._icons)
+        Choice.__init__(
+            self, setting, False,
+            utils.ArrowCodes, parent,
+            icons=self._icons
+        )
 
     @classmethod
     def _generateIcons(cls):
         size = 16
         icons = []
-        brush = qt.QBrush(qt.Qt.black)
-        pen = qt.QPen( qt.QBrush(qt.Qt.black), 1. )
+        brush = qt.QBrush(qt.Qt.GlobalColor.black)
+        pen = qt.QPen( qt.QBrush(qt.Qt.GlobalColor.black), 1. )
         for arrow in utils.ArrowCodes:
             pix = qt.QPixmap(size, size)
             pix.fill()
             painter = qt.QPainter(pix)
-            painter.setRenderHint(qt.QPainter.Antialiasing)
+            painter.setRenderHint(qt.QPainter.RenderHint.Antialiasing)
             painter.setBrush(brush)
             painter.setPen(pen)
-            utils.plotLineArrow(painter, size*0.4, size*0.5,
-                                size*2, 0.,
-                                arrowsize=size*0.2,
-                                arrowleft=arrow, arrowright=arrow)
+            utils.plotLineArrow(
+                painter, size*0.4, size*0.5,
+                size*2, 0.,
+                arrowsize=size*0.2,
+                arrowleft=arrow, arrowright=arrow)
             painter.end()
             icons.append( qt.QIcon(pix) )
 
@@ -907,9 +938,11 @@ class LineStyle(Choice):
         if self._icons is None:
             self._generateIcons()
 
-        Choice.__init__(self, setting, False,
-                        self._lines, parent,
-                        icons=self._icons)
+        Choice.__init__(
+            self, setting, False,
+            self._lines, parent,
+            icons=self._icons
+        )
         self.setIconSize( qt.QSize(*self.size) )
 
     @classmethod
@@ -932,7 +965,7 @@ class LineStyle(Choice):
             pix.fill()
 
             painter = document.DirectPainter(pix)
-            painter.setRenderHint(qt.QPainter.Antialiasing)
+            painter.setRenderHint(qt.QPainter.RenderHint.Antialiasing)
 
             phelper = document.PaintHelper(doc, (1, 1))
             painter.updateMetaData(phelper)
@@ -949,7 +982,7 @@ class LineStyle(Choice):
         cls._icons = icons
 
 class _ColNotifier(qt.QObject):
-    sigNewColor = qt.pyqtSignal(cstr)
+    sigNewColor = qt.pyqtSignal(str)
 
 
 class Color(qt.QWidget):
@@ -970,12 +1003,12 @@ class Color(qt.QWidget):
         # combo box
         c = self.combo = qt.QComboBox()
         c.setEditable(True)
-        c.activated[str].connect(self.slotActivated)
+        c.textActivated[str].connect(self.slotActivated)
 
         # button for selecting colors
         b = self.button = qt.QPushButton()
         b.setFlat(True)
-        b.setSizePolicy(qt.QSizePolicy.Maximum, qt.QSizePolicy.Maximum)
+        b.setSizePolicy(qt.QSizePolicy.Policy.Maximum, qt.QSizePolicy.Policy.Maximum)
         b.setMaximumHeight(24)
         b.setMaximumWidth(24)
         b.clicked.connect(self.slotButtonClicked)
@@ -1023,7 +1056,7 @@ class Color(qt.QWidget):
 
         self.combo.setCurrentIndex(index)
 
-        icon = self.combo.itemData(index, qt.Qt.DecorationRole)
+        icon = self.combo.itemData(index, qt.Qt.ItemDataRole.DecorationRole)
         self.button.setIcon(icon)
 
     @qt.pyqtSlot()
@@ -1124,7 +1157,7 @@ class ListSet(qt.QFrame):
         """
 
         qt.QFrame.__init__(self, parent)
-        self.setFrameStyle(qt.QFrame.Box)
+        self.setFrameStyle(qt.QFrame.Shape.Box)
         self.defaultval = defaultval
         self.setting = setting
         self.controls = []
@@ -1169,7 +1202,7 @@ class ListSet(qt.QFrame):
         for row, val in enumerate(self.setting.val):
             cntrls = self.populateRow(row)
             self.updateRow(cntrls, val)
-            for col in crange(len(cntrls)):
+            for col in range(len(cntrls)):
                 self.layout.addWidget(cntrls[col], row, col)
             for c in cntrls:
                 c.show()
@@ -1215,7 +1248,7 @@ class ListSet(qt.QFrame):
     def onModified(self):
         """called when the setting is changed remotely"""
         self.populate()
-        for cntrls, row in czip(self.controls, self.setting.val):
+        for cntrls, row in zip(self.controls, self.setting.val):
             self.updateRow(cntrls, row)
 
     def identifyPosn(self, widget):
@@ -1234,7 +1267,7 @@ class ListSet(qt.QFrame):
         """Add a color button to the list at the position specified."""
         wcolor = qt.QPushButton()
         wcolor.setFlat(True)
-        wcolor.setSizePolicy(qt.QSizePolicy.Maximum, qt.QSizePolicy.Maximum)
+        wcolor.setSizePolicy(qt.QSizePolicy.Policy.Maximum, qt.QSizePolicy.Policy.Maximum)
         wcolor.setMaximumHeight(24)
         wcolor.setMaximumWidth(24)
         wcolor.setToolTip(tooltip)
@@ -1271,7 +1304,7 @@ class ListSet(qt.QFrame):
             for icon in icons:
                 wcombo.addItem(icon, "")
         else:
-            for text, icon in czip(texts, icons):
+            for text, icon in zip(texts, icons):
                 wcombo.addItem(icon, text)
 
         wcombo._vz_values = values
@@ -1314,7 +1347,7 @@ class ListSet(qt.QFrame):
             qcolor,
             self,
             "Choose color",
-            qt.QColorDialog.ShowAlphaChannel )
+            qt.QColorDialog.ColorDialogOption.ShowAlphaChannel )
         if color.isValid():
             # change setting
             # this is a bit irritating, as have to do lots of
@@ -1398,8 +1431,8 @@ class _FillBox(qt.QScrollArea):
         """
 
         qt.QScrollArea.__init__(self, parent)
-        self.setWindowFlags(qt.Qt.Popup)
-        self.setAttribute(qt.Qt.WA_DeleteOnClose)
+        self.setWindowFlags(qt.Qt.WindowType.Popup)
+        self.setAttribute(qt.Qt.WidgetAttribute.WA_DeleteOnClose)
         self.parent = parent
         self.row = row
         self.setting = thesetting
@@ -1450,7 +1483,7 @@ class _FillBox(qt.QScrollArea):
     def eventFilter(self, obj, event):
         """Grab clicks outside this window to close it."""
         if ( isinstance(event, qt.QMouseEvent) and
-             event.buttons() != qt.Qt.NoButton ):
+             event.buttons() != qt.Qt.MouseButton.NoButton ):
             frame = qt.QRect(0, 0, self.width(), self.height())
             if not frame.contains(event.pos()):
                 self.close()
@@ -1462,7 +1495,7 @@ class _FillBox(qt.QScrollArea):
         qt.QScrollArea.keyPressEvent(self, event)
 
         key = event.key()
-        if key == qt.Qt.Key_Escape:
+        if key == qt.Qt.Key.Key_Escape:
             self.close()
 
     def closeEvent(self, event):
@@ -1516,8 +1549,9 @@ class FillSet(ListSet):
 
     def editMore(self, on, row):
         if on:
-            fb = _FillBox(self.setting.getDocument(), self.setting,
-                          row, self.buttonAtRow(row), self.parent())
+            fb = _FillBox(
+                self.setting.getDocument(), self.setting,
+                row, self.buttonAtRow(row), self.parent())
             fb.closing.connect(self.boxClosing)
             fb.sigSettingChanged.connect(self.sigSettingChanged)
             fb.show()
@@ -1555,14 +1589,8 @@ class MultiSettingWidget(qt.QWidget):
         row = len(self.controls)
         cntrl = self.makeControl(row)
         cntrl.installEventFilter(self)
-        addbutton = qt.QPushButton('+')
-        addbutton.setFixedWidth(24)
-        addbutton.setFlat(True)
-        addbutton.setToolTip('Add another item')
-        subbutton = qt.QPushButton('-')
-        subbutton.setToolTip('Remove item')
-        subbutton.setFixedWidth(24)
-        subbutton.setFlat(True)
+        addbutton = AddButton()
+        subbutton = SubButton()
 
         self.controls.append((cntrl, addbutton, subbutton))
 
@@ -1582,7 +1610,7 @@ class MultiSettingWidget(qt.QWidget):
 
     def eventFilter(self, obj, event):
         """Capture loss of focus by controls."""
-        if event.type() == qt.QEvent.FocusOut:
+        if event.type() == qt.QEvent.Type.FocusOut:
             for row, c in enumerate(self.controls):
                 if c[0] is obj:
                     self.dataChanged(row)
@@ -1670,7 +1698,7 @@ class Datasets(MultiSettingWidget):
         combo.setEditable(True)
         combo.lineEdit().editingFinished.connect(lambda: self.dataChanged(row))
         # if a different item is selected
-        combo.activated[str].connect(lambda x: self.dataChanged(row))
+        combo.textActivated[str].connect(lambda x: self.dataChanged(row))
         utils.populateCombo(combo, self.getDatasets())
         return combo
 
@@ -1681,7 +1709,7 @@ class Datasets(MultiSettingWidget):
     def getDatasets(self):
         """Get applicable datasets (sorted)."""
         datasets = []
-        for name, ds in citems(self.document.data):
+        for name, ds in self.document.data.items():
             if (ds.dimensions == self.dimensions and
                 ds.datatype == self.datatype):
                 datasets.append(name)
@@ -1690,7 +1718,7 @@ class Datasets(MultiSettingWidget):
 
     def updateControls(self):
         """Set values of controls."""
-        for cntrls, val in czip(self.controls, self.setting.val):
+        for cntrls, val in zip(self.controls, self.setting.val):
             cntrls[0].lineEdit().setText(val)
 
     @qt.pyqtSlot()
@@ -1732,7 +1760,7 @@ class Strings(MultiSettingWidget):
 
     def updateControls(self):
         """Set values of controls."""
-        for cntrls, val in czip(self.controls, self.setting.val):
+        for cntrls, val in zip(self.controls, self.setting.val):
             cntrls[0].setText(val)
 
 class Filename(qt.QWidget):
@@ -1761,8 +1789,8 @@ class Filename(qt.QWidget):
         self.edit.setText( setting.toUIText() )
         layout.addWidget(self.edit)
 
-        b = self.button = DotDotButton(checkable=False,
-                                       tooltip=_("Browse for file"))
+        b = self.button = DotDotButton(
+            checkable=False, tooltip=_("Browse for file"))
         layout.addWidget(b)
 
         # connect up signals
@@ -1771,7 +1799,7 @@ class Filename(qt.QWidget):
 
         # completion support
         c = self.filenamecompleter = qt.QCompleter(self)
-        model = qt.QDirModel(c)
+        model = qt.QFileSystemModel()
         c.setModel(model)
         self.edit.setCompleter(c)
 
@@ -1788,8 +1816,13 @@ class Filename(qt.QWidget):
         filefilter = _("All files (*)")
         if self.mode == 'image':
             title = _('Choose image')
-            filefilter = ("Images (*.png *.jpg *.jpeg *.bmp *.svg *.tiff *.tif "
-                          "*.gif *.xbm *.xpm);;" + filefilter)
+            filefilter = (
+                "Images (*.png *.jpg *.jpeg *.bmp *.svg *.tiff *.tif "
+                "*.gif *.xbm *.xpm);;" + filefilter)
+        
+        elif self.mode == 'svg':
+            title = _('Choose SVG file')
+            filefilter = ("Images (*.svg);;" + filefilter)
 
         retn = qt.QFileDialog.getOpenFileName(
             self, title, self.edit.text(), filefilter)
@@ -1825,19 +1858,19 @@ class FontFamily(qt.QFontComboBox):
 
         qt.QFontComboBox.__init__(self, parent)
         self.setting = setting
-        self.setFontFilters( qt.QFontComboBox.ScalableFonts )
+        self.setFontFilters( qt.QFontComboBox.FontFilter.ScalableFonts )
 
         # set initial value
         self.onModified()
 
         # stops combobox readjusting in size to fit contents
         self.setSizeAdjustPolicy(
-            qt.QComboBox.AdjustToMinimumContentsLengthWithIcon)
+            qt.QComboBox.SizeAdjustPolicy.AdjustToMinimumContentsLengthWithIcon)
 
         self.setting.setOnModified(self.onModified)
 
         # if a different item is selected
-        self.activated[str].connect(self.slotActivated)
+        self.textActivated[str].connect(self.slotActivated)
 
     def focusOutEvent(self, *args):
         """Allows us to check the contents of the widget."""
@@ -1854,6 +1887,53 @@ class FontFamily(qt.QFontComboBox):
         """Make control reflect chosen setting."""
         self.setCurrentFont( qt.QFont(self.setting.toUIText()) )
 
+class FontStyle(qt.QComboBox):
+    """Font style associated with font family."""
+
+    sigSettingChanged = qt.pyqtSignal(qt.QObject, object, object)
+    deftext = _('default')
+
+    def __init__(self, setting, familysetting, parent):
+        """Create the combobox."""
+
+        qt.QComboBox.__init__(self, parent)
+        self.setEditable(True)
+        self.setting = setting
+        self.familysetting = familysetting
+
+        self.onModified()
+
+        self.setting.setOnModified(self.onModified)
+        self.familysetting.setOnModified(self.onModified)
+
+        # if a different item is selected
+        self.textActivated[str].connect(self.slotActivated)
+
+    def slotActivated(self, val):
+        """Update setting if a different item is chosen."""
+        newval = self.currentText().strip()
+        if newval == self.deftext:
+            newval = ''
+        self.sigSettingChanged.emit(self, self.setting, newval)
+
+    @qt.pyqtSlot()
+    def onModified(self):
+        """Make control reflect chosen setting."""
+
+        font_family = self.familysetting.get()
+        styles = [self.deftext] + sorted(
+            qt.QFontDatabase.styles(font_family))
+
+        val = self.setting.get().strip()
+        if not val:
+            val = 'default'
+        elif val not in styles:
+            styles.append(val)
+
+        utils.populateCombo(self, styles)
+        idx = self.findText(val)
+        self.setCurrentIndex(idx)
+
 class ErrorStyle(Choice):
     """Choose different error bar styles."""
 
@@ -1864,9 +1944,11 @@ class ErrorStyle(Choice):
         if self._icons is None:
             self._generateIcons()
 
-        Choice.__init__(self, setting, False,
-                        self._errorstyles, parent,
-                        icons=self._icons)
+        Choice.__init__(
+            self, setting, False,
+            self._errorstyles, parent,
+            icons=self._icons
+        )
 
     @classmethod
     def _generateIcons(cls):
@@ -1889,9 +1971,11 @@ class Colormap(Choice):
         names = sorted(document.evaluate.colormaps)
 
         icons = Colormap._generateIcons(document, names)
-        Choice.__init__(self, setn, True,
-                        names, parent,
-                        icons=icons)
+        Choice.__init__(
+            self, setn, True,
+            names, parent,
+            icons=icons
+        )
         self.setIconSize( qt.QSize(*self.size) )
 
     @classmethod
@@ -1914,12 +1998,11 @@ class Colormap(Choice):
                 if val is None:
                     # empty icon
                     pixmap = qt.QPixmap(*size)
-                    pixmap.fill(qt.Qt.transparent)
+                    pixmap.fill(qt.Qt.GlobalColor.transparent)
                 else:
                     # generate icon
-                    image = utils.applyColorMap(val, 'linear',
-                                                fakedataset,
-                                                0., size[0]-1., 0)
+                    image = utils.applyColorMap(
+                        val, 'linear', fakedataset, 0., size[0]-1., 0)
                     pixmap = qt.QPixmap.fromImage(image)
                 icon = qt.QIcon(pixmap)
                 kls._icons[name] = icon
@@ -1945,3 +2028,4 @@ class AxisBound(Choice):
 
         if self.currentText().lower() != 'auto':
             self.setEditText( self.setting.toUIText() )
+
