@@ -16,12 +16,11 @@
 #    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 ###############################################################################
 
-from __future__ import division
 import re
+
 import numpy as N
 
 from .. import qtall as qt
-
 from ..helpers.qtloops import numpyToQImage, applyImageTransparancy
 
 # Default colormaps used by widgets.
@@ -38,21 +37,21 @@ _defaultmaps = {
     'blank': (
         (0,   0,   0,   0),
         (0,   0,   0,   0),
-        ),
+    ),
     'heat': (
         (0,   0,   0,   255),
         (0,   0,   186, 255),
         (50,  139, 255, 255),
         (19,  239, 248, 255),
         (255, 255, 255, 255),
-        ),
+    ),
     'spectrum2': (
         (0,   0,   255, 255),
         (0,   255, 255, 255),
         (0,   255, 0,   255),
         (255, 255, 0,   255),
         (255, 0,   0,   255),
-        ),
+    ),
     'spectrum2-step': (
         (-1,  0,   0,   0),
         (0,   0,   255, 255),
@@ -60,7 +59,7 @@ _defaultmaps = {
         (0,   255, 0,   255),
         (255, 255, 0,   255),
         (255, 0,   0,   255),
-        ),
+    ),
     'spectrum': (
         (0,   0,   0,   255),
         (0,   0,   255, 255),
@@ -69,44 +68,44 @@ _defaultmaps = {
         (255, 255, 0,   255),
         (255, 0,   0,   255),
         (255, 255, 255, 255),
-        ),
+    ),
     'grey': (
         (0,   0,   0,   255),
         (255, 255, 255, 255),
-        ),
+    ),
     'blue': (
         (0,   0,   0,   255),
         (255, 0,   0,   255),
         (255, 255, 255, 255),
-        ),
+    ),
     'red': (
         (0,   0,   0,   255),
         (0,   0,   255, 255),
         (255, 255, 255, 255),
-        ),
+    ),
     'green': (
         (0,   0,   0,   255),
         (0,   255, 0,   255),
         (255, 255, 255, 255),
-        ),
+    ),
     'bluegreen': (
         (0,   0,   0,   255),
         (255, 123, 0,   255),
         (255, 226, 72,  255),
         (161, 255, 0,   255),
         (255, 255, 255, 255),
-        ),
+    ),
     'transblack': (
         (0,   0,   0,   255),
         (0,   0,   0,   0),
-        ),
+    ),
     'royal': (
         (0,   0,   0,   255),
         (128, 0,   0,   255),
         (255, 0,   128, 255),
         (0,   255, 255, 255),
         (255, 255, 255, 255),
-        ),
+    ),
     'complement': (
         (0,   0,   0,   255),
         (0,   255, 0,   255),
@@ -114,7 +113,7 @@ _defaultmaps = {
         (0,   0,   255, 255),
         (0,   255, 255, 255),
         (255, 255, 255, 255),
-        ),
+    ),
 
     # from http://www.kennethmoreland.com/color-maps/
     'cool-warm': (
@@ -151,7 +150,7 @@ _defaultmaps = {
         (203, 62, 56, 255),
         (192, 40, 47, 255),
         (180, 4, 38, 255),
-        ),
+    ),
 
     # from http://geog.uoregon.edu/datagraphics/color_scales.htm
     'green-magenta': (
@@ -171,7 +170,7 @@ _defaultmaps = {
         (187, 0, 187, 255),
         (134, 0, 134, 255),
         (80, 0, 80, 255)
-        ),
+    ),
 
     'blue-darkred': (
         (216, 0, 36, 255),
@@ -192,7 +191,7 @@ _defaultmaps = {
         (53, 39, 247, 255),
         (47, 21, 216, 255),
         (33, 0, 165, 255)
-        ),
+    ),
 
     'blue-darkorange': (
         (102, 102, 0, 255),
@@ -213,7 +212,7 @@ _defaultmaps = {
         (0, 85, 204, 255),
         (0, 61, 153, 255),
         (0, 39, 102, 255)
-        ),
+    ),
 
     'brown-blue': (
         (0, 25, 51, 255),
@@ -228,7 +227,7 @@ _defaultmaps = {
         (255, 227, 50, 255),
         (204, 169, 0, 255),
         (153, 122, 0, 255)
-        ),
+    ),
 
     'blue-orange': (
         (255, 42, 0, 255),
@@ -243,7 +242,7 @@ _defaultmaps = {
         (50, 153, 255, 255),
         (25, 102, 255, 255),
         (0, 42, 255, 255)
-        ),
+    ),
 
     'seq': (
         (15, 15, 153, 255),
@@ -271,7 +270,7 @@ _defaultmaps = {
         (204, 81, 101, 255),
         (229, 126, 143, 255),
         (255, 178, 191, 255),
-        ),
+    ),
 
     # from https://github.com/visit-vis/VisIt/blob/master/avt/Pipeline/Data/avtColorTables.C
     'hot_desaturated': (
@@ -283,7 +282,7 @@ _defaultmaps = {
         (0,   96,  255, 255),
         (0,   0,   107, 255),
         (76,  76,  224, 255),
-        ),
+    ),
 
     # exported from VisIt color table (http://www.visitusers.org)
     'yellow-green': (
@@ -296,7 +295,7 @@ _defaultmaps = {
         (67,  132, 35,  255),
         (55,  104, 0,   255),
         (41,  69,  0,   255),
-        ),
+    ),
     'yellow-green-blue': (
         (217, 255, 255, 255),
         (177, 248, 237, 255),
@@ -307,7 +306,7 @@ _defaultmaps = {
         (168, 94,  34,  255),
         (148, 52,  37,  255),
         (88,  29,  8,   255),
-        ),
+    ),
     'yellow-orange-brown': (
         (229, 255, 255, 255),
         (188, 247, 255, 255),
@@ -318,7 +317,7 @@ _defaultmaps = {
         (2,   76,  204, 255),
         (4,   52,  153, 255),
         (6,   37,  102, 255),
-        ),
+    ),
     'yellow-orange-red': (
         (204, 255, 255, 255),
         (160, 237, 255, 255),
@@ -329,7 +328,23 @@ _defaultmaps = {
         (28,  26,  227, 255),
         (38,  0,   189, 255),
         (38,  0,   128, 255),
-        ),
+    ),
+
+    # https://iamkate.com/data/12-bit-rainbow/
+    'rainbow-12bit': (
+        (0x77, 0x11, 0x88, 0xff),
+        (0x55, 0x33, 0xaa, 0xff),
+        (0x66, 0x66, 0xcc, 0xff),
+        (0x44, 0x99, 0xee, 0xff),
+        (0x00, 0xdd, 0xee, 0xff),
+        (0x55, 0xdd, 0x99, 0xff),
+        (0x88, 0xdd, 0x44, 0xff),
+        (0xbb, 0xcc, 0x22, 0xff),
+        (0xcc, 0xbb, 0x00, 0xff),
+        (0xcc, 0x99, 0x00, 0xff),
+        (0xbb, 0x66, 0x33, 0xff),
+        (0x99, 0x33, 0x66, 0xff),
+    ),
 
     'none': (
         (255, 255, 255, 255),
@@ -786,7 +801,7 @@ def stepCMap(cmap, n):
 
     return N.vstack( ([-1,0,0,0], N.column_stack((b,g,r,a))) ).astype(N.intc)
 
-class ColorMaps(object):
+class ColorMaps:
     """Class representing defined color maps.
 
     This is initialised from the default list.
@@ -969,8 +984,9 @@ def applyColorMap(cmap, scaling, datain, minval, maxval,
     # apply transparency
     if trans != 0:
         cmap = cmap.copy()
-        cmap[:,3] = (cmap[:,3].astype(N.float32) * (100-trans) /
-                     100.).astype(N.intc)
+        cmap[:,3] = (
+            cmap[:,3].astype(N.float32) * (100-trans) /
+            100.).astype(N.intc)
 
     # apply scaling of data
     fracs = applyScaling(datain, scaling, minval, maxval)
@@ -1007,8 +1023,8 @@ def makeColorbarImage(minval, maxval, scaling, cmap, transparency,
         assert direction == 'vertical'
         vals = vals.reshape(barsize, 1)
 
-    img = applyColorMap(cmap, colorscaling, vals,
-                        minval, maxval, transparency)
+    img = applyColorMap(
+        cmap, colorscaling, vals, minval, maxval, transparency)
 
     return img
 
@@ -1021,7 +1037,7 @@ def getColormapArray(cmap, nvals):
     img = makeColorbarImage(0, 1, 'linear', cmap, 0, barsize=nvals)
 
     # ensure data are stored in the correct order
-    fmt = qt.QImage.Format_ARGB32
+    fmt = qt.QImage.Format.Format_ARGB32
     if img.format() != fmt:
         img = img.convertToFormat(fmt)
 
