@@ -78,7 +78,7 @@ def makeSplash(app):
     layout.setContentsMargins(h,h,h,h)
 
     # Center the spash screen
-    screen = app.screenAt(qt.QPoint()).size()
+    screen = splash.screen().size()
     splash.move(
         (screen.width()-layout.sizeHint().width())//2,
         (screen.height()-layout.sizeHint().height())//2
@@ -164,6 +164,9 @@ class VeuszApp(qt.QApplication):
         self.lastWindowClosed.connect(self.quit)
         self.signalException.connect(self.showException)
 
+        # Bind desktop file to display icon in wayland
+        qt.QGuiApplication.setDesktopFileName("veusz")
+
         # register a signal handler to catch ctrl+C
         signal.signal(signal.SIGINT, handleIntSignal)
 
@@ -335,6 +338,22 @@ class VeuszApp(qt.QApplication):
         except document.PluginLoadError as e:
             startuperrors.append(str(e))
 
+        # color theme
+        scheme = setting.settingdb['color_scheme']
+        hascolorscheme = hasattr(self.styleHints(), 'setColorScheme') # qt>=6.5
+        if scheme == 'default':
+            pass
+        elif scheme == 'system-light' and hascolorscheme:
+            self.styleHints().setColorScheme(qt.Qt.ColorScheme.Light)
+        elif scheme == 'system-dark' and hascolorscheme:
+            self.styleHints().setColorScheme(qt.Qt.ColorScheme.Dark)
+        else:
+            pal = utils.getPalette(scheme)
+            if pal is not None:
+                # palettes only work typically in fusion style
+                self.setStyle("fusion")
+                self.setPalette(pal)
+
         # different modes
         if args.listen:
             # listen to incoming commands
