@@ -18,12 +18,10 @@
 
 """For making box plots."""
 
-from __future__ import division
 import math
 import numpy as N
 
-from ..compat import crange, czip
-from .. import qtall as qt4
+from .. import qtall as qt
 from .. import setting
 from .. import document
 from .. import utils
@@ -32,7 +30,7 @@ from .plotters import GenericPlotter
 
 def _(text, disambiguation=None, context='BoxPlot'):
     """Translate text."""
-    return qt4.QCoreApplication.translate(context, text, disambiguation)
+    return qt.QCoreApplication.translate(context, text, disambiguation)
 
 def percentile(sortedds, perc):
     """Given a sorted dataset, get the percentile perc.
@@ -51,18 +49,18 @@ def percentile(sortedds, perc):
 def swapline(painter, x1, y1, x2, y2, swap):
     """Draw line, swapping x and y coordinates if swap is True."""
     if swap:
-        painter.drawLine( qt4.QPointF(y1, x1), qt4.QPointF(y2, x2) )
+        painter.drawLine( qt.QPointF(y1, x1), qt.QPointF(y2, x2) )
     else:
-        painter.drawLine( qt4.QPointF(x1, y1), qt4.QPointF(x2, y2) )
+        painter.drawLine( qt.QPointF(x1, y1), qt.QPointF(x2, y2) )
 
 def swapbox(painter, x1, y1, x2, y2, swap):
     """Return box, swapping x and y coordinates if swap is True."""
     if swap:
-        return qt4.QRectF(qt4.QPointF(y1, x1), qt4.QPointF(y2, x2))
+        return qt.QRectF(qt.QPointF(y1, x1), qt.QPointF(y2, x2))
     else:
-        return qt4.QRectF(qt4.QPointF(x1, y1), qt4.QPointF(x2, y2))
+        return qt.QRectF(qt.QPointF(x1, y1), qt.QPointF(x2, y2))
 
-class _Stats(object):
+class _Stats:
     """Store statistics about box."""
 
     def calculate(self, data, whiskermode):
@@ -79,7 +77,7 @@ class _Stats(object):
         self.botquart = percentile(cleaned, 25)
         self.topquart = percentile(cleaned, 75)
         self.mean = N.mean(cleaned)
-        
+
         if whiskermode == 'min/max':
             self.botwhisker = cleaned.min()
             self.topwhisker = cleaned.max()
@@ -87,7 +85,7 @@ class _Stats(object):
             iqr = self.topquart - self.botquart
             eltop = N.searchsorted(cleaned, self.topquart+1.5*iqr)-1
             self.topwhisker = cleaned[eltop]
-            elbot = max(N.searchsorted(cleaned, self.botquart-1.5*iqr)-1, 0)
+            elbot = max(N.searchsorted(cleaned, self.botquart-1.5*iqr), 0)
             self.botwhisker = cleaned[elbot]
         elif whiskermode == '1 stddev':
             stddev = N.std(cleaned)
@@ -118,106 +116,124 @@ class BoxPlot(GenericPlotter):
         GenericPlotter.addSettings(s)
 
         s.remove('key')
-        s.add( setting.Choice('whiskermode', 
-                              ('min/max',
-                               '1.5IQR',
-                               '1 stddev',
-                               '9/91 percentile',
-                               '2/98 percentile'),
-                              '1.5IQR', 
-                              descr = _('Whisker mode'), 
-                              usertext=_('Whisker mode')), 0 )
+        s.add( setting.Choice(
+            'whiskermode',
+            (
+                'min/max',
+                '1.5IQR',
+                '1 stddev',
+                '9/91 percentile',
+                '2/98 percentile'
+            ),
+            '1.5IQR',
+            descr=_('Whisker mode'),
+            usertext=_('Whisker mode')), 0 )
 
-        s.add( setting.Choice('direction', 
-                              ('horizontal', 'vertical'), 'vertical', 
-                              descr = _('Horizontal or vertical boxes'), 
-                              usertext=_('Direction')), 0 )
-        s.add( setting.DatasetOrStr('labels', '',
-                                    descr=_('Dataset or string to label bars'),
-                                    usertext=_('Labels')), 0 )
+        s.add( setting.Choice(
+            'direction',
+            ('horizontal', 'vertical'), 'vertical',
+            descr=_('Horizontal or vertical boxes'),
+            usertext=_('Direction')), 0 )
+        s.add( setting.DatasetOrStr(
+            'labels', '',
+            descr=_('Dataset or string to label bars'),
+            usertext=_('Labels')), 0 )
         s.add( setting.DatasetExtended(
-                'posn', '',
-                descr = _('Dataset or list of values giving '
-                          'positions of boxes (optional)'),
-                usertext=_('Positions')), 0 )
+            'posn', '',
+            descr=_(
+                'Dataset or list of values giving positions of boxes (optional)'),
+            usertext=_('Positions')), 0 )
 
         # calculate statistics from these datasets
-        s.add( setting.Datasets('values', ('data',),
-                                descr = _('Datasets containing values to '
-                                          'calculate statistics for'),
-                                usertext=_('Datasets')), 0 )
+        s.add( setting.Datasets(
+            'values', ('data',),
+            descr=_('Datasets containing values to calculate statistics for'),
+            usertext=_('Datasets')), 0 )
 
         # alternate mode where data are provided for boxes
         s.add( setting.DatasetExtended(
-                'whiskermax', '',
-                descr=_('Dataset with whisker maxima or list of values'),
-                usertext=_('Whisker max')), 0 )
+            'whiskermax', '',
+            descr=_('Dataset with whisker maxima or list of values'),
+            usertext=_('Whisker max')), 0 )
         s.add( setting.DatasetExtended(
-                'whiskermin', '',
-                descr=_('Dataset with whisker minima or list of values'),
-                usertext=_('Whisker min')), 0 )
+            'whiskermin', '',
+            descr=_('Dataset with whisker minima or list of values'),
+            usertext=_('Whisker min')), 0 )
         s.add( setting.DatasetExtended(
-                'boxmax', '',
-                descr=_('Dataset with box maxima or list of values'),
-                usertext=_('Box max')), 0 )
+            'boxmax', '',
+            descr=_('Dataset with box maxima or list of values'),
+            usertext=_('Box max')), 0 )
         s.add( setting.DatasetExtended(
-                'boxmin', '',
-                descr=_('Dataset with box minima or list of values'),
-                usertext=_('Box min')), 0 )
+            'boxmin', '',
+            descr=_('Dataset with box minima or list of values'),
+            usertext=_('Box min')), 0 )
         s.add( setting.DatasetExtended(
-                'median', '',
-                descr=_('Dataset with medians or list of values'),
-                usertext=_('Median')), 0 )
+            'median', '',
+            descr=_('Dataset with medians or list of values'),
+            usertext=_('Median')), 0 )
         s.add( setting.DatasetExtended(
-                'mean', '',
-                descr=_('Dataset with means or list of values'),
-                usertext=_('Mean')), 0 )
+            'mean', '',
+            descr=_('Dataset with means or list of values'),
+            usertext=_('Mean')), 0 )
 
         # switch between different modes
-        s.add( setting.BoolSwitch('calculate', True,
-                                  descr = _('Calculate statistics from datasets'
-                                            ' rather than given manually'),
-                                  usertext = _('Calculate'),
-                                  settingstrue=('whiskermode', 'values'),
-                                  settingsfalse=('boxmin', 'whiskermin',
-                                                 'boxmax', 'whiskermax',
-                                                 'mean', 'median')), 0 )
+        s.add( setting.BoolSwitch(
+            'calculate', True,
+            descr=_(
+                'Calculate statistics from datasets rather than given manually'),
+            usertext=_('Calculate'),
+            settingstrue=('whiskermode', 'values'),
+            settingsfalse=(
+                'boxmin', 'whiskermin',
+                'boxmax', 'whiskermax',
+                'mean', 'median')), 0 )
 
         # formatting options
-        s.add( setting.Float('fillfraction', 0.75,
-                             descr = _('Fill fraction of boxes'),
-                             usertext=_('Fill fraction'), formatting=True) )
-        s.add( setting.Marker('outliersmarker',
-                              'circle',
-                              descr = _('Marker for outliers'),
-                              usertext=_('Outliers'), formatting=True) )
-        s.add( setting.Marker('meanmarker',
-                              'linecross',
-                              descr = _('Marker for mean'),
-                              usertext=_('Mean'), formatting=True) )
-        s.add( setting.DistancePt('markerSize',
-                                  '3pt',
-                                  descr = _('Size of markers to plot'),
-                                  usertext=_('Markers size'), formatting=True) )
+        s.add( setting.Float(
+            'fillfraction', 0.75,
+            descr=_('Fill fraction of boxes'),
+            usertext=_('Fill fraction'), formatting=True) )
+        s.add( setting.Marker(
+            'outliersmarker',
+            'circle',
+            descr=_('Marker for outliers'),
+            usertext=_('Outliers'), formatting=True) )
+        s.add( setting.Marker(
+            'meanmarker',
+            'linecross',
+            descr=_('Marker for mean'),
+            usertext=_('Mean'), formatting=True) )
+        s.add( setting.DistancePt(
+            'markerSize',
+            '3pt',
+            descr=_('Size of markers to plot'),
+            usertext=_('Markers size'), formatting=True) )
 
-        s.add( setting.GraphBrush( 'Fill',
-                                   descr = _('Box fill'),
-                                   usertext=_('Box fill')),
-               pixmap='settings_bgfill' )
-        s.add( setting.Line('Border', descr = _('Box border line'),
-                            usertext=_('Box border')),
-               pixmap='settings_border')
-        s.add( setting.Line('Whisker', descr = _('Whisker line'),
-                            usertext=_('Whisker line')),
-               pixmap='settings_whisker')
-        s.add( setting.Line('MarkersLine',
-                            descr = _('Line around markers'),
-                            usertext = _('Markers border')),
-               pixmap = 'settings_plotmarkerline' )
-        s.add( setting.BoxPlotMarkerFillBrush('MarkersFill',
-                                              descr = _('Markers fill'),
-                                              usertext = _('Markers fill')),
-               pixmap = 'settings_plotmarkerfill' )
+        s.add( setting.GraphBrush(
+            'Fill',
+            descr=_('Box fill'),
+            usertext=_('Box fill')),
+            pixmap='settings_bgfill' )
+        s.add( setting.Line(
+            'Border',
+            descr=_('Box border line'),
+            usertext=_('Box border')),
+            pixmap='settings_border')
+        s.add( setting.Line(
+            'Whisker',
+            descr=_('Whisker line'),
+            usertext=_('Whisker line')),
+            pixmap='settings_whisker')
+        s.add( setting.Line(
+            'MarkersLine',
+            descr=_('Line around markers'),
+            usertext=_('Markers border')),
+            pixmap='settings_plotmarkerline' )
+        s.add( setting.BoxPlotMarkerFillBrush(
+            'MarkersFill',
+            descr=_('Markers fill'),
+            usertext=_('Markers fill')),
+            pixmap='settings_plotmarkerfill' )
 
     @property
     def userdescription(self):
@@ -235,8 +251,8 @@ class BoxPlot(GenericPlotter):
         """For updating range in manual mode."""
         s = self.settings
         ds = []
-        for name in ('whiskermin', 'whiskermax', 'boxmin', 'boxmax',
-                     'mean', 'median'):
+        for name in (
+                'whiskermin', 'whiskermax', 'boxmin', 'boxmax', 'mean', 'median'):
             ds.append( s.get(name).getData(self.document) )
         r = [N.inf, -N.inf]
         if None not in ds:
@@ -325,34 +341,39 @@ class BoxPlot(GenericPlotter):
         medplt, botplt, topplt, botwhisplt, topwhisplt = tuple(
             axes[not horz].dataToPlotterCoords(
                 posn,
-                N.array([ stats.median, stats.botquart, stats.topquart,
-                          stats.botwhisker, stats.topwhisker ]))
-            )
+                N.array([
+                    stats.median, stats.botquart, stats.topquart,
+                    stats.botwhisker, stats.topwhisker
+                ]))
+        )
 
         # draw whisker top to bottom
         p = s.Whisker.makeQPenWHide(painter)
-        p.setCapStyle(qt4.Qt.FlatCap)
+        p.setCapStyle(qt.Qt.PenCapStyle.FlatCap)
         painter.setPen(p)
         swapline(painter, boxposn, topwhisplt, boxposn, botwhisplt, horz)
         # draw ends of whiskers
         endsize = width/2
-        swapline(painter, boxposn-endsize/2, topwhisplt,
-                 boxposn+endsize/2, topwhisplt, horz)
-        swapline(painter, boxposn-endsize/2, botwhisplt,
-                 boxposn+endsize/2, botwhisplt, horz)
+        swapline(
+            painter, boxposn-endsize/2, topwhisplt,
+            boxposn+endsize/2, topwhisplt, horz)
+        swapline(
+            painter, boxposn-endsize/2, botwhisplt,
+            boxposn+endsize/2, botwhisplt, horz)
 
         # draw box fill
-        boxpath = qt4.QPainterPath()
-        boxpath.addRect( swapbox(painter, boxposn-width/2, botplt,
-                                 boxposn+width/2, topplt, horz) )
+        boxpath = qt.QPainterPath()
+        boxpath.addRect( swapbox(
+            painter, boxposn-width/2, botplt, boxposn+width/2, topplt, horz) )
         utils.brushExtFillPath(painter, s.Fill, boxpath)
 
         # draw line across box
         p = s.Whisker.makeQPenWHide(painter)
-        p.setCapStyle(qt4.Qt.FlatCap)
+        p.setCapStyle(qt.Qt.PenCapStyle.FlatCap)
         painter.setPen(p)
-        swapline(painter, boxposn-width/2, medplt,
-                 boxposn+width/2, medplt, horz)
+        swapline(
+            painter, boxposn-width/2, medplt,
+            boxposn+width/2, medplt, horz)
 
         # draw box
         painter.strokePath(boxpath, s.Border.makeQPenWHide(painter) )
@@ -369,8 +390,8 @@ class BoxPlot(GenericPlotter):
             else:
                 x, y = otherpos, pltvals
 
-            utils.plotMarkers( painter, x, y, s.outliersmarker,
-                               markersize, clip=clip )
+            utils.plotMarkers(
+                painter, x, y, s.outliersmarker, markersize, clip=clip )
 
         # draw mean
         meanplt = axes[not horz].dataToPlotterCoords(
@@ -396,9 +417,10 @@ class BoxPlot(GenericPlotter):
                 return
         else:
             # use manual datasets
-            datasets = [ s.get(x).getData(doc) for x in
-                         ('whiskermin', 'whiskermax', 'boxmin',
-                          'boxmax', 'mean', 'median') ]
+            datasets = [
+                s.get(x).getData(doc) for x in
+                ('whiskermin', 'whiskermax', 'boxmin', 'boxmax', 'mean', 'median')
+            ]
             if any((d is None for d in datasets)):
                 return
 
@@ -435,16 +457,17 @@ class BoxPlot(GenericPlotter):
 
         if s.calculate:
             # calculated boxes
-            for vals, plotpos in czip(values, plotposns):
+            for vals, plotpos in zip(values, plotposns):
                 stats = _Stats()
                 stats.calculate(vals.data, s.whiskermode)
-                self.plotBox(painter, axes, plotpos, widgetposn, width,
-                             clip, stats)
+                self.plotBox(
+                    painter, axes, plotpos, widgetposn, width,
+                    clip, stats)
         else:
             # manually given boxes
             vals = [d.data for d in datasets] + [plotposns]
             lens = [len(d) for d in vals]
-            for i in crange(min(lens)):
+            for i in range(min(lens)):
                 stats = _Stats()
                 stats.topwhisker = vals[0][i]
                 stats.botwhisker = vals[1][i]
@@ -453,8 +476,9 @@ class BoxPlot(GenericPlotter):
                 stats.mean = vals[4][i]
                 stats.median = vals[5][i]
                 stats.outliers = N.array([])
-                self.plotBox(painter, axes, vals[6][i], widgetposn,
-                             width, clip, stats)
+                self.plotBox(
+                    painter, axes, vals[6][i], widgetposn,
+                    width, clip, stats)
 
 # allow the factory to instantiate a boxplot
-document.thefactory.register( BoxPlot )
+document.thefactory.register(BoxPlot)
