@@ -1,4 +1,3 @@
-# fit.py
 # fitting plotter
 
 #    Copyright (C) 2005 Jeremy S. Sanders
@@ -19,13 +18,11 @@
 #    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 ###############################################################################
 
-from __future__ import division, absolute_import, print_function
 import re
 import sys
 
 import numpy as N
 
-from ..compat import czip, cstr
 from .. import document
 from .. import setting
 from .. import utils
@@ -43,6 +40,13 @@ except ImportError:
     except ImportError:
         minuit = None
 
+# Check whether iminuit version is old (1.x)
+if minuit is not None:
+    if minuit.__version__[0:1] == '1':
+        isiminuit1 = True
+    else:
+        isiminuit1 = False
+
 def _(text, disambiguation=None, context='Fit'):
     """Translate text."""
     return qt.QCoreApplication.translate(context, text, disambiguation)
@@ -71,6 +75,9 @@ def minuitFit(evalfunc, params, names, values, xvals, yvals, yserr):
     print(_('Fitting via Minuit:'))
     m = minuit.Minuit(fn, **values)
 
+    # set errordef explicitly (least-squares: 1.0 or log-likelihood: 0.5)
+    m.errordef = 1.0
+
     # run the fit
     chi2.runningFit = True
     chi2.iters = 0
@@ -96,23 +103,28 @@ def minuitFit(evalfunc, params, names, values, xvals, yvals, yserr):
     redchi2 = retchi2 / dof
 
     if have_err:
-        print(_('Fit results:\n') + "\n".join([
-                    u"    %s = %g \u00b1 %g (+%g / %g)"
-                    % (n, m.values[n], m.errors[n], m.merrors[(n, 1.0)],
-                       m.merrors[(n, -1.0)]) for n in names]))
+        if isiminuit1:
+            results = ["    %s = %g \u00b1 %g (+%g / %g)" % (
+                n, m.values[n], m.errors[n], m.merrors[(n, 1.0)],
+                m.merrors[(n, -1.0)]) for n in names]
+        else:
+            results = ["    %s = %g \u00b1 %g (+%g / %g)" % (
+                n, m.values[n], m.errors[n], m.merrors[n].upper,
+                m.merrors[n].lower) for n in names]
+        print(_('Fit results:\n') + "\n".join(results))
     elif have_symerr:
         print(_('Fit results:\n') + "\n".join([
-                    u"    %s = %g \u00b1 %g" % (n, m.values[n], m.errors[n])
-                    for n in names]))
+            "    %s = %g \u00b1 %g" % (n, m.values[n], m.errors[n])
+            for n in names]))
         print(_('MINOS error estimate not available.'))
     else:
         print(_('Fit results:\n') + "\n".join([
-                    '    %s = %g' % (n, m.values[n]) for n in names]))
+            '    %s = %g' % (n, m.values[n]) for n in names]))
         print(_('No error analysis available: fit quality uncertain'))
 
     print("chi^2 = %g, dof = %i, reduced-chi^2 = %g" % (retchi2, dof, redchi2))
 
-    vals = dict(m.values)
+    vals = {name:m.values[name] for name in names}
     return vals, retchi2, dof
 
 class Fit(FunctionPlotter):
@@ -125,9 +137,10 @@ class Fit(FunctionPlotter):
     def __init__(self, parent, name=None):
         FunctionPlotter.__init__(self, parent, name=name)
 
-        self.addAction( widget.Action('fit', self.actionFit,
-                                      descr = _('Fit function'),
-                                      usertext = _('Fit function')) )
+        self.addAction( widget.Action(
+            'fit', self.actionFit,
+            descr=_('Fit function'),
+            usertext=_('Fit function')) )
 
     @classmethod
     def addSettings(klass, s):
@@ -135,59 +148,71 @@ class Fit(FunctionPlotter):
         FunctionPlotter.addSettings(s)
 
         s.add( setting.FloatDict(
-                'values',
-                {'a': 0.0, 'b': 1.0},
-                descr = _('Variables and fit values'),
-                usertext=_('Parameters')), 1 )
+            'values',
+            {'a': 0.0, 'b': 1.0},
+            descr=_('Variables and fit values'),
+            usertext=_('Parameters')), 1 )
         s.add( setting.DatasetExtended(
-                'xData', 'x',
-                descr = _('X data to fit (dataset name, list of values '
-                          'or expression)'),
-                usertext=_('X data')), 2 )
+            'xData', 'x',
+            descr=_('X data to fit (dataset name, list of values or expression)'),
+            usertext=_('X data')), 2 )
         s.add( setting.DatasetExtended(
-                'yData', 'y',
-                descr = _('Y data to fit (dataset name, list of values '
-                          'or expression)'),
-                usertext=_('Y data')), 3 )
+            'yData', 'y',
+            descr=_('Y data to fit (dataset name, list of values or expression)'),
+            usertext=_('Y data')), 3 )
+        s.add( setting.Choice(
+            'defErrType', ['absolute', 'relative'], 'absolute',
+            descr=_('Default error type'),
+            usertext=_('Def. error type')) )
+        s.add( setting.Float(
+            'defErr', 0.05,
+            descr = 'Default absolute/relative error value for data',
+            usertext=_('Default error')))
+        s.add(setting.FloatOrAuto(
+            'fitMin', 'Auto',
+            descr=_('Minimum value at which to fit function'),
+            usertext=_('Min. fit range')))
+        s.add(setting.FloatOrAuto(
+            'fitMax', 'Auto',
+            descr=_('Maximum value at which to fit function'),
+            usertext=_('Max. fit range')))
+
         s.add( setting.Bool(
-                'fitRange', False,
-                descr = _('Fit only the data between the '
-                          'minimum and maximum of the axis for '
-                          'the function variable'),
-                usertext=_('Fit only range')),
-               4 )
+            'fitRange', False,
+            descr=_(
+                'Fit only the data between the minimum and maximum '
+                'of the axis for the function variable'),
+            usertext=_('Fit only range')), 4 )
         s.add( setting.WidgetChoice(
-                'outLabel', '',
-                descr=_('Write best fit parameters to this text label '
-                        'after fitting'),
-                widgettypes=('label',),
-                usertext=_('Output label')),
-               5 )
-        s.add( setting.Str('outExpr', '',
-                           descr = _('Output best fitting expression'),
-                           usertext=_('Output expression')),
-               6, readonly=True )
-        s.add( setting.Float('chi2', -1,
-                             descr = 'Output chi^2 from fitting',
-                             usertext=_('Fit &chi;<sup>2</sup>')),
-               7, readonly=True )
-        s.add( setting.Int('dof', -1,
-                           descr = _('Output degrees of freedom from fitting'),
-                           usertext=_('Fit d.o.f.')),
-               8, readonly=True )
-        s.add( setting.Float('redchi2', -1,
-                             descr = _('Output reduced-chi-squared from fitting'),
-                             usertext=_('Fit reduced &chi;<sup>2</sup>')),
-               9, readonly=True )
+            'outLabel', '',
+            descr=_('Write best fit parameters to this text label after fitting'),
+            widgettypes=('label',),
+            usertext=_('Output label')), 5 )
+        s.add( setting.Str(
+            'outExpr', '',
+            descr=_('Output best fitting expression'),
+            usertext=_('Output expression')),
+            6, readonly=True )
+        s.add( setting.Float(
+            'chi2', -1,
+            descr='Output chi^2 from fitting',
+            usertext=_('Fit &chi;<sup>2</sup>')),
+            7, readonly=True )
+        s.add( setting.Int(
+            'dof', -1,
+            descr=_('Output degrees of freedom from fitting'),
+            usertext=_('Fit d.o.f.')),
+            8, readonly=True )
+        s.add( setting.Float(
+            'redchi2', -1,
+            descr=_('Output reduced-chi-squared from fitting'),
+            usertext=_('Fit reduced &chi;<sup>2</sup>')),
+            9, readonly=True )
 
         f = s.get('function')
         f.newDefault('a + b*x')
         f.descr = _('Function to fit')
 
-        # modify description
-        s.get('min').usertext=_('Min. fit range')
-        s.get('max').usertext=_('Max. fit range')
-
     def affectsAxisRange(self):
         """This widget provides range information about these axes."""
         s = self.settings
@@ -223,14 +248,14 @@ class Fit(FunctionPlotter):
                 txt.append( '%s = %s' % (l, val) )
             # add chi2 output
             txt.append( r'\chi^{2}_{\nu} = %s/%i = %s' % (
-                    utils.formatNumber(chi2, '%.4Vg', locale=loc),
-                    dof,
-                    utils.formatNumber(chi2/dof, '%.4Vg', locale=loc) ))
+                utils.formatNumber(chi2, '%.4Vg', locale=loc),
+                dof,
+                utils.formatNumber(chi2/dof, '%.4Vg', locale=loc) ))
 
             # update label with text
             text = r'\\'.join(txt)
             ops.append( document.OperationSettingSet(
-                    labelwidget.settings.get('label') , text ) )
+                labelwidget.settings.get('label') , text ) )
 
     def actionFit(self):
         """Fit the data."""
@@ -265,9 +290,14 @@ class Fit(FunctionPlotter):
                 print("Warning: Symmeterising positive and negative errors")
                 yserr = N.sqrt( 0.5*(ydata.perr**2 + ydata.nerr**2) )
             else:
-                print("Warning: No errors on y values. Assuming 5% errors.")
-                yserr = yvals*0.05
-                yserr[yserr < 1e-8] = 1e-8
+                err = s.defErr
+                if s.defErrType == 'absolute':
+                    print(f"Warning: No errors on values. Assuming absolute {err} errors.")
+                    yserr = err + yvals*0
+                else: # relative
+                    print(f"Warning: No errors on values. Assuming fractional {err} errors.")
+                    yserr = yvals*err
+                    yserr[yserr < 1e-8] = 1e-8
 
         # if the fitRange parameter is on, we chop out data outside the
         # range of the axis
@@ -280,39 +310,41 @@ class Fit(FunctionPlotter):
                 drange = self.parent.getAxes((s.yAxis,))[0].getPlottedRange()
                 mask = N.logical_and(yvals >= drange[0], yvals <= drange[1])
             xvals, yvals, yserr = xvals[mask], yvals[mask], yserr[mask]
-            print("Fitting %s from %g to %g" % (s.variable,
-                                                drange[0], drange[1]))
+            print("Fitting %s from %g to %g" % (
+                s.variable, drange[0], drange[1]))
 
         evalenv = self.initEnviron()
         def evalfunc(params, xvals):
             # update environment with variable and parameters
             evalenv[self.settings.variable] = xvals
-            evalenv.update( czip(paramnames, params) )
+            evalenv.update( zip(paramnames, params) )
 
             try:
                 return eval(compiled, evalenv) + xvals*0.
             except Exception as e:
-                self.document.log(cstr(e))
+                self.document.log(str(e))
                 return N.nan
 
         # minimum set for fitting
-        if s.min != 'Auto':
+        if s.fitMin != 'Auto':
             if s.variable == 'x':
-                mask = xvals >= s.min
+                mask = xvals >= s.fitMin
             else:
-                mask = yvals >= s.min
+                mask = yvals >= s.fitMin
             xvals, yvals, yserr = xvals[mask], yvals[mask], yserr[mask]
 
         # maximum set for fitting
-        if s.max != 'Auto':
+        if s.fitMax != 'Auto':
             if s.variable == 'x':
-                mask = xvals <= s.max
+                mask = xvals <= s.fitMax
             else:
-                mask = yvals <= s.max
+                mask = yvals <= s.fitMax
             xvals, yvals, yserr = xvals[mask], yvals[mask], yserr[mask]
 
-        if s.min != 'Auto' or s.max != 'Auto':
-            print("Fitting %s between %s and %s" % (s.variable, s.min, s.max))
+        if s.fitMin != 'Auto' or s.fitMax != 'Auto':
+            print(
+                "Fitting %s between %s and %s"
+                % (s.variable, s.fitMin, s.fitMax))
 
         # various error checks
         if len(xvals) != len(yvals) or len(xvals) != len(yserr):
@@ -346,7 +378,7 @@ class Fit(FunctionPlotter):
             retn, chi2, dof = utils.fitLM(
                 evalfunc, params, xvals, yvals, yserr)
             vals = {}
-            for i, v in czip(paramnames, retn):
+            for i, v in zip(paramnames, retn):
                 vals[i] = float(v)
 
         # list of operations do we can undo the changes
@@ -403,4 +435,4 @@ class Fit(FunctionPlotter):
         return ''.join(parts)
 
 # allow the factory to instantiate an x,y plotter
-document.thefactory.register( Fit )
+document.thefactory.register(Fit)
