@@ -18,10 +18,8 @@
 
 """For plotting numerical functions."""
 
-from __future__ import division
 import numpy as N
 
-from ..compat import czip, cstr
 from .. import qtall as qt
 from .. import document
 from .. import setting
@@ -46,18 +44,23 @@ class FunctionPlotter(GenericPlotter):
         """Construct list of settings."""
         GenericPlotter.addSettings(s)
 
+        s.add( setting.Color(
+            'color',
+            'auto',
+            descr=_('Master color'),
+            usertext=_('Color'),
+            formatting=True), 0 )
         s.add( setting.Int(
             'steps',
             50,
             minval = 3,
-            descr = _('Number of steps to evaluate the function'
-                      ' over'),
-            usertext=_('Steps'), formatting=True), 0 )
+            descr = _('Number of steps to evaluate the function over'),
+            usertext=_('Steps'), formatting=True), 1 )
+
         s.add( setting.Choice(
             'variable', ['x', 'y'], 'x',
             descr=_('Variable the function is a function of'),
-            usertext=_('Variable')),
-               0 )
+            usertext=_('Variable')), 0 )
         s.add( setting.Str(
             'function', 'x',
             descr=_('Function expression'),
@@ -75,21 +78,29 @@ class FunctionPlotter(GenericPlotter):
 
         s.add( setting.Line(
             'Line',
-            descr = _('Function line settings'),
-            usertext = _('Plot line')),
-               pixmap = 'settings_plotline' )
-        s.Line.get('color').newDefault('auto')
+            descr=_('Function line settings'),
+            usertext=_('Plot line')),
+            pixmap='settings_plotline' )
+        s.Line.get('color').newDefault(setting.Reference('../color'))
 
         s.add( setting.PlotterFill(
             'FillBelow',
-            descr = _('Fill below/left function'),
-            usertext = _('Fill below')),
-               pixmap = 'settings_plotfillbelow' )
+            descr=_('Fill below/left function'),
+            usertext=_('Fill below')),
+            pixmap='settings_plotfillbelow' )
         s.add( setting.PlotterFill(
             'FillAbove',
-            descr = _('Fill mode above/right function'),
-            usertext = _('Fill above')),
-               pixmap = 'settings_plotfillabove' )
+            descr=_('Fill mode above/right function'),
+            usertext=_('Fill above')),
+            pixmap='settings_plotfillabove' )
+
+    @classmethod
+    def addSettingsCompatLevel(klass, s, level):
+        if level >= 1:
+            s.FillBelow.get('color').newDefault(
+                setting.Reference('../color') )
+            s.FillAbove.get('color').newDefault(
+                setting.Reference('../color') )
 
     @property
     def userdescription(self):
@@ -100,7 +111,7 @@ class FunctionPlotter(GenericPlotter):
         """Write error message to document log for exception ex."""
         self.document.log(
             "Error evaluating expression in function widget '%s': '%s'" % (
-                self.name, cstr(ex)))
+                self.name, str(ex)))
 
     def affectsAxisRange(self):
         s = self.settings
@@ -191,7 +202,7 @@ class FunctionPlotter(GenericPlotter):
         # or reach the end, then plot them
         pts = qt.QPolygonF()
         lastx = lasty = -65536
-        for x, y in czip(xpts, ypts):
+        for x, y in zip(xpts, ypts):
 
             # ignore point if it outside sensible bounds
             if x < -32767 or y < -32767 or x > 32767 or y > 32767:
@@ -364,7 +375,7 @@ class FunctionPlotter(GenericPlotter):
         (xpts, ypts), (pxpts, pypts) = self.calcFunctionPoints(axes, posn)
 
         return pickable.GenericPickable(
-                    self, axisnames, (xpts, ypts), (pxpts, pypts) )
+            self, axisnames, (xpts, ypts), (pxpts, pypts) )
 
     def pickPoint(self, x0, y0, bounds, distance='radial'):
         return self._pickable(bounds).pickPoint(x0, y0, bounds, distance)
@@ -393,16 +404,16 @@ class FunctionPlotter(GenericPlotter):
             painter.setFont(f)
             painter.drawText(
                 cliprect,
-                qt.Qt.AlignCenter,
+                qt.Qt.AlignmentFlag.AlignCenter,
                 "Cannot evaluate '%s'" % s.function)
         else:
             if not s.FillBelow.hide:
-                self._fillRegion(painter, pxpts, pypts, posn, True, cliprect,
-                                 s.FillBelow)
+                self._fillRegion(
+                    painter, pxpts, pypts, posn, True, cliprect, s.FillBelow)
 
             if not s.FillAbove.hide:
-                self._fillRegion(painter, pxpts, pypts, posn, False, cliprect,
-                                 s.FillAbove)
+                self._fillRegion(
+                    painter, pxpts, pypts, posn, False, cliprect, s.FillAbove)
 
             if not s.Line.hide:
                 painter.setBrush( qt.QBrush() )
@@ -410,4 +421,4 @@ class FunctionPlotter(GenericPlotter):
                 self._plotLine(painter, pxpts, pypts, posn, cliprect)
 
 # allow the factory to instantiate an function plotter
-document.thefactory.register( FunctionPlotter )
+document.thefactory.register(FunctionPlotter)
