@@ -18,10 +18,8 @@
 #    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 ###############################################################################
 
-from __future__ import division
 import math
 
-from ..compat import crange, citems
 from .. import qtall as qt
 from .. import document
 from .. import setting
@@ -37,7 +35,7 @@ def _(text, disambiguation=None, context='Key'):
 #############################################################################
 # classes for controlling key position interactively
 
-class ControlKey(object):
+class ControlKey:
     """Control the position of a key on a plot."""
 
     def __init__( self, widget, phelper, parentposn,
@@ -73,10 +71,10 @@ class _GraphControlKey(qt.QGraphicsRectItem, controlgraph._ScaledShape):
             params.dims[0], params.dims[1]
         )
 
-        self.setCursor(qt.Qt.SizeAllCursor)
+        self.setCursor(qt.Qt.CursorShape.SizeAllCursor)
         self.setZValue(1.)
-        self.setFlag(qt.QGraphicsItem.ItemIsMovable)
-        self.highlightpen = qt.QPen(qt.Qt.red, 2, qt.Qt.DotLine)
+        self.setFlag(qt.QGraphicsItem.GraphicsItemFlag.ItemIsMovable)
+        self.highlightpen = qt.QPen(qt.Qt.GlobalColor.red, 2, qt.Qt.PenStyle.DotLine)
 
         pposn, dims = params.parentposn, params.dims
         th = params.textheight
@@ -95,8 +93,8 @@ class _GraphControlKey(qt.QGraphicsRectItem, controlgraph._ScaledShape):
 
         # these are special places where the key is aligned
         self.highlightpoints = {}
-        for xname, xval in citems(xposn):
-            for yname, yval in citems(yposn):
+        for xname, xval in xposn.items():
+            for yname, yval in yposn.items():
                 self.highlightpoints[(xname, yname)] = qt.QPointF(
                     xval*params.cgscale, yval*params.cgscale)
 
@@ -111,7 +109,7 @@ class _GraphControlKey(qt.QGraphicsRectItem, controlgraph._ScaledShape):
 
         highlight = None
         highlightrect = qt.QRectF(rect.left()-10, rect.top()-10, 20, 20)
-        for name, point in citems(self.highlightpoints):
+        for name, point in self.highlightpoints.items():
             if highlightrect.contains(point):
                 highlight = name
                 break
@@ -174,9 +172,9 @@ class Key(widget.Widget):
 
         s.add( setting.Text(
             'Text',
-            descr = _('Text settings'),
+            descr=_('Text settings'),
             usertext=_('Text')),
-               pixmap = 'settings_axislabel' )
+            pixmap='settings_axislabel' )
 
         s.add( setting.Str(
             'order', '',
@@ -195,71 +193,71 @@ class Key(widget.Widget):
 
         s.add( setting.KeyBrush(
             'Background',
-            descr = _('Key background fill'),
+            descr=_('Key background fill'),
             usertext=_('Background')),
-               pixmap = 'settings_bgfill' )
+            pixmap='settings_bgfill' )
         s.add( setting.Line(
             'Border',
-            descr = _('Key border line'),
+            descr=_('Key border line'),
             usertext=_('Border')),
-               pixmap = 'settings_border' )
+            pixmap='settings_border' )
 
         s.add( setting.AlignHorzWManual(
             'horzPosn',
             'right',
-            descr = _('Horizontal key position'),
+            descr=_('Horizontal key position'),
             usertext=_('Horz posn'),
             formatting=True) )
         s.add( setting.AlignVertWManual(
             'vertPosn',
             'bottom',
-            descr = _('Vertical key position'),
+            descr=_('Vertical key position'),
             usertext=_('Vert posn'),
             formatting=True) )
 
         s.add( setting.Distance(
             'keyLength',
             '1cm',
-            descr = _('Length of line to show in sample'),
+            descr=_('Length of line to show in sample'),
             usertext=_('Key length'),
             formatting=True) )
 
         s.add( setting.AlignVert(
             'keyAlign',
             'top',
-            descr = _('Alignment of key symbols relative to text'),
-            usertext = _('Key alignment'),
+            descr=_('Alignment of key symbols relative to text'),
+            usertext=_('Key alignment'),
             formatting=True) )
 
         s.add( setting.Float(
             'horzManual',
             0.,
-            descr = _('Manual horizontal fractional position'),
+            descr=_('Manual horizontal fractional position'),
             usertext=_('Horz manual'),
             formatting=True) )
         s.add( setting.Float(
             'vertManual',
             0.,
-            descr = _('Manual vertical fractional position'),
+            descr=_('Manual vertical fractional position'),
             usertext=_('Vert manual'),
             formatting=True) )
 
         s.add( setting.Float(
             'marginSize',
             1.,
-            minval = 0.,
-            descr = _('Width of margin in characters'),
+            minval=0.,
+            descr=_('Width of margin in characters'),
             usertext=_('Margin size'),
             formatting=True) )
 
         s.add( setting.Int(
             'columns',
             1,
-            descr = _('Number of columns in key'),
-            usertext = _('Columns'),
-            minval = 1,
-            maxval = 100,
-            formatting = True) )
+            descr=_('Number of columns in key'),
+            usertext=_('Columns'),
+            minval=1,
+            maxval=100,
+            formatting=True) )
 
         s.add( setting.Bool(
             'symbolswap',
@@ -339,14 +337,14 @@ class Key(widget.Widget):
             victimcol = numcols
             while True:
                 # find the right-most column with excess occupation number
-                for i in reversed(crange(victimcol)):
+                for i in reversed(range(victimcol)):
                     if colstats[i] > meanoccupation:
                         victimcol = i
                         break
 
                 # find the last item in the victim column
                 victim = 0
-                for i in reversed(crange(len(layout))):
+                for i in reversed(range(len(layout))):
                     if layout[i][2] == victimcol:
                         victim = i
                         break
@@ -438,7 +436,7 @@ class Key(widget.Widget):
                 continue
 
             # add an entry for each key entry for each widget
-            for i in crange(num):
+            for i in range(num):
                 lines = 1
                 if showtext:
                     w, h = utils.Renderer(
@@ -562,4 +560,4 @@ class Key(widget.Widget):
             [ControlKey(self, phelper, parentposn, boxposn, boxdims, height)]
         )
 
-document.thefactory.register( Key )
+document.thefactory.register(Key)
