@@ -18,12 +18,11 @@
 
 """Non orthogonal point plotting."""
 
-from __future__ import division
 import numpy as N
 
-from ..compat import czip
-from .. import qtall as qt4
+from .. import qtall as qt
 from .. import document
+from .. import datasets
 from .. import setting
 from .. import utils
 
@@ -35,7 +34,7 @@ from .point import MarkerFillBrush
 
 def _(text, disambiguation=None, context='NonOrthPoint'):
     """Translate text."""
-    return qt4.QCoreApplication.translate(context, text, disambiguation)
+    return qt.QCoreApplication.translate(context, text, disambiguation)
 
 class NonOrthPoint(Widget):
     '''Widget for plotting points in a non-orthogonal plot.'''
@@ -44,77 +43,83 @@ class NonOrthPoint(Widget):
     allowusercreation = True
     description = _('Plot points on a graph with non-orthogonal axes')
 
-    def __init__(self, parent, name=None):
-        """Initialise plotter."""
-        Widget.__init__(self, parent, name=name)
-        if type(self) == NonOrthPoint:
-            self.readDefaults()
-
     @classmethod
     def addSettings(klass, s):
         '''Settings for widget.'''
         Widget.addSettings(s)
 
         s.add( setting.DatasetExtended(
-                'data1', 'x',
-                descr=_('Dataset containing 1st dataset, list of values '
-                        'or expression'),
-                usertext=_('Dataset 1')) )
+            'data1', 'x',
+            descr=_(
+                'Dataset containing 1st dataset, list of values '
+                'or expression'),
+            usertext=_('Dataset 1')) )
         s.add( setting.DatasetExtended(
-                'data2', 'y',
-                descr=_('Dataset containing 2nd dataset, list of values '
-                        'or expression'),
-                usertext=_('Dataset 2')) )
+            'data2', 'y',
+            descr=_(
+                'Dataset containing 2nd dataset, list of values '
+                'or expression'),
+            usertext=_('Dataset 2')) )
         s.add( setting.DatasetOrStr(
-                'labels', '',
-                descr=_('Dataset or string to label points'),
-                usertext=_('Labels')) )
+            'labels', '',
+            descr=_('Dataset or string to label points'),
+            usertext=_('Labels')) )
         s.add( setting.DatasetExtended(
-                'scalePoints', '',
-                descr = _('Scale size of plotted markers by this dataset, '
-                          ' list of values or expression'),
-                usertext=_('Scale markers')) )
-        s.add( setting.MarkerColor('Color') )
+            'scalePoints', '',
+            descr = _(
+                'Scale size of plotted markers by this dataset, '
+                ' list of values or expression'),
+            usertext=_('Scale markers')) )
+        s.add( setting.DataColor('Color') )
 
-        s.add( setting.Color('color',
-                             'black',
-                             descr = _('Master color'),
-                             usertext = _('Color'),
-                             formatting=True), 0 )
-        s.add( setting.DistancePt('markerSize',
-                                  '3pt',
-                                  descr = _('Size of marker to plot'),
-                                  usertext=_('Marker size'), formatting=True), 0 )
-        s.add( setting.Marker('marker',
-                              'circle',
-                              descr = _('Type of marker to plot'),
-                              usertext=_('Marker'), formatting=True), 0 )
-        s.add( setting.Line('PlotLine',
-                            descr = _('Plot line settings'),
-                            usertext = _('Plot line')),
-               pixmap = 'settings_plotline' )
+        s.add( setting.Color(
+            'color',
+            'auto',
+            descr=_('Master color'),
+            usertext=_('Color'),
+            formatting=True), 0 )
+        s.add( setting.DistancePt(
+            'markerSize',
+            '3pt',
+            descr=_('Size of marker to plot'),
+            usertext=_('Marker size'), formatting=True), 0 )
+        s.add( setting.Marker(
+            'marker',
+            'circle',
+            descr=_('Type of marker to plot'),
+            usertext=_('Marker'), formatting=True), 0 )
+        s.add( setting.Line(
+            'PlotLine',
+            descr=_('Plot line settings'),
+            usertext=_('Plot line')),
+            pixmap='settings_plotline' )
         s.PlotLine.get('color').newDefault( setting.Reference('../color') )
 
-        s.add( setting.MarkerLine('MarkerLine',
-                                  descr = _('Line around the marker settings'),
-                                  usertext = _('Marker border')),
-               pixmap = 'settings_plotmarkerline' )
-        s.add( MarkerFillBrush('MarkerFill',
-                               descr = _('Marker fill settings'),
-                               usertext = _('Marker fill')),
-               pixmap = 'settings_plotmarkerfill' )
-        s.add( FillBrush('Fill1',
-                         descr = _('Fill settings (1)'),
-                         usertext = _('Area fill 1')),
-               pixmap = 'settings_plotfillbelow' )
-        s.add( FillBrush('Fill2',
-                         descr = _('Fill settings (2)'),
-                         usertext = _('Area fill 2')),
-               pixmap = 'settings_plotfillbelow' )
-        s.add( setting.PointLabel('Label',
-                                  descr = _('Label settings'),
-                                  usertext=_('Label')),
-               pixmap = 'settings_axislabel' )
+        s.add( setting.MarkerLine(
+            'MarkerLine',
+            descr=_('Line around the marker settings'),
+            usertext=_('Marker border')),
+            pixmap='settings_plotmarkerline' )
+        s.add( MarkerFillBrush(
+            'MarkerFill',
+            descr=_('Marker fill settings'),
+            usertext=_('Marker fill')),
+            pixmap='settings_plotmarkerfill' )
+        s.add( FillBrush(
+            'Fill1',
+            descr=_('Fill settings (1)'),
+            usertext=_('Area fill 1')),
+            pixmap='settings_plotfillbelow' )
+        s.add( FillBrush(
+            'Fill2',
+            descr=_('Fill settings (2)'),
+            usertext=_('Area fill 2')),
+            pixmap='settings_plotfillbelow' )
+        s.add( setting.PointLabel(
+            'Label',
+            descr=_('Label settings'),
+            usertext=_('Label')),
+            pixmap='settings_axislabel' )
 
     @classmethod
     def allowedParentTypes(klass):
@@ -167,23 +172,31 @@ class NonOrthPoint(Widget):
         alignvert = {'top':-1, 'centre':0, 'bottom':1}[lab.posnVert]
 
         # make font and len
-        textpen = lab.makeQPen()
+        textpen = lab.makeQPen(painter)
         painter.setPen(textpen)
         font = lab.makeQFont(painter)
         angle = lab.angle
 
         # iterate over each point and plot each label
-        for x, y, t in czip(xplotter+deltax, yplotter+deltay,
-                            textvals):
-            utils.Renderer( painter, font, x, y, t,
-                            alignhorz, alignvert, angle ).render()
+        for x, y, t in zip(xplotter+deltax, yplotter+deltay, textvals):
+            utils.Renderer(
+                painter, font, x, y, t,
+                alignhorz, alignvert, angle,
+                doc=self.document).render()
 
     def getColorbarParameters(self):
         """Return parameters for colorbar."""
         s = self.settings
         c = s.Color
-        return (c.min, c.max, c.scaling, s.MarkerFill.colorMap, 0,
-                s.MarkerFill.colorMapInvert)
+        return (
+            c.min, c.max, c.scaling, s.MarkerFill.colorMap, 0,
+            s.MarkerFill.colorMapInvert
+        )
+
+    def autoColor(self, painter, dataindex=0):
+        """Automatic color for plotting."""
+        return painter.docColorAuto(
+            painter.helper.autoColorIndex((self, dataindex)))
 
     def draw(self, parentposn, phelper, outerbounds=None):
         '''Plot the data on a plotter.'''
@@ -205,14 +218,14 @@ class NonOrthPoint(Widget):
             return
 
         x1, y1, x2, y2 = posn
-        cliprect = qt4.QRectF( qt4.QPointF(x1, y1), qt4.QPointF(x2, y2) )
+        cliprect = qt.QRectF( qt.QPointF(x1, y1), qt.QPointF(x2, y2) )
         painter = phelper.painter(self, posn)
         with painter:
             self.parent.setClip(painter, posn)
 
             # split parts separated by NaNs
-            for v1, v2, scalings, cvals, textitems in document.generateValidDatasetParts(
-                d1, d2, dscale, colorpoints, text):
+            for v1, v2, scalings, cvals, textitems in datasets.generateValidDatasetParts(
+                [d1, d2, dscale, colorpoints, text]):
                 # convert data (chopping down length)
                 v1d, v2d = v1.data, v2.data
                 minlen = min(v1d.shape[0], v2d.shape[0])
@@ -228,9 +241,9 @@ class NonOrthPoint(Widget):
 
                 # plot line
                 if not s.PlotLine.hide:
-                    painter.setBrush( qt4.QBrush() )
+                    painter.setBrush( qt.QBrush() )
                     painter.setPen(s.PlotLine.makeQPen(painter))
-                    pts = qt4.QPolygonF()
+                    pts = qt.QPolygonF()
                     utils.addNumpyToPolygonF(pts, px, py)
                     utils.plotClippedPolyline(painter, cliprect, pts)
 
@@ -243,24 +256,26 @@ class NonOrthPoint(Widget):
                         pscale = scalings.data
 
                     # color point individually
-                    if cvals and not s.MarkerFill.hide:
+                    cmapname = s.MarkerFill.colorMap
+                    if cvals and not s.MarkerFill.hide and cmapname != 'none':
                         colorvals = utils.applyScaling(
                             cvals.data, s.Color.scaling,
                             s.Color.min, s.Color.max)
-                        cmap = self.document.getColormap(
-                            s.MarkerFill.colorMap, s.MarkerFill.colorMapInvert)
+                        cmap = self.document.evaluate.getColormap(
+                            cmapname, s.MarkerFill.colorMapInvert)
 
-                    painter.setBrush(s.MarkerFill.makeQBrushWHide())
+                    painter.setBrush(s.MarkerFill.makeQBrushWHide(painter))
                     painter.setPen(s.MarkerLine.makeQPenWHide(painter))
 
-                    utils.plotMarkers(painter, px, py, s.marker, markersize,
-                                      scaling=pscale, clip=cliprect,
-                                      cmap=cmap, colorvals=colorvals,
-                                      scaleline=s.MarkerLine.scaleLine)
+                    utils.plotMarkers(
+                        painter, px, py, s.marker, markersize,
+                        scaling=pscale, clip=cliprect,
+                        cmap=cmap, colorvals=colorvals,
+                        scaleline=s.MarkerLine.scaleLine)
 
                 # finally plot any labels
                 if textitems and not s.Label.hide:
                     self.drawLabels(painter, px, py, textitems, markersize)
 
 # allow the factory to instantiate plotter
-document.thefactory.register( NonOrthPoint )
+document.thefactory.register(NonOrthPoint)
