@@ -18,12 +18,10 @@
 
 """Widget that represents a page in the document."""
 
-from __future__ import division, print_function
 import collections
 import textwrap
 import numpy as N
 
-from ..compat import crange, citems
 from .. import qtall as qt
 from .. import document
 from .. import setting
@@ -49,7 +47,7 @@ def _resolveLinkedAxis(axis):
             return None
     return axis
 
-class AxisDependHelper(object):
+class AxisDependHelper:
     """A class to work out the dependency of widgets on axes and vice
     versa, in terms of ranges of the axes.
 
@@ -110,7 +108,7 @@ class AxisDependHelper(object):
 
         Builds up a dict of "nodes" representing each widget: plotter/axis
         Each node is a list of tuples saying which widgets need evaling first
-        The tuples are (widget, depname), where depname is a name for the 
+        The tuples are (widget, depname), where depname is a name for the
         part of the plotter, e.g. "sx" or "sy" for x or y.
         """
 
@@ -130,8 +128,9 @@ class AxisDependHelper(object):
                 if resolvedaxis is not None and resolvedaxis.usesAutoRange():
                     # only add dependency if axis has an automatic range
                     self.deps[(origaxis, None)].append((widget, depname))
-                    self.pairs.append( ((widget, depname),
-                                        (resolvedaxis, None)) )
+                    self.pairs.append( (
+                        (widget, depname),
+                        (resolvedaxis, None)) )
 
             # find which axes the plotter needs information from
             for depname, axname in widget.requiresAxisRange():
@@ -139,8 +138,9 @@ class AxisDependHelper(object):
                 resolvedaxis = _resolveLinkedAxis(origaxis)
                 if resolvedaxis is not None and resolvedaxis.usesAutoRange():
                     self.deps[(widget, depname)].append((origaxis, None))
-                    self.pairs.append( ((resolvedaxis, None),
-                                        (widget, depname)) )
+                    self.pairs.append( (
+                        (resolvedaxis, None),
+                        (widget, depname)) )
 
         elif widget.isaxis:
             if widget.isaxis and widget.isLinked():
@@ -163,7 +163,7 @@ class AxisDependHelper(object):
         numcyclic = len(origcyclic)
         best = -1
 
-        for i in crange(len(self.pairs)):
+        for i in range(len(self.pairs)):
             if not self.pairs[i][0][0].isaxis:
                 p = self.pairs[:i] + self.pairs[i+1:]
                 ordered, cyclic = utils.topological_sort(p)
@@ -212,7 +212,7 @@ class AxisDependHelper(object):
                     self.ranges[axis] = [
                         N.nanmin((self.ranges[axis][0], therange[0])),
                         N.nanmax((self.ranges[axis][1], therange[1]))
-                        ]
+                    ]
         else:
             plotter.getRange(axis, plotterdep, self.ranges[axis])
 
@@ -280,30 +280,37 @@ class Page(widget.Widget):
     typename='page'
     allowusercreation = True
     description=_('Blank page')
- 
+
     @classmethod
     def addSettings(klass, s):
         widget.Widget.addSettings(s)
-        
+
         # page sizes are initially linked to the document page size
         s.add( setting.DistancePhysical(
-                'width',
-                setting.Reference('/width'),
-                descr=_('Width of page'),
-                usertext=_('Page width'),
-                formatting=True) )
+            'width',
+            setting.Reference('/width'),
+            descr=_('Width of page'),
+            usertext=_('Page width'),
+            formatting=True) )
         s.add( setting.DistancePhysical(
-                'height',
-                setting.Reference('/height'),
-                descr=_('Height of page'),
-                usertext=_('Page height'),
-                formatting=True) )
+            'height',
+            setting.Reference('/height'),
+            descr=_('Height of page'),
+            usertext=_('Page height'),
+            formatting=True) )
 
         s.add( setting.Notes(
-                'notes', '',
-                descr=_('User-defined notes'),
-                usertext=_('Notes')
-                ) )
+            'notes', '',
+            descr=_('User-defined notes'),
+            usertext=_('Notes')) )
+
+        s.add(
+            setting.PageBrush(
+                'Background',
+                descr = _('Background page fill'),
+                usertext=_('Background')),
+            pixmap='settings_bgfill',
+        )
 
     @classmethod
     def allowedParentTypes(klass):
@@ -318,6 +325,8 @@ class Page(widget.Widget):
     def draw(self, parentposn, painthelper, outerbounds=None):
         """Draw the plotter. Clip graph inside bounds."""
 
+        s = self.settings
+
         # document should pass us the page bounds
         x1, y1, x2, y2 = parentposn
 
@@ -330,12 +339,12 @@ class Page(widget.Widget):
         painthelper.axisplottermap.update(axisdependhelper.axis_plotter_map)
         # reverse mapping
         pamap = collections.defaultdict(list)
-        for axis, plotters in citems(painthelper.axisplottermap):
+        for axis, plotters in painthelper.axisplottermap.items():
             for plot in plotters:
                 pamap[plot].append(axis)
         painthelper.plotteraxismap.update(pamap)
 
-        if self.settings.hide:
+        if s.hide:
             bounds = self.computeBounds(parentposn, painthelper)
             return bounds
 
@@ -345,17 +354,22 @@ class Page(widget.Widget):
             # w and h are non integer
             w = self.settings.get('width').convert(painter)
             h = self.settings.get('height').convert(painter)
+            if not s.Background.hide:
+                path = qt.QPainterPath()
+                path.addRect(qt.QRectF(0, 0, w, h))
+                utils.brushExtFillPath(painter, s.Background, path)
 
         painthelper.setControlGraph(self, [
-                controlgraph.ControlMarginBox(self, [0, 0, w, h],
-                                              [-10000, -10000,
-                                                10000,  10000],
-                                              painthelper,
-                                              ismovable = False)
-                ] )
+                controlgraph.ControlMarginBox(
+                    self,
+                    [0, 0, w, h],
+                    [-10000, -10000, 10000,  10000],
+                    painthelper,
+                    ismovable=False)
+        ] )
 
-        bounds = widget.Widget.draw(self, parentposn, painthelper,
-                                    parentposn)
+        bounds = widget.Widget.draw(
+            self, parentposn, painthelper, parentposn)
         return bounds
 
     def updateControlItem(self, cgi):
@@ -363,5 +377,4 @@ class Page(widget.Widget):
         cgi.setPageSize()
 
 # allow the factory to instantiate this
-document.thefactory.register( Page )
-    
+document.thefactory.register(Page)
