@@ -18,10 +18,8 @@
 
 """For plotting xy points."""
 
-from __future__ import division
 import numpy as N
 
-from ..compat import czip
 from .. import qtall as qt
 from .. import datasets
 from .. import document
@@ -49,7 +47,7 @@ class ErrorBarDraw:
 
     def plot(self, painter, xmin, xmax, ymin, ymax, xplt, yplt, clip):
         pen = self.linestyle.makeQPenWHide(painter)
-        pen.setCapStyle(qt.Qt.FlatCap)
+        pen.setCapStyle(qt.Qt.PenCapStyle.FlatCap)
 
         painter.setPen(pen)
         for function in self.error_functions[self.style]:
@@ -182,7 +180,7 @@ class ErrorBarDraw:
         # non-filling brush
         painter.setBrush( qt.QBrush() )
 
-        for xp, yp, xmn, ymn, xmx, ymx in czip(xplt, yplt, xmin, ymin, xmax, ymax):
+        for xp, yp, xmn, ymn, xmx, ymx in zip(xplt, yplt, xmin, ymin, xmax, ymax):
             p = qt.QPainterPath()
             p.moveTo(xp + (xmx-xp), yp)
             p.arcTo(qt.QRectF(
@@ -201,7 +199,7 @@ class ErrorBarDraw:
         if utils.anyNone(xmin, xmax, ymin, ymax):
             return
 
-        for xp, yp, xmn, ymn, xmx, ymx in czip(xplt, yplt, xmin, ymin, xmax, ymax):
+        for xp, yp, xmn, ymn, xmx, ymx in zip(xplt, yplt, xmin, ymin, xmax, ymax):
 
             if not self.fillabove.hideerror:
                 p = qt.QPainterPath()
@@ -332,14 +330,20 @@ class MarkerFillBrush(setting.Brush):
 
         self.add( setting.Colormap(
             'colorMap', 'grey',
-            descr = _('If color markers dataset is given, use this colormap '
-                      'instead of the fill color'),
+            descr=_(
+                'If color markers dataset is given, use this colormap '
+                'instead of the fill color'),
             usertext=_('Color map'),
             formatting=True) )
         self.add( setting.Bool(
             'colorMapInvert', False,
-            descr = _('Invert color map'),
-            usertext = _('Invert map'),
+            descr=_('Invert color map'),
+            usertext=_('Invert map'),
+            formatting=True) )
+        self.add( setting.Bool(
+            'newMarkerSizes', False,
+            descr=_('Use new marker sizes with equal area'),
+            usertext=_('New marker sizes'),
             formatting=True) )
 
 class PointPlotter(GenericPlotter):
@@ -366,12 +370,24 @@ class PointPlotter(GenericPlotter):
         s.add( setting.DatasetOrStr(
             'labels', '',
             descr=_('Dataset or string to label points'),
-            usertext=_('Labels')), 5 )
+            usertext=_('Labels')), 6 )
         s.add( setting.DatasetExtended(
             'scalePoints', '',
-            descr = _('Scale size of markers given by dataset, expression'
-                      ' or list of values'),
-            usertext=_('Scale markers')), 6 )
+            descr=_(
+                'Scale size of markers given by dataset, expression'
+                ' or list of values'),
+            usertext=_('Scale markers')), 7 )
+        s.add( setting.DataColor('Color'), 8 )
+        s.add( setting.Choice(
+            'nanHandling',
+            ('break-on', 'ignore'),
+            'break-on',
+            descr=_('Effect of gaps or NaN values in input datasets'),
+            usertext=_('Data gaps'),
+            descriptions=(
+                _('NaN values are used to break datasets into parts at their locations'),
+                _('NaN values cause data in their locations to be ignored'),
+            )), 9 )
 
         # formatting
         s.add( setting.Int(
@@ -383,27 +399,27 @@ class PointPlotter(GenericPlotter):
         s.add( setting.Int(
             'thinfactor', 1,
             minval=1,
-            descr=_('Thin number of markers plotted'
-                    ' for each datapoint by this factor'),
+            descr=_(
+                'Thin number of markers plotted for each datapoint '
+                'by this factor'),
             usertext=_('Thin markers'),
             formatting=True), 0 )
         s.add( setting.Color(
             'color',
             'auto',
-            descr = _('Master color'),
-            usertext = _('Color'),
+            descr=_('Master color'),
+            usertext=_('Color'),
             formatting=True), 0 )
         s.add( setting.DistancePt(
             'markerSize',
             '3pt',
-            descr = _('Size of marker to plot'),
+            descr=_('Size of marker to plot'),
             usertext=_('Marker size'), formatting=True), 0 )
         s.add( setting.Marker(
             'marker',
             'circle',
-            descr = _('Type of marker to plot'),
+            descr=_('Type of marker to plot'),
             usertext=_('Marker'), formatting=True), 0 )
-        s.add( setting.DataColor('Color') )
 
         s.add( setting.ErrorStyle(
             'errorStyle',
@@ -413,44 +429,53 @@ class PointPlotter(GenericPlotter):
 
         s.add( setting.XYPlotLine(
             'PlotLine',
-            descr = _('Plot line'),
-            usertext = _('Plot line')),
-               pixmap = 'settings_plotline' )
+            descr=_('Plot line'),
+            usertext=_('Plot line')),
+            pixmap='settings_plotline' )
 
         s.add( setting.MarkerLine(
             'MarkerLine',
-            descr = _('Line around marker'),
-            usertext = _('Marker border')),
-               pixmap = 'settings_plotmarkerline' )
+            descr=_('Line around marker'),
+            usertext=_('Marker border')),
+            pixmap='settings_plotmarkerline' )
         s.add( MarkerFillBrush(
             'MarkerFill',
-            descr = _('Marker fill'),
-            usertext = _('Marker fill')),
-               pixmap = 'settings_plotmarkerfill' )
+            descr=_('Marker fill'),
+            usertext=_('Marker fill')),
+            pixmap='settings_plotmarkerfill' )
 
         s.add( setting.ErrorBarLine(
             'ErrorBarLine',
-            descr = _('Error bar line'),
-            usertext = _('Error bar line')),
-               pixmap = 'settings_ploterrorline' )
+            descr=_('Error bar line'),
+            usertext=_('Error bar line')),
+            pixmap='settings_ploterrorline' )
         s.ErrorBarLine.get('color').newDefault( setting.Reference('../color') )
 
         s.add( setting.PointFill(
             'FillBelow',
-            descr = _('Fill mode 1'),
-            usertext = _('Fill 1')),
-               pixmap = 'settings_plotfillbelow' )
+            descr=_('Fill mode 1'),
+            usertext=_('Fill 1')),
+            pixmap='settings_plotfillbelow' )
         s.FillBelow.get('fillto').newDefault('bottom')
         s.add( setting.PointFill(
             'FillAbove',
-            descr = _('Fill 2'),
-            usertext = _('Fill 2')),
-               pixmap = 'settings_plotfillabove' )
+            descr=_('Fill 2'),
+            usertext=_('Fill 2')),
+            pixmap='settings_plotfillabove' )
         s.add( setting.PointLabel(
             'Label',
-            descr = _('Label settings'),
+            descr=_('Label settings'),
             usertext=_('Label')),
-               pixmap = 'settings_axislabel' )
+            pixmap='settings_axislabel' )
+
+    @classmethod
+    def addSettingsCompatLevel(klass, s, level):
+        if level >= 1:
+            s.FillBelow.get('color').newDefault(
+                setting.Reference('../color') )
+            s.FillAbove.get('color').newDefault(
+                setting.Reference('../color') )
+            s.MarkerFill.get('newMarkerSizes').newDefault(True)
 
     @property
     def userdescription(self):
@@ -618,11 +643,11 @@ class PointPlotter(GenericPlotter):
                     pts.append( qt.QPointF(xvals[-1], yvals[-1]) )
 
         else:
-            assert False
+            raise RuntimeError('Invalid line mode')
 
         return pts
 
-    def _getBezierLine(self, poly, cliprect):
+    def _getBezierLine(self, poly, cliprect, beziertype):
         """Try to draw a bezier line connecting the points."""
 
         # clip to a larger box to help the lines get right angle
@@ -638,18 +663,22 @@ class PointPlotter(GenericPlotter):
         path = qt.QPainterPath()
         for lpoly in polys:
             if len(lpoly) >= 2:
-                npts = qtloops.bezier_fit_cubic_multi(lpoly, 0.1, len(lpoly)+1)
-                qtloops.addCubicsToPainterPath(path, npts);
+                if beziertype == "tight-Bezier":
+                    npts = qtloops.bezier_fit_cubic_tight(lpoly, 0.5)
+                else:
+                    npts = qtloops.bezier_fit_cubic_multi(
+                        lpoly, 0.1, len(lpoly)+1)
+                qtloops.addCubicsToPainterPath(path, npts)
         return path
 
     def _drawBezierLine( self, painter, xvals, yvals, posn,
-                         xdata, ydata, cliprect ):
+                         xdata, ydata, cliprect, beziertype ):
         """Handle bezier lines and fills."""
 
         pts = self._getLinePoints(xvals, yvals, posn, xdata, ydata)
         if len(pts) < 2:
             return
-        path = self._getBezierLine(pts, cliprect)
+        path = self._getBezierLine(pts, cliprect, beziertype)
         s = self.settings
 
         # do filling
@@ -762,7 +791,7 @@ class PointPlotter(GenericPlotter):
             if not s.MarkerLine.hide:
                 painter.setPen( s.MarkerLine.makeQPen(painter) )
             else:
-                painter.setPen( qt.QPen( qt.Qt.NoPen ) )
+                painter.setPen( qt.QPen( qt.Qt.PenStyle.NoPen ) )
 
             utils.plotMarker(painter, x+width/2, yp, s.marker, markersize)
 
@@ -788,8 +817,7 @@ class PointPlotter(GenericPlotter):
         angle = lab.angle
 
         # iterate over each point and plot each label
-        for x, y, t in czip(xplotter+deltax, yplotter+deltay,
-                            textvals):
+        for x, y, t in zip(xplotter+deltax, yplotter+deltay, textvals):
             utils.Renderer(
                 painter, font, x, y, t,
                 alignhorz, alignvert, angle,
@@ -841,8 +869,10 @@ class PointPlotter(GenericPlotter):
         """Return parameters for colorbar."""
         s = self.settings
         c = s.Color
-        return (c.min, c.max, c.scaling, s.MarkerFill.colorMap, 0,
-                s.MarkerFill.colorMapInvert)
+        return (
+            c.min, c.max, c.scaling, s.MarkerFill.colorMap, 0,
+            s.MarkerFill.colorMapInvert
+        )
 
     def dataDraw(self, painter, axes, posn, cliprect):
         """Plot the data on a plotter."""
@@ -877,9 +907,12 @@ class PointPlotter(GenericPlotter):
             text = text*(length // len(text)) + text[:length % len(text)]
 
         # loop over chopped up values
+        nanbreak = s.nanHandling == 'break-on'
+
         for xvals, yvals, tvals, ptvals, cvals in (
             datasets.generateValidDatasetParts(
-                [xv, yv, text, scalepoints, colorpoints])):
+                [xv, yv, text, scalepoints, colorpoints],
+                breakds=nanbreak)):
 
             #print "Calculating coordinates"
             # calc plotter coords of x and y points
@@ -907,10 +940,11 @@ class PointPlotter(GenericPlotter):
             #print "Painting plot line"
             # plot data line (and/or filling above or below)
             if not s.PlotLine.hide or not s.FillAbove.hide or not s.FillBelow.hide:
-                if s.PlotLine.bezierJoin:
+                interpolation_type = s.PlotLine.interpType
+                if interpolation_type != "linear":
                     self._drawBezierLine(
                         painter, xplotter, yplotter, posn,
-                        xvals, yvals, cliprect )
+                        xvals, yvals, cliprect, interpolation_type )
                 else:
                     self._drawPlotLine(
                         painter, xplotter, yplotter, posn,
@@ -920,8 +954,9 @@ class PointPlotter(GenericPlotter):
             # plot normal errors bars
             if s.errorStyle not in ('fillvert', 'fillhorz'):
                 # normally the error bar is painted after the line
-                self._plotErrors(posn, painter, xpltpoint, ypltpoint,
-                                 axes, xvals, yvals, cliprect)
+                self._plotErrors(
+                    posn, painter, xpltpoint, ypltpoint,
+                    axes, xvals, yvals, cliprect)
 
             # plot the points (we do this last so they are on top)
             markersize = s.get('markerSize').convert(painter)
@@ -941,7 +976,7 @@ class PointPlotter(GenericPlotter):
                     painter.setPen( s.MarkerLine.makeQPen(painter) )
                 else:
                     # invisible pen
-                    painter.setPen( qt.QPen(qt.Qt.NoPen) )
+                    painter.setPen( qt.QPen(qt.Qt.PenStyle.NoPen) )
 
                 # thin datapoints as required
                 if s.thinfactor <= 1:
@@ -974,7 +1009,9 @@ class PointPlotter(GenericPlotter):
                     painter, xplt, yplt, s.marker, markersize,
                     scaling=scaling, clip=cliprect,
                     cmap=cmap, colorvals=colorvals,
-                    scaleline=s.MarkerLine.scaleLine)
+                    scaleline=s.MarkerLine.scaleLine,
+                    equalarea=s.MarkerFill.newMarkerSizes,
+                )
 
             # finally plot any labels
             if tvals and not s.Label.hide:
@@ -983,4 +1020,4 @@ class PointPlotter(GenericPlotter):
                     tvals, markersize)
 
 # allow the factory to instantiate an x,y plotter
-document.thefactory.register( PointPlotter )
+document.thefactory.register(PointPlotter)
