@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #    Copyright (C) 2003 Jeremy S. Sanders
 #    Email: Jeremy Sanders <jeremy@jeremysanders.net>
 #
@@ -19,11 +18,9 @@
 
 """Implements the main window of the application."""
 
-from __future__ import division, print_function
 import os
 import os.path
 import sys
-import glob
 import re
 import datetime
 
@@ -32,7 +29,6 @@ try:
 except ImportError:
     h5py = None
 
-from ..compat import cstr, cstrerror, cgetcwd, cbytes
 from .. import qtall as qt
 
 from .. import document
@@ -132,7 +128,7 @@ class MainWindow(qt.QMainWindow):
         # icon and different size variations
         self.setWindowIcon( utils.getIcon('veusz') )
 
-        # master documenent
+        # master document
         self.document = document.Document()
 
         # filename for document and update titlebar
@@ -146,29 +142,34 @@ class MainWindow(qt.QMainWindow):
         self._defineMenus()
 
         # make plot window
-        self.plot = plotwindow.PlotWindow(self.document, self,
-                                          menu = self.menus['view'])
+        self.plot = plotwindow.PlotWindow(
+            self.document, self, menu=self.menus['view'])
         self.setCentralWidget(self.plot)
         self.plot.showToolbar()
 
         # likewise with the tree-editing window
         self.treeedit = treeeditwindow.TreeEditDock(self.document, self)
-        self.addDockWidget(qt.Qt.LeftDockWidgetArea, self.treeedit)
-        self.propdock = treeeditwindow.PropertiesDock(self.document,
-                                                      self.treeedit, self)
-        self.addDockWidget(qt.Qt.LeftDockWidgetArea, self.propdock)
-        self.formatdock = treeeditwindow.FormatDock(self.document,
-                                                    self.treeedit, self)
-        self.addDockWidget(qt.Qt.LeftDockWidgetArea, self.formatdock)
+        self.addDockWidget(
+            qt.Qt.DockWidgetArea.LeftDockWidgetArea, self.treeedit)
+        self.propdock = treeeditwindow.PropertiesDock(
+            self.document, self.treeedit, self)
+        self.addDockWidget(
+            qt.Qt.DockWidgetArea.LeftDockWidgetArea, self.propdock)
+        self.formatdock = treeeditwindow.FormatDock(
+            self.document, self.treeedit, self)
+        self.addDockWidget(
+            qt.Qt.DockWidgetArea.LeftDockWidgetArea, self.formatdock)
         self.datadock = DataNavigatorWindow(self.document, self, self)
-        self.addDockWidget(qt.Qt.RightDockWidgetArea, self.datadock)
+        self.addDockWidget(
+            qt.Qt.DockWidgetArea.RightDockWidgetArea, self.datadock)
 
         # make the console window a dock
-        self.console = consolewindow.ConsoleWindow(self.document,
-                                                   self)
+        self.console = consolewindow.ConsoleWindow(
+            self.document, self)
         self.console.hide()
         self.interpreter = self.console.interpreter
-        self.addDockWidget(qt.Qt.BottomDockWidgetArea, self.console)
+        self.addDockWidget(
+            qt.Qt.DockWidgetArea.BottomDockWidgetArea, self.console)
 
         # assemble the statusbar
         statusbar = self.statusbar = qt.QStatusBar(self)
@@ -210,7 +211,7 @@ class MainWindow(qt.QMainWindow):
         # working directory - use previous one
         self.dirname = setdb.get('dirname', qt.QDir.homePath())
         if setdb['dirname_usecwd']:
-            self.dirname = cgetcwd()
+            self.dirname = os.getcwd()
 
         # connect plot signals to main window
         self.plot.sigUpdatePage.connect(self.slotUpdatePage)
@@ -230,7 +231,7 @@ class MainWindow(qt.QMainWindow):
         # enable/disable undo/redo
         self.menus['edit'].aboutToShow.connect(self.slotAboutToShowEdit)
 
-        #Get the list of recently opened files
+        # get the list of recently opened files
         self.populateRecentFiles()
         self.setupWindowGeometry()
         self.defineViewWindowMenu()
@@ -252,8 +253,7 @@ class MainWindow(qt.QMainWindow):
 
     def dragEnterEvent(self, event):
         """Check whether event is valid to be dropped."""
-        if (event.mimeData().hasUrls() and
-            self._getVeuszDropFiles(event)):
+        if event.mimeData().hasUrls() and self._getVeuszDropFiles(event):
             event.acceptProposedAction()
 
     def dropEvent(self, event):
@@ -310,7 +310,7 @@ class MainWindow(qt.QMainWindow):
                 qt.QMessageBox.warning(
                     self, _("Error - Veusz"),
                     _("Unable to load default stylesheet '%s'\n\n%s") %
-                    (filename, cstrerror(e)))
+                    (filename, e.strerror))
             else:
                 # reset any modified flag
                 self.document.setModified(False)
@@ -327,7 +327,7 @@ class MainWindow(qt.QMainWindow):
                 qt.QMessageBox.warning(
                     self, _("Error - Veusz"),
                     _("Unable to load custom definitions '%s'\n\n%s") %
-                    (filename, cstrerror(e)))
+                    (filename, e.strerror))
             else:
                 # reset any modified flag
                 self.document.setModified(False)
@@ -366,7 +366,7 @@ class MainWindow(qt.QMainWindow):
     def slotEditPreferences(self):
         from ..dialogs.preferences import PreferencesDialog
         dialog = PreferencesDialog(self)
-        dialog.exec_()
+        dialog.exec()
 
     def slotEditStylesheet(self):
         from ..dialogs.stylesheet import StylesheetDialog
@@ -554,10 +554,10 @@ class MainWindow(qt.QMainWindow):
 
             'data.import':
                 a(self, _('Import data into Veusz'), _('&Import...'),
-                  self.slotDataImport, icon='kde-vzdata-import'),
+                  self.slotDataImport, icon='kde-vzdata-import', key='Ctrl+I'),
             'data.edit':
                 a(self, _('Edit and enter new datasets'), _('&Editor...'),
-                  lambda: self.slotDataEdit(), icon='kde-edit-veuszedit'),
+                  lambda: self.slotDataEdit(), icon='kde-edit-veuszedit', key='Ctrl+E'),
             'data.create':
                 a(self, _('Create new datasets using ranges, parametrically or as functions of existing datasets'), _('&Create...'),
                   self.slotDataCreate, icon='kde-dataset-new-veuszedit'),
@@ -575,7 +575,7 @@ class MainWindow(qt.QMainWindow):
                   self.slotDataHistogram, icon='button_bar'),
             'data.reload':
                 a(self, _('Reload linked datasets'), _('&Reload'),
-                  self.slotDataReload, icon='kde-view-refresh'),
+                  self.slotDataReload, icon='kde-view-refresh', key='F5'),
 
             'help.home':
                 a(self, _('Go to the Veusz home page on the internet'),
@@ -593,19 +593,19 @@ class MainWindow(qt.QMainWindow):
             'help.about':
                 a(self, _('Displays information about the program'), _('About...'),
                   self.slotHelpAbout, icon='veusz')
-            }
+        }
 
         # create main toolbar
         tb = self.maintoolbar = qt.QToolBar(_("Main toolbar - Veusz"), self)
         iconsize = setdb['toolbar_size']
         tb.setIconSize(qt.QSize(iconsize, iconsize))
         tb.setObjectName('veuszmaintoolbar')
-        self.addToolBar(qt.Qt.TopToolBarArea, tb)
+        self.addToolBar(qt.Qt.ToolBarArea.TopToolBarArea, tb)
 
         utils.makeMenuGroupSaved(
             'file.new.menu', self, self.vzactions, (
-                    'file.new.graph', 'file.new.graph3d',
-                    'file.new.polar', 'file.new.ternary',
+                'file.new.graph', 'file.new.graph3d',
+                'file.new.polar', 'file.new.ternary',
             )
         )
 
@@ -618,20 +618,27 @@ class MainWindow(qt.QMainWindow):
         tb = self.datatoolbar = qt.QToolBar(_("Data toolbar - Veusz"), self)
         tb.setIconSize(qt.QSize(iconsize, iconsize))
         tb.setObjectName('veuszdatatoolbar')
-        self.addToolBar(qt.Qt.TopToolBarArea, tb)
+        self.addToolBar(qt.Qt.ToolBarArea.TopToolBarArea, tb)
         utils.addToolbarActions(
             tb, self.vzactions,
             ('data.import', 'data.edit',
              'data.create', 'data.capture',
-             'data.filter', 'data.reload'))
+             'data.filter', 'data.reload')
+        )
 
         # menu structure
         filemenu = [
-            ['file.new', _('New'),
-             ['file.new.graph', 'file.new.graph3d', 'file.new.polar',
-              'file.new.ternary']],
+            [
+                'file.new', _('New'),
+                [
+                    'file.new.graph', 'file.new.graph3d', 'file.new.polar',
+                    'file.new.ternary'
+                ]
+            ],
             'file.open',
-            ['file.filerecent', _('Open &Recent'), []],
+            [
+                'file.filerecent', _('Open &Recent'), []
+            ],
             'file.reload',
             '',
             'file.save', 'file.saveas', 'file.trust',
@@ -639,7 +646,7 @@ class MainWindow(qt.QMainWindow):
             'file.print', 'file.export',
             '',
             'file.close', 'file.quit'
-            ]
+        ]
         editmenu = [
             'edit.undo', 'edit.redo',
             '',
@@ -647,44 +654,53 @@ class MainWindow(qt.QMainWindow):
             '',
             'edit.prefs', 'edit.stylesheet', 'edit.custom',
             ''
-            ]
+        ]
         viewwindowsmenu = [
             'view.edit', 'view.props', 'view.format',
             'view.console', 'view.datanav',
             '',
             'view.maintool', 'view.viewtool',
             'view.addtool', 'view.edittool'
-            ]
+        ]
         viewmenu = [
-            ['view.viewwindows', _('&Windows'), viewwindowsmenu],
+            [
+                'view.viewwindows', _('&Windows'), viewwindowsmenu
+            ],
             ''
-            ]
+        ]
         insertmenu = [
-            ]
+        ]
 
         # load dataset plugins and create menu
-        datapluginsmenu = self.definePlugins( plugins.datasetpluginregistry,
-                                              self.vzactions, 'data.ops' )
+        datapluginsmenu = self.definePlugins(
+            plugins.datasetpluginregistry,
+            self.vzactions, 'data.ops'
+        )
 
         datamenu = [
-            ['data.ops', _('&Operations'), datapluginsmenu],
+            [
+                'data.ops', _('&Operations'), datapluginsmenu
+            ],
             'data.import', 'data.edit', 'data.create',
             'data.create2d', 'data.capture', 'data.filter', 'data.histogram',
             'data.reload',
-            ]
+        ]
         helpmenu = [
             'help.home', 'help.bug', 'help.update',
             '',
             'help.tutorial',
             '',
-            ['help.examples', _('&Example documents'), []],
+            [
+                'help.examples', _('&Example documents'), []
+            ],
             '',
             'help.about'
-            ]
+        ]
 
         # load tools plugins and create menu
-        toolsmenu = self.definePlugins( plugins.toolspluginregistry,
-                                        self.vzactions, 'tools' )
+        toolsmenu = self.definePlugins(
+            plugins.toolspluginregistry,
+            self.vzactions, 'tools')
 
         menus = [
             ['file', _('&File'), filemenu],
@@ -694,7 +710,7 @@ class MainWindow(qt.QMainWindow):
             ['data', _('&Data'), datamenu],
             ['tools', _('&Tools'), toolsmenu],
             ['help', _('&Help'), helpmenu],
-            ]
+        ]
 
         self.menus = {}
         utils.constructMenus(self.menuBar(), self.menus, menus, self.vzactions)
@@ -715,9 +731,11 @@ class MainWindow(qt.QMainWindow):
 
         # not cstr here forces to unicode for Python 2, getting
         # filenames in unicode
-        examples = [ os.path.join(utils.exampleDirectory, f)
-                     for f in os.listdir(cstr(utils.exampleDirectory))
-                     if os.path.splitext(f)[1] == ".vsz" ]
+        examples = [
+            os.path.join(utils.exampleDirectory, f)
+            for f in os.listdir(str(utils.exampleDirectory))
+            if os.path.splitext(f)[1] == ".vsz"
+        ]
 
         menu = self.menus["help.examples"]
         for ex in sorted(examples):
@@ -741,16 +759,18 @@ class MainWindow(qt.QMainWindow):
 
         # set whether windows are visible and connect up to toggle windows
         self.viewwinfns = []
-        for win, act in ((self.treeedit, 'view.edit'),
-                         (self.propdock, 'view.props'),
-                         (self.formatdock, 'view.format'),
-                         (self.console, 'view.console'),
-                         (self.datadock, 'view.datanav'),
-                         (self.maintoolbar, 'view.maintool'),
-                         (self.datatoolbar, 'view.datatool'),
-                         (self.treeedit.edittoolbar, 'view.edittool'),
-                         (self.treeedit.addtoolbar, 'view.addtool'),
-                         (self.plot.viewtoolbar, 'view.viewtool')):
+        for win, act in (
+                (self.treeedit, 'view.edit'),
+                (self.propdock, 'view.props'),
+                (self.formatdock, 'view.format'),
+                (self.console, 'view.console'),
+                (self.datadock, 'view.datanav'),
+                (self.maintoolbar, 'view.maintool'),
+                (self.datatoolbar, 'view.datatool'),
+                (self.treeedit.edittoolbar, 'view.edittool'),
+                (self.treeedit.addtoolbar, 'view.addtool'),
+                (self.plot.viewtoolbar, 'view.viewtool')
+        ):
 
             a = self.vzactions[act]
             fn = viewHideWindow(win)
@@ -859,10 +879,11 @@ class MainWindow(qt.QMainWindow):
             _("Veusz includes a tutorial to help get you started.\n"
               "Would you like to start the tutorial now?\n"
               "If not, you can access it later through the Help menu."),
-            qt.QMessageBox.Yes | qt.QMessageBox.No
-            )
+            qt.QMessageBox.StandardButton.Yes |
+            qt.QMessageBox.StandardButton.No
+        )
 
-        if retn == qt.QMessageBox.Yes:
+        if retn == qt.QMessageBox.StandardButton.Yes:
             self.slotHelpTutorial()
 
     def slotHelpTutorial(self):
@@ -871,7 +892,8 @@ class MainWindow(qt.QMainWindow):
             # run the tutorial
             from .tutorial import TutorialDock
             tutdock = TutorialDock(self.document, self, self)
-            self.addDockWidget(qt.Qt.RightDockWidgetArea, tutdock)
+            self.addDockWidget(
+                qt.Qt.DockWidgetArea.RightDockWidgetArea, tutdock)
             tutdock.show()
         else:
             # open up a blank window for tutorial
@@ -881,7 +903,7 @@ class MainWindow(qt.QMainWindow):
     def slotHelpAbout(self):
         """Show about dialog."""
         from ..dialogs.aboutdialog import AboutDialog
-        AboutDialog(self).exec_()
+        AboutDialog(self).exec()
 
     def askVersionCheck(self, mininterval=2):
         """Check with user whether to do version checks.
@@ -894,10 +916,10 @@ class MainWindow(qt.QMainWindow):
         dayssinceinstall = (
             datetime.date.today() -
             datetime.date(*setting.settingdb['install_date'])).days
-        if (dayssinceinstall<mininterval or
-            setting.settingdb['vercheck_asked_user'] or
-            setting.settingdb['vercheck_disabled'] or
-            utils.disableVersionChecks):
+        if ( dayssinceinstall<mininterval or
+             setting.settingdb['vercheck_asked_user'] or
+             setting.settingdb['vercheck_disabled'] or
+             utils.disableVersionChecks ):
             return
 
         retn = qt.QMessageBox.question(
@@ -905,11 +927,11 @@ class MainWindow(qt.QMainWindow):
             _("Veusz will periodically check for new Veusz versions and\n"
               "let you know if there is a new one available.\n\n"
               "Is this ok? This choice can be changed in Preferences."),
-            qt.QMessageBox.Yes | qt.QMessageBox.No,
-            qt.QMessageBox.Yes
-            )
+            qt.QMessageBox.StandardButton.Yes | qt.QMessageBox.StandardButton.No,
+            qt.QMessageBox.StandardButton.Yes
+        )
 
-        setting.settingdb['vercheck_disabled'] = retn==qt.QMessageBox.No
+        setting.settingdb['vercheck_disabled'] = retn==qt.QMessageBox.StandardButton.No
         setting.settingdb['vercheck_asked_user'] = True
 
     def doVersionCheck(self):
@@ -934,10 +956,10 @@ class MainWindow(qt.QMainWindow):
         dayssinceinstall = (
             datetime.date.today() -
             datetime.date(*setting.settingdb['install_date'])).days
-        if (dayssinceinstall<mininterval or
-            setting.settingdb['feedback_asked_user'] or
-            setting.settingdb['feedback_disabled'] or
-            utils.disableFeedback):
+        if ( dayssinceinstall<mininterval or
+             setting.settingdb['feedback_asked_user'] or
+             setting.settingdb['feedback_disabled'] or
+             utils.disableFeedback ):
             return
 
         retn = qt.QMessageBox.question(
@@ -947,11 +969,11 @@ class MainWindow(qt.QMainWindow):
               "of software dependencies, the computer language and how "
               "often features are used.\n\n"
               "Is this ok? This choice can be changed in Preferences."),
-            qt.QMessageBox.Yes | qt.QMessageBox.No,
-            qt.QMessageBox.Yes
-            )
+            qt.QMessageBox.StandardButton.Yes | qt.QMessageBox.StandardButton.No,
+            qt.QMessageBox.StandardButton.Yes
+        )
 
-        setting.settingdb['feedback_disabled'] = retn==qt.QMessageBox.No
+        setting.settingdb['feedback_disabled'] = retn==qt.QMessageBox.StandardButton.No
         setting.settingdb['feedback_asked_user'] = True
 
     def doFeedback(self):
@@ -986,8 +1008,9 @@ class MainWindow(qt.QMainWindow):
             self,
             _("Save file?"),
             _("Document%s was modified. Save first?") % filetext,
-            qt.QMessageBox.Save | qt.QMessageBox.Discard |
-            qt.QMessageBox.Cancel)
+            qt.QMessageBox.StandardButton.Save | qt.QMessageBox.StandardButton.Discard |
+            qt.QMessageBox.StandardButton.Cancel
+        )
 
     def closeEvent(self, event):
         """Before closing, check whether we need to save first."""
@@ -995,10 +1018,10 @@ class MainWindow(qt.QMainWindow):
         # if the document has been modified then query user for saving
         if self.document.isModified():
             v = self.queryOverwrite()
-            if v == qt.QMessageBox.Cancel:
+            if v == qt.QMessageBox.StandardButton.Cancel:
                 event.ignore()
                 return
-            elif v == qt.QMessageBox.Save:
+            elif v == qt.QMessageBox.StandardButton.Save:
                 self.slotFileSave()
 
         # store working directory
@@ -1010,7 +1033,7 @@ class MainWindow(qt.QMainWindow):
 
         # store docked windows
         data = self.saveState().data()
-        setdb['geometry_mainwindowstate'] = cbytes(data)
+        setdb['geometry_mainwindowstate'] = bytes(data)
 
         # save current setting db
         setdb.writeSettings()
@@ -1022,7 +1045,7 @@ class MainWindow(qt.QMainWindow):
 
         # count number of main windows shown
         nummain = 0
-        for w in qt.qApp.topLevelWidgets():
+        for w in qt.QGuiApplication.topLevelWindows():
             if isinstance(w, qt.QMainWindow):
                 nummain += 1
 
@@ -1031,7 +1054,7 @@ class MainWindow(qt.QMainWindow):
             geometry = setdb['geometry_mainwindow']
             self.resize( qt.QSize(geometry[2], geometry[3]) )
             if nummain <= 1:
-                geomrect = qt.QApplication.desktop().availableGeometry()
+                geomrect = self.screen().geometry()
                 newpos = qt.QPoint(geometry[0], geometry[1])
                 if geomrect.contains(newpos):
                     self.move(newpos)
@@ -1076,19 +1099,19 @@ class MainWindow(qt.QMainWindow):
                 qt.QMessageBox.critical(
                     self, _("Error - Veusz"),
                     _("Unable to save document as '%s'\n\n%s") %
-                    (self.filename, cstrerror(e)))
+                    (self.filename, e.strerror))
 
     def updateTitlebar(self):
         """Put the filename into the title bar."""
         if self.filename == '':
             self.setWindowTitle(_('Untitled - Veusz'))
         else:
-            self.setWindowTitle( _("%s - Veusz") %
-                                 os.path.basename(self.filename) )
+            self.setWindowTitle(
+                _("%s - Veusz") % os.path.basename(self.filename))
 
     def plotQueueChanged(self, incr):
         self.plotqueuecount += incr
-        text = u'•' * self.plotqueuecount
+        text = '•' * self.plotqueuecount
         self.plotqueuelabel.setText(text)
 
     def fileSaveDialog(self, filters, dialogtitle):
@@ -1099,8 +1122,8 @@ class MainWindow(qt.QMainWindow):
 
         fd = qt.QFileDialog(self, dialogtitle)
         fd.setDirectory(self.dirname)
-        fd.setFileMode(qt.QFileDialog.AnyFile)
-        fd.setAcceptMode(qt.QFileDialog.AcceptSave)
+        fd.setFileMode(qt.QFileDialog.FileMode.AnyFile)
+        fd.setAcceptMode(qt.QFileDialog.AcceptMode.AcceptSave)
         fd.setNameFilters(filters)
 
         # selected filetype is saved under a key constructed here
@@ -1113,7 +1136,7 @@ class MainWindow(qt.QMainWindow):
                 fd.selectNameFilter(filter)
 
         # okay was selected (and is okay to overwrite if it exists)
-        if fd.exec_() == qt.QDialog.Accepted:
+        if fd.exec() == qt.QDialog.DialogCode.Accepted:
             # save directory for next time
             self.dirname = fd.directory().absolutePath()
             # update the edit box
@@ -1134,12 +1157,12 @@ class MainWindow(qt.QMainWindow):
 
         fd = qt.QFileDialog(self, dialogtitle)
         fd.setDirectory(self.dirname)
-        fd.setFileMode( qt.QFileDialog.ExistingFile )
-        fd.setAcceptMode( qt.QFileDialog.AcceptOpen )
+        fd.setFileMode( qt.QFileDialog.FileMode.ExistingFile )
+        fd.setAcceptMode( qt.QFileDialog.AcceptMode.AcceptOpen )
         fd.setNameFilters(filters)
 
         # if the user chooses a file
-        if fd.exec_() == qt.QDialog.Accepted:
+        if fd.exec() == qt.QDialog.DialogCode.Accepted:
             # save directory for next time
             self.dirname = fd.directory().absolutePath()
 
@@ -1151,7 +1174,7 @@ class MainWindow(qt.QMainWindow):
                 qt.QMessageBox.critical(
                     self, _("Error - Veusz"),
                     _("Unable to open '%s'\n\n%s") %
-                    (filename, cstrerror(e)))
+                    (filename, e.strerror))
                 return None
             return filename
         return None
@@ -1195,18 +1218,22 @@ class MainWindow(qt.QMainWindow):
             """Ask user if they want to give a new filename in case of import
             error.
             """
-            with utils.OverrideCursor(qt.Qt.ArrowCursor):
+            with utils.OverrideCursor(qt.Qt.CursorShape.ArrowCursor):
                 msgbox = qt.QMessageBox(self)
                 msgbox.setWindowTitle(_("Import error"))
                 msgbox.setText(
                     _("Could not import data from file '%s':\n\n %s") % (
                         filename, error))
                 msgbox.setInformativeText(_("Do you want to look for another file?"))
-                msgbox.setStandardButtons(qt.QMessageBox.Yes | qt.QMessageBox.Cancel)
+                msgbox.setStandardButtons(
+                    qt.QMessageBox.StandardButton.Yes |
+                    qt.QMessageBox.StandardButton.Cancel )
                 filename = None
-                if msgbox.exec_() == qt.QMessageBox.Yes:
+                if msgbox.exec() == qt.QMessageBox.StandardButton.Yes:
                     filename = qt.QFileDialog.getOpenFileName(self, "Choose data file")
                     filename = filename[0] if filename else None
+                elif res == qt.QMessageBox.Ignore:
+                    filename = False
             return filename
 
         # save stdout and stderr, then redirect to console
@@ -1236,12 +1263,12 @@ class MainWindow(qt.QMainWindow):
         except document.LoadError as e:
             from ..dialogs.errorloading import ErrorLoadingDialog
             if e.backtrace:
-                d = ErrorLoadingDialog(self, filename, cstr(e), e.backtrace)
-                d.exec_()
+                d = ErrorLoadingDialog(self, filename, str(e), e.backtrace)
+                d.exec()
             else:
                 qt.QMessageBox.critical(
                     self, _("Error opening %s - Veusz") % filename,
-                    cstr(e))
+                    str(e))
             return False
 
         # need to remember to restore stdout, stderr
@@ -1311,8 +1338,8 @@ class MainWindow(qt.QMainWindow):
         menu.clear()
 
         if setdb['main_recentfiles']:
-            files = [f for f in setdb['main_recentfiles']
-                     if os.path.isfile(f)]
+            files = [
+                f for f in setdb['main_recentfiles'] if os.path.isfile(f)]
 
             # add each recent file to menu
             newmenuitems = []
@@ -1336,9 +1363,10 @@ class MainWindow(qt.QMainWindow):
             self,
             _("Reload file"),
             _("Reload document from file, losing any changes?"),
-            qt.QMessageBox.Yes | qt.QMessageBox.Cancel,
-            qt.QMessageBox.Cancel)
-        if retn == qt.QMessageBox.Yes:
+            qt.QMessageBox.StandardButton.Yes | qt.QMessageBox.StandardButton.Cancel,
+            qt.QMessageBox.StandardButton.Cancel
+        )
+        if retn == qt.QMessageBox.StandardButton.Yes:
             if not os.path.exists(self.filename):
                 qt.QMessageBox.critical(
                     self,
@@ -1374,16 +1402,16 @@ class MainWindow(qt.QMainWindow):
 
     def slotFileQuit(self):
         """File quit chosen."""
-        qt.qApp.closeAllWindows()
+        qt.QApplication.instance().closeAllWindows()
 
     def slotUpdatePage(self, number):
         """Update page number when the plot window says so."""
 
-        np = self.document.getNumberPages()
-        if np == 0:
+        nump = self.document.getNumberPages()
+        if nump == 0:
             self.pagelabel.setText(_("No pages"))
         else:
-            self.pagelabel.setText(_("Page %i/%i") % (number+1, np))
+            self.pagelabel.setText(_("Page %i/%i") % (number+1, nump))
 
     def slotUpdateAxisValues(self, values):
         """Update the position where the mouse is relative to the axes."""
@@ -1445,8 +1473,8 @@ class MainWindow(qt.QMainWindow):
 
         # we shouldn't allow these places to be added to allowed safe directories
         badlocs = (
-            qt.QStandardPaths.standardLocations(qt.QStandardPaths.DownloadLocation) +
-            qt.QStandardPaths.standardLocations(qt.QStandardPaths.TempLocation)
+            qt.QStandardPaths.standardLocations(qt.QStandardPaths.StandardLocation.DownloadLocation) +
+            qt.QStandardPaths.standardLocations(qt.QStandardPaths.StandardLocation.TempLocation)
         )
         fname = self.document.filename
         absfile = os.path.abspath(fname)
@@ -1460,47 +1488,50 @@ class MainWindow(qt.QMainWindow):
                 isbadloc = True
         # don't allow plain home directory
         if filedir == qt.QStandardPaths.standardLocations(
-                qt.QStandardPaths.HomeLocation)[0]:
+                qt.QStandardPaths.StandardLocation.HomeLocation)[0]:
             isbadloc = True
 
         msgbox = qt.QMessageBox(
-            qt.QMessageBox.Warning,
+            qt.QMessageBox.Icon.Warning,
             _("Potentially unsafe code in document"),
-            _("<p><b>The document '%s' contains potentially unsafe code</b></p>"
-              "<p>Directory: '%s'</p>"
-              "<p>This file could damage your computer or data "
-              "as it can contain arbitrary code. "
-              "Please check "
-              "that the file was made by you or a trusted source.</p>") % (
-                  os.path.basename(absfile) if fname else "",
-                  filedir if fname else "",
-              ),
-            qt.QMessageBox.NoButton,
+            _(
+                "<p><b>The document '%s' contains potentially unsafe code</b></p>"
+                "<p>Directory: '%s'</p>"
+                "<p>This file could damage your computer or data "
+                "as it can contain arbitrary code. "
+                "Please check "
+                "that the file was made by you or a trusted source.</p>"
+            ) % (
+                os.path.basename(absfile) if fname else "",
+                filedir if fname else "",
+            ),
+            qt.QMessageBox.StandardButton.NoButton,
             self,
         )
-        allow = msgbox.addButton(_("Allow"), qt.QMessageBox.AcceptRole)
-        addloc = msgbox.addButton(_("Add to trusted locations"), qt.QMessageBox.AcceptRole)
+        allow = msgbox.addButton(_("Allow"), qt.QMessageBox.ButtonRole.AcceptRole)
+        addloc = msgbox.addButton(_("Add to trusted locations"), qt.QMessageBox.ButtonRole.AcceptRole)
         addloc.setEnabled(not isbadloc)
-        stop = msgbox.addButton(_("Skip"), qt.QMessageBox.RejectRole)
+        stop = msgbox.addButton(_("Skip"), qt.QMessageBox.ButtonRole.RejectRole)
 
         msgbox.setDefaultButton(stop)
 
         # we enter here with a busy cursor often, so set back to arrow temporarily
-        with utils.OverrideCursor(qt.Qt.ArrowCursor):
-            msgbox.exec_()
+        with utils.OverrideCursor(qt.Qt.CursorShape.ArrowCursor):
+            msgbox.exec()
 
         clicked = msgbox.clickedButton()
         if clicked is addloc:
-            with utils.OverrideCursor(qt.Qt.ArrowCursor):
+            with utils.OverrideCursor(qt.Qt.CursorShape.ArrowCursor):
                 button = qt.QMessageBox.warning(
                     self, _("Are you sure?"),
                     _("Are you really sure that you want to add directory '%s' to the "
                       "list of trusted locations. Any file loaded from this directory "
                       "will be trusted.") % filedir,
-                    qt.QMessageBox.Yes | qt.QMessageBox.No,
-                    qt.QMessageBox.No,
+                    qt.QMessageBox.StandardButton.Yes |
+                    qt.QMessageBox.StandardButton.No,
+                    qt.QMessageBox.StandardButton.No,
                 )
-            if button == qt.QMessageBox.Yes:
+            if button == qt.QMessageBox.StandardButton.Yes:
                 setting.settingdb['secure_dirs'].append(filedir)
                 return True
             else:
@@ -1525,10 +1556,11 @@ class MainWindow(qt.QMainWindow):
             _("Are you sure that you want to trust the document contents, "
               "including any potentially dangerous code? Only trust "
               "documents with a trusted source."),
-            qt.QMessageBox.Yes | qt.QMessageBox.No,
-            qt.QMessageBox.No,
+            qt.QMessageBox.StandardButton.Yes |
+            qt.QMessageBox.StandardButton.No,
+            qt.QMessageBox.StandardButton.No,
         )
-        if button == qt.QMessageBox.Yes:
+        if button == qt.QMessageBox.StandardButton.Yes:
             self.document.evaluate.setSecurity(True)
             # force redraw of document
             self.plot.actionForceUpdate()
