@@ -720,9 +720,13 @@ class FormatDock(qt.QDockWidget):
             tab = 0
 
         # delete old tabwidget
-        if self.tabwidget:
-            self.tabwidget.deleteLater()
-            self.tabwidget = None
+        oldItem = self.layout.takeAt(0)
+        if oldItem:
+            oldWidget = oldItem.widget()
+            if oldWidget:
+                oldWidget.setParent(None)
+                oldWidget.deleteLater()
+                self.tabwidget = None
 
         self.tabwidget = TabbedFormatting(self.document, setnsproxy)
         self.layout.addWidget(self.tabwidget)
@@ -1536,12 +1540,13 @@ class SettingLabel(qt.QWidget):
     def updateHighlight(self):
         """Show drop down arrow if item has focus."""
         if self.inmouse or self.infocus or self.inmenu:
-            pixmap = 'downarrow.png'
+            pixmap = 'veusz-dropdown.svg'
         else:
             if self.setting.isReference() and not self.setting.isDefault():
-                pixmap = 'link.png'
+                pixmap = 'veusz-dropdown-link.svg'
             else:
-                pixmap = 'downarrow_blank.png'
+                pixmap = 'veusz-dropdown-blank.svg'
+
         self.iconlabel.setPixmap(utils.getPixmap(pixmap))
 
     def enterEvent(self, event):
