@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #    Copyright (C) 2011 Jeremy S. Sanders
 #    Email: Jeremy Sanders <jeremy@jeremysanders.net>
 #
@@ -17,20 +16,19 @@
 #    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 ###############################################################################
 
-from __future__ import division
 import os.path
 
-from .. import qtall as qt4
+from .. import qtall as qt
 from .. import utils
 from .. import setting
 
 def _(text, disambiguation=None, context="Tutorial"):
     """Translate text."""
-    return qt4.QCoreApplication.translate(context, text, disambiguation)
+    return qt.QCoreApplication.translate(context, text, disambiguation)
 
-class TutorialStep(qt4.QObject):
+class TutorialStep(qt.QObject):
 
-    nextStep = qt4.pyqtSignal()
+    nextStep = qt.pyqtSignal()
 
     def __init__(self, text, mainwin,
                  nextstep=None, flash=None,
@@ -49,7 +47,7 @@ class TutorialStep(qt4.QObject):
         nextonselected: go to next if widget with name is selected
         """
 
-        qt4.QObject.__init__(self)
+        qt.QObject.__init__(self)
         self.text = text
         self.nextstep = nextstep
         self.flash = flash
@@ -68,8 +66,8 @@ class TutorialStep(qt4.QObject):
     def slotNextSetting(self, *args):
         """Check setting to emit next."""
         try:
-            setn = self.mainwin.document.basewidget.prefLookup(
-                self.nextonsetting[0]).get()
+            setn = self.mainwin.document.resolveSettingPath(
+                None, self.nextonsetting[0]).get()
             if self.nextonsetting[1](setn):
                 self.nextStep.emit()
         except ValueError:
@@ -118,7 +116,7 @@ class StepWidgets2(TutorialStep):
     def __init__(self, mainwin):
         TutorialStep.__init__(
             self, _('''
-<p>Widget can often be placed inside each other. For instance, a graph
+<p>Widgets can often be placed inside each other. For instance, a graph
 widget is placed in a page widget or a grid widget. Plotting widgets
 are placed in graph widget.</p>
 
@@ -172,8 +170,8 @@ Enter key.</p>
 '''), mainwin,
             flash = mainwin.propdock,
             disablenext = True,
-            nextonsetting = ('/page1/graph1/x/label',
-                             lambda val: val != ''),
+            nextonsetting = (
+                '/page1/graph1/x/label', lambda val: val != ''),
             nextstep = StepPropertiesWin2)
 
 class StepPropertiesWin2(TutorialStep):
@@ -240,8 +238,9 @@ be <code>x**2</code>, plotting x squared.</p>
 <p>(Veusz uses Python syntax for its functions, so the power operator
 is <code>**</code>, rather than <code>^</code>)</p>
 '''), mainwin,
-            nextonsetting = ('/page1/graph1/function1/function',
-                             lambda val: val.strip() == 'x**2'),
+            nextonsetting = (
+                '/page1/graph1/function1/function',
+                lambda val: val.strip() == 'x**2'),
             disablenext = True,
             nextstep=FunctionFormatting)
 
@@ -264,8 +263,8 @@ class FunctionFormatLine(TutorialStep):
     def __init__(self, mainwin):
 
         tb = mainwin.formatdock.tabwidget.tabBar()
-        label = qt4.QLabel("  ", tb)
-        tb.setTabButton(1, qt4.QTabBar.LeftSide, label)
+        label = qt.QLabel("  ", tb)
+        tb.setTabButton(1, qt.QTabBar.ButtonPosition.LeftSide, label)
 
         TutorialStep.__init__(
             self, _('''
@@ -274,7 +273,7 @@ tables. The options for drawing the function line are grouped under
 the flashing Line tab (%s).</p>
 
 <p class="usercmd">Click on the Line tab to continue.</p>
-''') % utils.pixmapAsHtml(utils.getPixmap('settings_plotline.png')),
+''') % utils.pixmapAsHtml(utils.getPixmap('settings_plotline.svg')),
             mainwin,
             flash=label,
             disablenext=True,
@@ -297,8 +296,9 @@ function line.</p>
 '''),
             mainwin,
             disablenext=True,
-            nextonsetting = ('/page1/graph1/function1/Line/color',
-                             lambda val: val.strip() != 'black'),
+            nextonsetting = (
+                '/page1/graph1/function1/Line/color',
+                lambda val: val.strip() != 'black'),
             nextstep=DataStart)
 
 ###########
@@ -338,8 +338,9 @@ class DataImport(TutorialStep):
             nextstep=DataImportDialog)
 
         # make sure we have the default delimiters
-        for k in ( 'importdialog_csvdelimitercombo_HistoryCombo',
-                   'importdialog_csvtextdelimitercombo_HistoryCombo' ):
+        for k in (
+                'importdialog_csvdelimitercombo_HistoryCombo',
+                'importdialog_csvtextdelimitercombo_HistoryCombo' ):
             if k in setting.settingdb:
                 del setting.settingdb[k]
 
@@ -350,6 +351,7 @@ class DataImport(TutorialStep):
         from ..dialogs.importdialog import ImportDialog
         if isinstance(dialog, ImportDialog):
             # make life easy by sticking in filename
+            dialog.slotReset()
             dialog.filenameedit.setText(
                 os.path.join(utils.exampleDirectory, 'tutorialdata.csv'))
             # and choosing tab
@@ -405,7 +407,7 @@ box or reopen it later.</p>
             disablenext=True,
             nextstep=DataImportDialog4)
 
-        self.timer = qt4.QTimer()
+        self.timer = qt.QTimer()
         self.timer.timeout.connect(self.slotTimeout)
         self.timer.start(200)
 
@@ -446,13 +448,14 @@ class AddXYPlotter(TutorialStep):
 <p>The point plotting widget plots datasets loaded in Veusz.</p>
 
 <p class="usercmd">The flashing icon adds a point plotting (xy)
-widget. Click on this, or go to the Add menu and choose "Add xy".</p>
+widget. Click on this, or go to the Insert menu and choose "Add xy".</p>
 '''), mainwin,
             flash=mainwin.treeedit.addtoolbar.widgetForAction(
                 mainwin.vzactions['add.xy']),
             disablenext=True,
-            nextonsetting = ('/page1/graph1/xy1/xData',
-                             lambda val: val != ''),
+            nextonsetting = (
+                '/page1/graph1/xy1/xData',
+                lambda val: val != ''),
             nextstep=SetXY_X)
 
 class SetXY_X(TutorialStep):
@@ -466,8 +469,9 @@ class SetXY_X(TutorialStep):
 menu or type it.</p>
 '''), mainwin,
             disablenext=True,
-            nextonsetting = ('/page1/graph1/xy1/xData',
-                             lambda val: val == 'alpha'),
+            nextonsetting = (
+                '/page1/graph1/xy1/xData',
+                lambda val: val == 'alpha'),
             nextstep=SetXY_Y)
 
 class SetXY_Y(TutorialStep):
@@ -478,8 +482,9 @@ class SetXY_Y(TutorialStep):
 <code>beta</code> dataset.</p>
 '''), mainwin,
             disablenext=True,
-            nextonsetting = ('/page1/graph1/xy1/yData',
-                             lambda val: val == 'beta'),
+            nextonsetting = (
+                '/page1/graph1/xy1/yData',
+                lambda val: val == 'beta'),
             nextstep=SetXYLine)
 
 class SetXYLine(TutorialStep):
@@ -494,11 +499,12 @@ widget is selected.</p>
 
 <p class="usercmd">Click on the check box next to the Hide option at
 the bottom, to hide the line plotted between the data points.</p>
-''') % utils.pixmapAsHtml(utils.getPixmap('settings_plotline.png')),
+''') % utils.pixmapAsHtml(utils.getPixmap('settings_plotline.svg')),
             mainwin,
             disablenext=True,
-            nextonsetting = ('/page1/graph1/xy1/PlotLine/hide',
-                             lambda val: val),
+            nextonsetting = (
+                '/page1/graph1/xy1/PlotLine/hide',
+                lambda val: val),
             nextstep=SetXYFill)
 
 class SetXYFill(TutorialStep):
@@ -509,11 +515,12 @@ class SetXYFill(TutorialStep):
 
 <p class="usercmd">Click on the "Marker fill (%s)" formatting tab.
 Change the fill color of the plotted data.</p>
-''') % utils.pixmapAsHtml(utils.getPixmap('settings_plotmarkerfill.png')),
+''') % utils.pixmapAsHtml(utils.getPixmap('settings_plotmarkerfill.svg')),
             mainwin,
             disablenext=True,
-            nextonsetting = ('/page1/graph1/xy1/MarkerFill/color',
-                             lambda val: val != 'black'),
+            nextonsetting = (
+                '/page1/graph1/xy1/MarkerFill/color',
+                lambda val: val != 'black'),
             nextstep=AddXY2nd)
 
 class AddXY2nd(TutorialStep):
@@ -526,13 +533,14 @@ class AddXY2nd(TutorialStep):
 <code>gamma</code> on the same graph.</p>
 
 <p class="usercmd">Add a second point plotting (xy) widget using the
-flashing icon, or go to the Add menu and choose "Add xy".</p>
+flashing icon, or go to the Insert menu and choose "Add xy".</p>
 '''), mainwin,
             flash=mainwin.treeedit.addtoolbar.widgetForAction(
                 mainwin.vzactions['add.xy']),
             disablenext=True,
-            nextonsetting = ('/page1/graph1/xy2/xData',
-                             lambda val: val != ''),
+            nextonsetting = (
+                '/page1/graph1/xy2/xData',
+                lambda val: val != ''),
             nextstep=AddXY2nd_2)
 
 class AddXY2nd_2(TutorialStep):
@@ -543,8 +551,9 @@ class AddXY2nd_2(TutorialStep):
 <code>alpha</code> dataset.</p>
 '''), mainwin,
             disablenext=True,
-            nextonsetting = ('/page1/graph1/xy2/xData',
-                             lambda val: val == 'alpha'),
+            nextonsetting = (
+                '/page1/graph1/xy2/xData',
+                lambda val: val == 'alpha'),
             nextstep=AddXY2nd_3)
 
 class AddXY2nd_3(TutorialStep):
@@ -555,8 +564,9 @@ class AddXY2nd_3(TutorialStep):
 <code>gamma</code> dataset.</p>
 '''), mainwin,
             disablenext=True,
-            nextonsetting = ('/page1/graph1/xy2/yData',
-                             lambda val: val == 'gamma'),
+            nextonsetting = (
+                '/page1/graph1/xy2/yData',
+                lambda val: val == 'gamma'),
             nextstep=AddXY2nd_4)
 
 class AddXY2nd_4(TutorialStep):
@@ -571,8 +581,9 @@ option.</p>
 ''') % utils.pixmapAsHtml(utils.getPixmap('settings_plotfillbelow.png')),
             mainwin,
             disablenext=True,
-            nextonsetting = ('/page1/graph1/xy2/FillBelow/hide',
-                             lambda val: not val),
+            nextonsetting = (
+                '/page1/graph1/xy2/FillBelow/hide',
+                lambda val: not val),
             nextstep=File1)
 
 class File1(TutorialStep):
@@ -645,7 +656,7 @@ deletes it from the document.</p>
     def slotCheckDelete(self, *args):
         d = self.mainwin.document
         try:
-            d.resolve(d.basewidget, '/page1/graph1')
+            d.resolveWidgetPath(None, '/page1/graph1')
         except ValueError:
             # success!
             self.nextStep.emit()
@@ -664,8 +675,9 @@ class AddGrid(TutorialStep):
             flash=mainwin.treeedit.addtoolbar.widgetForAction(
                 mainwin.vzactions['add.grid']),
             disablenext=True,
-            nextonsetting = ('/page1/grid1/rows',
-                             lambda val: val != ''),
+            nextonsetting = (
+                '/page1/grid1/rows',
+                lambda val: val != ''),
             nextstep=Paste1)
 
 class Paste1(TutorialStep):
@@ -680,8 +692,9 @@ from the Edit menu.</p>
             disablenext=True,
             flash=mainwin.treeedit.edittoolbar.widgetForAction(
                 mainwin.vzactions['edit.paste']),
-            nextonsetting = ('/page1/grid1/graph1/leftMargin',
-                             lambda val: val != ''),
+            nextonsetting = (
+                '/page1/grid1/graph1/leftMargin',
+                lambda val: val != ''),
             nextstep=Paste2)
 
 class Paste2(TutorialStep):
@@ -696,8 +709,9 @@ or choose "Paste" from the Edit menu.</p>
             disablenext=True,
             flash=mainwin.treeedit.edittoolbar.widgetForAction(
                 mainwin.vzactions['edit.paste']),
-            nextonsetting = ('/page1/grid1/graph2/leftMargin',
-                             lambda val: val != ''),
+            nextonsetting = (
+                '/page1/grid1/graph2/leftMargin',
+                lambda val: val != ''),
             nextstep=Paste3)
 
 class Paste3(TutorialStep):
@@ -711,8 +725,9 @@ change the graphs to be arranged in rows.</p>
 number of columns to 1.</p>
 '''), mainwin,
             disablenext=True,
-            nextonsetting = ('/page1/grid1/columns',
-                             lambda val: val == 1),
+            nextonsetting = (
+                '/page1/grid1/columns',
+                lambda val: val == 1),
             nextstep=Paste4)
 
 class Paste4(TutorialStep):
@@ -742,48 +757,48 @@ developers via the mailing list.</p>
 <p>You can try this tutorial again from the Help menu.</p>
 '''), mainwin, closestep=True, disablenext=True)
 
-class TutorialDock(qt4.QDockWidget):
+class TutorialDock(qt.QDockWidget):
     '''A dock tutorial window.'''
 
     def __init__(self, document, mainwin, *args):
-        qt4.QDockWidget.__init__(self, *args)
-        self.setAttribute(qt4.Qt.WA_DeleteOnClose)
+        qt.QDockWidget.__init__(self, *args)
+        self.setAttribute(qt.Qt.WidgetAttribute.WA_DeleteOnClose)
         self.setMinimumHeight(300)
         self.setWindowTitle('Tutorial - Veusz')
         self.setObjectName('veusztutorialwindow')
 
-        self.setStyleSheet('background: lightyellow;')
+        self.setStyleSheet('background: lightyellow; color: black;')
 
         self.document = document
         self.mainwin = mainwin
 
-        self.layout = l = qt4.QVBoxLayout()
+        self.layout = l = qt.QVBoxLayout()
 
-        txtdoc = qt4.QTextDocument(self)
+        txtdoc = qt.QTextDocument(self)
         txtdoc.setDefaultStyleSheet(
             "p.usercmd { color: blue; } "
-            "h1 { font-size: x-large;} "
+            "h1 { font-size: x-large; color: darkblue; } "
             "code { color: green;} "
-            )
-        self.textedit = qt4.QTextEdit(readOnly=True)
+        )
+        self.textedit = qt.QTextEdit(readOnly=True)
         self.textedit.setDocument(txtdoc)
 
         l.addWidget(self.textedit)
 
-        self.buttonbox = qt4.QDialogButtonBox()
+        self.buttonbox = qt.QDialogButtonBox()
         self.nextb = self.buttonbox.addButton(
-            'Next', qt4.QDialogButtonBox.ActionRole)
+            'Next', qt.QDialogButtonBox.ButtonRole.ActionRole)
         self.nextb.clicked.connect(self.slotNext)
 
         l.addWidget(self.buttonbox)
 
         # have to use a separate widget as dialog already has layout
-        self.widget = qt4.QWidget()
+        self.widget = qt.QWidget()
         self.widget.setLayout(l)
         self.setWidget(self.widget)
 
         # timer for controlling flashing
-        self.flashtimer = qt4.QTimer(self)
+        self.flashtimer = qt.QTimer(self)
         self.flashtimer.timeout.connect(self.slotFlashTimeout)
         self.flash = self.oldflash = None
         self.flashon = False
@@ -824,25 +839,25 @@ class TutorialDock(qt4.QDockWidget):
         # add a close button if requested
         if self.step.closestep:
             closeb = self.buttonbox.addButton(
-                'Close', qt4.QDialogButtonBox.ActionRole)
+                'Close', qt.QDialogButtonBox.ButtonRole.ActionRole)
             closeb.clicked.connect(self.close)
 
     # work around C/C++ object deleted
-    @qt4.pyqtSlot()
+    @qt.pyqtSlot()
     def slotFlashTimeout(self):
         '''Handle flashing of UI components.'''
 
         # because we're flashing random UI components, the C++ object
         # might be deleted, so we have to check before doing things to
-        # it: hence the qt4.isdeleted
+        # it: hence the sip.isdeleted
 
         if ( self.flash is not self.oldflash and self.oldflash is not None
-             and not qt4.isdeleted(self.oldflash) ):
+             and not qt.sip.isdeleted(self.oldflash) ):
             # clear any flashing on previous widget
             self.oldflash.setStyleSheet('')
             self.oldflash = None
 
-        if self.flash is not None and not qt4.isdeleted(self.flash):
+        if self.flash is not None and not qt.sip.isdeleted(self.flash):
             # set flash state and toggle variable
             if self.flashon:
                 self.flash.setStyleSheet('background: yellow;')
